@@ -27,6 +27,7 @@ DEALINGS IN THE SOFTWARE.
 #include <errno.h>
 #include <list>
 #include <poll.h>
+#include <pthread.h>
 
 // Define WITH_LIBDBUS to 1 (e.g. from configure) if you are using
 // libdbus < 1.2 that does not have dbus_watch_get_unix_fd yet.
@@ -50,7 +51,7 @@ typedef std::list<DBusWatch *> WatchesList;
 class DBusThread : public wxThread
 {
 public:
-	DBusThread(wxThreadKind kind, wxDBusConnection * parent, int ID, DBusConnection * connection) ;
+	DBusThread(wxThreadKind kind, wxDBusConnection * parent, int ID, DBusConnection * connection);
 	virtual ~DBusThread();
 	bool Init();
 	inline void SetExit() { m_exit = true; }
@@ -70,15 +71,15 @@ private:
 
 	int m_wakeup_pipe[2];
 	wxCriticalSection m_critical_section;
-	bool m_thread_holds_lock;
+	bool m_thread_holds_lock{};
 
 	int m_ID;
 	DBusConnection * m_connection;
 	wxDBusConnection * m_parent;
-	bool m_exit;
+	bool m_exit{};
 	std::list<DBusWatch *> bus_watches;
 
-	pthread_t m_parent_id;
+	pthread_t m_parent_id{};
 
 	static dbus_bool_t add_watch(DBusWatch *watch, void *data);
 	static void remove_watch(DBusWatch *watch, void *data);
@@ -99,8 +100,6 @@ DBusThread::DBusThread(wxThreadKind kind, wxDBusConnection * parent, int ID, DBu
 	m_ID = ID;
 	m_connection = connection;
 	m_parent = parent;
-	m_exit = false;
-	m_thread_holds_lock = false;
 	m_wakeup_pipe[0] = -1;
 	m_wakeup_pipe[1] = -1;
 }
@@ -118,7 +117,10 @@ bool DBusThread::Init()
 	if (Create() != wxTHREAD_NO_ERROR)
 		return false;
 
-	fcntl(m_wakeup_pipe[0], F_SETFL, O_NONBLOCK);
+	int res;
+	do {
+		res = fcntl(m_wakeup_pipe[0], F_SETFL, O_NONBLOCK);
+	} while( res == -1 && errno == EINTR );
 
 	m_parent_id = pthread_self();
 
@@ -153,7 +155,7 @@ wxThread::ExitCode DBusThread::Entry()
 		fd_array[0].events = POLLIN;
 
 		unsigned int nfds = 1;
-		for (std::list<DBusWatch *>::iterator it = bus_watches.begin(); it != bus_watches.end(); ++it) {
+		for (auto it = bus_watches.begin(); it != bus_watches.end(); ++it) {
 			if (dbus_watch_get_enabled(*it))
 			{
 #if WITH_LIBDBUS >= 2
@@ -185,7 +187,7 @@ wxThread::ExitCode DBusThread::Entry()
 				continue;
 			}
 
-			for (std::list<DBusWatch *>::iterator it = bus_watches.begin(); it != bus_watches.end(); ++it) {
+			for (auto it = bus_watches.begin(); it != bus_watches.end(); ++it) {
 				if (!dbus_watch_get_enabled(*it))
 					continue;
 #if WITH_LIBDBUS >= 2
@@ -268,7 +270,7 @@ void DBusThread::remove_watch(DBusWatch *watch, void *data)
 		thread->LeaveCriticalSection();
 }
 
-void DBusThread::toggle_watch(DBusWatch *watch, void *data)
+void DBusThread::toggle_watch(DBusWatch *, void *data)
 {
 	DBusThread * thread = (DBusThread *) data;
 
@@ -282,7 +284,6 @@ void response_notify(DBusPendingCall *pending, void *user_data);
 DBusHandlerResult handle_notification(DBusConnection *connection, DBusMessage *message, void *user_data);
 
 wxDBusConnection::wxDBusConnection(int ID, wxEvtHandler * EvtHandler, bool System)
-	: m_filter_installed()
 {
 	// Make sure libdbus locks its data structures, otherwise
 	// there'll be crashes if it gets used from multiple threads
@@ -293,7 +294,6 @@ wxDBusConnection::wxDBusConnection(int ID, wxEvtHandler * EvtHandler, bool Syste
 	m_connection = System ? dbus_bus_get(DBUS_BUS_SYSTEM, &(m_error->GetError())) : dbus_bus_get(DBUS_BUS_SESSION, &(m_error->GetError()));
 	if (!m_connection) {
 		fprintf(stderr, "Failed to connect to D-BUS: %s\n", m_error->GetError().message);
-		m_thread = NULL;
 	}
 	else
 	{
@@ -413,7 +413,7 @@ wxDBusError &wxDBusConnection::GetLastError()
 	return * m_error;
 }
 
-DBusHandlerResult handle_notification(DBusConnection *connection, DBusMessage *message, void *user_data)
+DBusHandlerResult handle_notification(DBusConnection *, DBusMessage *message, void *user_data)
 {
 	wxDBusConnection * _connection = (wxDBusConnection *) user_data;
 	DBusMessage * msg = dbus_message_copy(message);
@@ -422,7 +422,7 @@ DBusHandlerResult handle_notification(DBusConnection *connection, DBusMessage *m
 	return DBUS_HANDLER_RESULT_HANDLED;
 }
 
-DBusHandlerResult handle_message(DBusConnection *connection, DBusMessage *message, void *user_data)
+DBusHandlerResult handle_message(DBusConnection *, DBusMessage *message, void *user_data)
 {
 	wxDBusConnection * _connection = (wxDBusConnection *) user_data;
 	DBusMessage * msg = dbus_message_copy(message);
