@@ -30,7 +30,7 @@ public:
 	~CDirectoryCache();
 
 	void Store(const CDirectoryListing &listing, const CServer &server);
-	bool GetChangeTime(CTimeEx& time, const CServer &server, const CServerPath &path);
+	bool GetChangeTime(CMonotonicTime& time, const CServer &server, const CServerPath &path);
 	bool Lookup(CDirectoryListing &listing, const CServer &server, const CServerPath &path, bool allowUnsureEntries, bool& is_outdated);
 	bool DoesExist(const CServer &server, const CServerPath &path, int &hasUnsureEntries, bool &is_outdated);
 	bool LookupFile(CDirentry &entry, const CServer &server, const CServerPath &path, const wxString& file, bool &dirDidExist, bool &matchedCase);
@@ -48,9 +48,15 @@ protected:
 	public:
 		CCacheEntry() : lruIt() { };
 		CCacheEntry(const CCacheEntry &entry);
+		explicit CCacheEntry(CDirectoryListing const& l)
+			: listing(l)
+			, modificationTime(CMonotonicTime::Now())
+			, lruIt()
+		{}
 		~CCacheEntry() { };
+
 		CDirectoryListing listing;
-		CTimeEx modificationTime;
+		CMonotonicTime modificationTime;
 
 		CCacheEntry& operator=(const CCacheEntry &a);
 
@@ -60,6 +66,11 @@ protected:
 	class CServerEntry
 	{
 	public:
+		CServerEntry() {}
+		explicit CServerEntry(CServer const& s)
+			: server(s)
+		{}
+
 		CServer server;
 		std::list<CCacheEntry> cacheList;
 	};
