@@ -32,7 +32,7 @@ std::list<CFileZillaEnginePrivate*> CFileZillaEnginePrivate::m_engineList;
 int CFileZillaEnginePrivate::m_activeStatus[2] = {0, 0};
 std::list<CFileZillaEnginePrivate::t_failedLogins> CFileZillaEnginePrivate::m_failedLogins;
 
-DEFINE_EVENT_TYPE(fzEVT_ENGINE_NOTIFICATION);
+DEFINE_EVENT_TYPE(fzEVT_ENGINE_NOTIFICATION)
 
 wxFzEngineEvent::wxFzEngineEvent(int id, enum EngineNotificationType eventType, int data /*=0*/) : wxEvent(id, fzEVT_ENGINE_NOTIFICATION)
 {
@@ -54,16 +54,7 @@ END_EVENT_TABLE()
 CFileZillaEnginePrivate::CFileZillaEnginePrivate()
 	: m_retryTimer(this)
 {
-	m_pRateLimiter = 0;
-	m_maySendNotificationEvent = true;
-	m_pEventHandler = 0;
-	m_pControlSocket = 0;
-	m_pCurrentCommand = 0;
-	m_bIsInCommand = false;
-	m_nControlSocketError = 0;
-	m_asyncRequestCounter = 0;
 	m_engineList.push_back(this);
-	m_retryCount = 0;
 
 	static int id = 0;
 	m_engine_id = ++id;
@@ -77,7 +68,7 @@ CFileZillaEnginePrivate::~CFileZillaEnginePrivate()
 	delete m_pCurrentCommand;
 
 	// Delete notification list
-	for (std::list<CNotification *>::iterator iter = m_NotificationList.begin(); iter != m_NotificationList.end(); ++iter)
+	for (auto iter = m_NotificationList.begin(); iter != m_NotificationList.end(); ++iter)
 		delete *iter;
 
 	// Remove ourself from the engine list
@@ -142,10 +133,10 @@ const CCommand *CFileZillaEnginePrivate::GetCurrentCommand() const
 	return m_pCurrentCommand;
 }
 
-enum Command CFileZillaEnginePrivate::GetCurrentCommandId() const
+Command CFileZillaEnginePrivate::GetCurrentCommandId() const
 {
 	if (!m_pCurrentCommand)
-		return cmd_none;
+		return Command::none;
 
 	else
 		return GetCurrentCommand()->GetId();
@@ -170,20 +161,20 @@ void CFileZillaEnginePrivate::AddNotification(CNotification *pNotification)
 
 int CFileZillaEnginePrivate::ResetOperation(int nErrorCode)
 {
-	m_pLogging->LogMessage(Debug_Debug, _T("CFileZillaEnginePrivate::ResetOperation(%d)"), nErrorCode);
+	m_pLogging->LogMessage(MessageType::Debug_Debug, _T("CFileZillaEnginePrivate::ResetOperation(%d)"), nErrorCode);
 
 	if (nErrorCode & FZ_REPLY_DISCONNECTED)
-		m_lastListDir.Clear();
+		m_lastListDir.clear();
 
 	if (m_pCurrentCommand)
 	{
 		if ((nErrorCode & FZ_REPLY_NOTSUPPORTED) == FZ_REPLY_NOTSUPPORTED)
 		{
 			wxASSERT(m_bIsInCommand);
-			m_pLogging->LogMessage(Error, _("Command not supported by this protocol"));
+			m_pLogging->LogMessage(MessageType::Error, _("Command not supported by this protocol"));
 		}
 
-		if (m_pCurrentCommand->GetId() == cmd_connect)
+		if (m_pCurrentCommand->GetId() == Command::connect)
 		{
 			if (!(nErrorCode & ~(FZ_REPLY_ERROR | FZ_REPLY_DISCONNECTED | FZ_REPLY_TIMEOUT | FZ_REPLY_CRITICALERROR | FZ_REPLY_PASSWORDFAILED)) &&
 				nErrorCode & (FZ_REPLY_ERROR | FZ_REPLY_DISCONNECTED))
@@ -200,7 +191,7 @@ int CFileZillaEnginePrivate::ResetOperation(int nErrorCode)
 						unsigned int delay = GetRemainingReconnectDelay(pConnectCommand->GetServer());
 						if (!delay)
 							delay = 1;
-						m_pLogging->LogMessage(Status, _("Waiting to retry..."));
+						m_pLogging->LogMessage(MessageType::Status, _("Waiting to retry..."));
 						m_retryTimer.Start(delay, true);
 						return FZ_REPLY_WOULDBLOCK;
 					}
@@ -227,7 +218,7 @@ int CFileZillaEnginePrivate::ResetOperation(int nErrorCode)
 		{
 			COperationNotification *notification = new COperationNotification();
 			notification->nReplyCode = nErrorCode;
-			notification->commandId = cmd_none;
+			notification->commandId = Command::none;
 			AddNotification(notification);
 		}
 	}
@@ -278,7 +269,7 @@ int CFileZillaEnginePrivate::Connect(const CConnectCommand &command)
 	{
 		ServerProtocol protocol = CServer::GetProtocolFromPort(command.GetServer().GetPort(), true);
 		if (protocol != UNKNOWN && protocol != command.GetServer().GetProtocol())
-			m_pLogging->LogMessage(Status, _("Selected port usually in use by a different protocol."));
+			m_pLogging->LogMessage(MessageType::Status, _("Selected port usually in use by a different protocol."));
 	}
 
 	return ContinueConnect();
@@ -300,14 +291,14 @@ int CFileZillaEnginePrivate::Disconnect(const CDisconnectCommand &command)
 	return res;
 }
 
-int CFileZillaEnginePrivate::Cancel(const CCancelCommand &command)
+int CFileZillaEnginePrivate::Cancel(const CCancelCommand &)
 {
 	if (!IsBusy())
 		return FZ_REPLY_OK;
 
 	if (m_retryTimer.IsRunning())
 	{
-		wxASSERT(m_pCurrentCommand && m_pCurrentCommand->GetId() == cmd_connect);
+		wxASSERT(m_pCurrentCommand && m_pCurrentCommand->GetId() == Command::connect);
 
 		delete m_pControlSocket;
 		m_pControlSocket = 0;
@@ -317,10 +308,10 @@ int CFileZillaEnginePrivate::Cancel(const CCancelCommand &command)
 
 		m_retryTimer.Stop();
 
-		m_pLogging->LogMessage(::Error, _("Connection attempt interrupted by user"));
+		m_pLogging->LogMessage(MessageType::Error, _("Connection attempt interrupted by user"));
 		COperationNotification *notification = new COperationNotification();
 		notification->nReplyCode = FZ_REPLY_DISCONNECTED|FZ_REPLY_CANCELED;
-		notification->commandId = cmd_connect;
+		notification->commandId = Command::connect;
 		AddNotification(notification);
 
 		return FZ_REPLY_WOULDBLOCK;
@@ -336,26 +327,27 @@ int CFileZillaEnginePrivate::List(const CListCommand &command)
 	if (!IsConnected())
 		return FZ_REPLY_NOTCONNECTED;
 
-	if (command.GetPath().IsEmpty() && command.GetSubDir() != _T(""))
+	if (command.GetPath().empty() && !command.GetSubDir().empty())
 		return FZ_REPLY_SYNTAXERROR;
 
-	if (command.GetFlags() & LIST_FLAG_LINK && command.GetSubDir() == _T(""))
+	if (command.GetFlags() & LIST_FLAG_LINK && command.GetSubDir().empty())
 		return FZ_REPLY_SYNTAXERROR;
 
-	bool refresh = (command.GetFlags() & LIST_FLAG_REFRESH) != 0;
-	bool avoid = (command.GetFlags() & LIST_FLAG_AVOID) != 0;
+	int flags = command.GetFlags();
+	bool const refresh = (command.GetFlags() & LIST_FLAG_REFRESH) != 0;
+	bool const avoid = (command.GetFlags() & LIST_FLAG_AVOID) != 0;
 	if (refresh && avoid)
 		return FZ_REPLY_SYNTAXERROR;
 
-	if (!refresh && !command.GetPath().IsEmpty())
+	if (!refresh && !command.GetPath().empty())
 	{
 		const CServer* pServer = m_pControlSocket->GetCurrentServer();
 		if (pServer)
 		{
 			CServerPath path(CPathCache::Lookup(*pServer, command.GetPath(), command.GetSubDir()));
-			if (path.IsEmpty() && command.GetSubDir().IsEmpty())
+			if (path.empty() && command.GetSubDir().empty())
 				path = command.GetPath();
-			if (!path.IsEmpty())
+			if (!path.empty())
 			{
 				CDirectoryListing *pListing = new CDirectoryListing;
 				CDirectoryCache cache;
@@ -363,14 +355,12 @@ int CFileZillaEnginePrivate::List(const CListCommand &command)
 				bool found = cache.Lookup(*pListing, *pServer, path, true, is_outdated);
 				if (found && !is_outdated)
 				{
-					if (pListing->m_hasUnsureEntries)
-						refresh = true;
-					else
-					{
-						if (!avoid)
-						{
+					if (pListing->get_unsure_flags())
+						flags |= LIST_FLAG_REFRESH;
+					else {
+						if (!avoid) {
 							m_lastListDir = pListing->path;
-							m_lastListTime = wxDateTime::Now();
+							m_lastListTime = CDateTime::Now();
 							CDirectoryListingNotification *pNotification = new CDirectoryListingNotification(pListing->path);
 							AddNotification(pNotification);
 						}
@@ -379,7 +369,7 @@ int CFileZillaEnginePrivate::List(const CListCommand &command)
 					}
 				}
 				if (is_outdated)
-					refresh = true;
+					flags |= LIST_FLAG_REFRESH;
 				delete pListing;
 			}
 		}
@@ -388,7 +378,7 @@ int CFileZillaEnginePrivate::List(const CListCommand &command)
 		return FZ_REPLY_BUSY;
 
 	m_pCurrentCommand = command.Clone();
-	return m_pControlSocket->List(command.GetPath(), command.GetSubDir(), command.GetFlags());
+	return m_pControlSocket->List(command.GetPath(), command.GetSubDir(), flags);
 }
 
 int CFileZillaEnginePrivate::FileTransfer(const CFileTransferCommand &command)
@@ -411,7 +401,7 @@ int CFileZillaEnginePrivate::RawCommand(const CRawCommand& command)
 	if (IsBusy())
 		return FZ_REPLY_BUSY;
 
-	if (command.GetCommand() == _T(""))
+	if (command.GetCommand().empty())
 		return FZ_REPLY_SYNTAXERROR;
 
 	m_pCurrentCommand = command.Clone();
@@ -426,7 +416,7 @@ int CFileZillaEnginePrivate::Delete(const CDeleteCommand& command)
 	if (IsBusy())
 		return FZ_REPLY_BUSY;
 
-	if (command.GetPath().IsEmpty() ||
+	if (command.GetPath().empty() ||
 		command.GetFiles().empty())
 		return FZ_REPLY_SYNTAXERROR;
 
@@ -442,8 +432,8 @@ int CFileZillaEnginePrivate::RemoveDir(const CRemoveDirCommand& command)
 	if (IsBusy())
 		return FZ_REPLY_BUSY;
 
-	if (command.GetPath().IsEmpty() ||
-		command.GetSubDir() == _T(""))
+	if (command.GetPath().empty() ||
+		command.GetSubDir().empty())
 		return FZ_REPLY_SYNTAXERROR;
 
 	m_pCurrentCommand = command.Clone();
@@ -458,7 +448,7 @@ int CFileZillaEnginePrivate::Mkdir(const CMkdirCommand& command)
 	if (IsBusy())
 		return FZ_REPLY_BUSY;
 
-	if (command.GetPath().IsEmpty() || !command.GetPath().HasParent())
+	if (command.GetPath().empty() || !command.GetPath().HasParent())
 		return FZ_REPLY_SYNTAXERROR;
 
 	m_pCurrentCommand = command.Clone();
@@ -473,8 +463,8 @@ int CFileZillaEnginePrivate::Rename(const CRenameCommand& command)
 	if (IsBusy())
 		return FZ_REPLY_BUSY;
 
-	if (command.GetFromPath().IsEmpty() || command.GetToPath().IsEmpty() ||
-		command.GetFromFile() == _T("") || command.GetToFile() == _T(""))
+	if (command.GetFromPath().empty() || command.GetToPath().empty() ||
+		command.GetFromFile().empty() || command.GetToFile().empty())
 		return FZ_REPLY_SYNTAXERROR;
 
 	m_pCurrentCommand = command.Clone();
@@ -489,8 +479,8 @@ int CFileZillaEnginePrivate::Chmod(const CChmodCommand& command)
 	if (IsBusy())
 		return FZ_REPLY_BUSY;
 
-	if (command.GetPath().IsEmpty() || command.GetFile().IsEmpty() ||
-		command.GetPermission() == _T(""))
+	if (command.GetPath().empty() || command.GetFile().empty() ||
+		command.GetPermission().empty())
 		return FZ_REPLY_SYNTAXERROR;
 
 	m_pCurrentCommand = command.Clone();
@@ -510,7 +500,7 @@ void CFileZillaEnginePrivate::SendDirectoryListingNotification(const CServerPath
 	{
 		CDirectoryListingNotification *pNotification = new CDirectoryListingNotification(path, false, true);
 		AddNotification(pNotification);
-		m_lastListTime = CTimeEx::Now();
+		m_lastListTime = CMonotonicTime::Now();
 
 		// On failed messages, we don't notify other engines
 		return;
@@ -518,7 +508,7 @@ void CFileZillaEnginePrivate::SendDirectoryListingNotification(const CServerPath
 
 	CDirectoryCache cache;
 
-	CTimeEx changeTime;
+	CMonotonicTime changeTime;
 	if (!cache.GetChangeTime(changeTime, *pOwnServer, path))
 		return;
 
@@ -600,20 +590,15 @@ unsigned int CFileZillaEnginePrivate::GetRemainingReconnectDelay(const CServer&
 	return 0;
 }
 
-void CFileZillaEnginePrivate::OnTimer(wxTimerEvent& event)
+void CFileZillaEnginePrivate::OnTimer(wxTimerEvent&)
 {
-	if (!m_pCurrentCommand || m_pCurrentCommand->GetId() != cmd_connect)
+	if (!m_pCurrentCommand || m_pCurrentCommand->GetId() != Command::connect)
 	{
-		wxFAIL_MSG(_T("CFileZillaEnginePrivate::OnTimer called without pending cmd_connect"));
+		wxFAIL_MSG(_T("CFileZillaEnginePrivate::OnTimer called without pending Command::connect"));
 		return;
 	}
 	wxASSERT(!IsConnected());
 
-#if 0//__WXDEBUG__
-	const CConnectCommand *pConnectCommand = (CConnectCommand *)m_pCurrentCommand;
-	wxASSERT(!GetRemainingReconnectDelay(pConnectCommand->GetServer()));
-#endif
-
 	delete m_pControlSocket;
 	m_pControlSocket = 0;
 
@@ -627,7 +612,7 @@ int CFileZillaEnginePrivate::ContinueConnect()
 	unsigned int delay = GetRemainingReconnectDelay(server);
 	if (delay)
 	{
-		m_pLogging->LogMessage(Status, wxPLURAL("Delaying connection for %d second due to previously failed connection attempt...", "Delaying connection for %d seconds due to previously failed connection attempt...", (delay + 999) / 1000), (delay + 999) / 1000);
+		m_pLogging->LogMessage(MessageType::Status, wxPLURAL("Delaying connection for %d second due to previously failed connection attempt...", "Delaying connection for %d seconds due to previously failed connection attempt...", (delay + 999) / 1000), (delay + 999) / 1000);
 		m_retryTimer.Start(delay, true);
 		return FZ_REPLY_WOULDBLOCK;
 	}
@@ -648,7 +633,7 @@ int CFileZillaEnginePrivate::ContinueConnect()
 		m_pControlSocket = new CHttpControlSocket(this);
 		break;
 	default:
-		m_pLogging->LogMessage(Debug_Warning, _T("Not a valid protocol: %d"), server.GetProtocol());
+		m_pLogging->LogMessage(MessageType::Debug_Warning, _T("Not a valid protocol: %d"), server.GetProtocol());
 		return FZ_REPLY_SYNTAXERROR|FZ_REPLY_DISCONNECTED;
 	}
 
