@@ -83,7 +83,7 @@ protected:
 	virtual void OnConnect();
 	virtual void OnReceive();
 
-	virtual bool Send(wxString str, bool maskArgs = false, bool measureRTT = true);
+	bool SendCommand(wxString const& str, bool maskArgs = false, bool measureRTT = true);
 
 	// Parse the latest reply line from the server
 	void ParseLine(wxString line);
@@ -141,8 +141,6 @@ protected:
 
 	int m_lastTypeBinary;
 
-	int m_pendingTransferEndEvents;
-
 	// Used by keepalive code so that we're not using keep alive
 	// till the end of time. Stop after a couple of minutes.
 	wxDateTime m_lastCommandCompletionTime;
@@ -151,8 +149,8 @@ protected:
 
 	CLatencyMeasurement m_rtt;
 
-	DECLARE_EVENT_TABLE();
-	void OnExternalIPAddress(fzExternalIPResolveEvent& event);
+	DECLARE_EVENT_TABLE()
+	void OnExternalIPAddress(fzExternalIPResolveEvent&);
 	void OnIdleTimer(wxTimerEvent& event);
 };
 
@@ -164,7 +162,7 @@ public:
 	CFtpTransferOpData();
 	virtual ~CFtpTransferOpData() {}
 
-	enum TransferEndReason transferEndReason;
+	TransferEndReason transferEndReason;
 	bool tranferCommandSent;
 
 	wxLongLong resumeOffset;
