@@ -1,8 +1,11 @@
 #ifndef __HTTPCONTROLSOCKET_H__
 #define __HTTPCONTROLSOCKET_H__
 
+#include <wx/uri.h>
+
 class CHttpOpData;
 class CTlsSocket;
+class CHttpFileTransferOpData;
 class CHttpControlSocket : public CRealControlSocket
 {
 public:
@@ -38,6 +41,8 @@ protected:
 
 	virtual void ResetHttpData(CHttpOpData* pData);
 
+	int OpenFile( CHttpFileTransferOpData* pData);
+
 	int ParseHeader(CHttpOpData* pData);
 	int OnChunkedData(CHttpOpData* pData);
 
@@ -50,6 +55,8 @@ protected:
 	CHttpOpData* m_pHttpOpData;
 
 	CTlsSocket* m_pTlsSocket;
+
+	wxURI m_current_uri;
 };
 
 #endif //__HTTPCONTROLSOCKET_H__
