@@ -1,32 +1,17 @@
 #include <filezilla.h>
 #include <gnutls/gnutls.h>
 #include <sqlite3.h>
+#include <random>
+#include <cstdint>
 
+#include "timeex.h"
 #include "tlssocket.h"
 
-bool VerifySetDate(wxDateTime& date, int year, wxDateTime::Month month, int day, int hour /*=0*/, int minute /*=0*/, int second /*=0*/)
-{
-	if (year < 1900 || year > 3000)
-		return false;
-
-	if (month < 0 || month >= 12)
-		return false;
-
-	int maxDays = wxDateTime::GetNumberOfDays(month, year);
-	if (day > maxDays)
-		return false;
-
-	date.Set(day, month, year, hour, minute, second);
-
-	return date.IsValid();
-}
-
 wxString GetIPV6LongForm(wxString short_address)
 {
-	if (short_address[0] == '[')
-	{
+	if (!short_address.empty() && short_address[0] == '[') {
 		if (short_address.Last() != ']')
-			return _T("");
+			return wxString();
 		short_address.RemoveLast();
 		short_address = short_address.Mid(1);
 	}
@@ -45,50 +30,46 @@ wxString GetIPV6LongForm(wxString short_address)
 
 	const unsigned int len = short_address.Len();
 	if (len > 39)
-		return _T("");
+		return wxString();
 
 	// First part, before possible ::
 	unsigned int i = 0;
 	unsigned int grouplength = 0;
-	for (i = 0; i < len + 1; i++)
-	{
-		const wxChar& c = short_address[i];
-		if (c == ':' || !c)
-		{
-			if (!grouplength)
-			{
+
+	wxChar const* s = short_address.c_str(); // Get it zero-terminated.
+	for (i = 0; i < len + 1; ++i) {
+		const wxChar& c = s[i];
+		if (c == ':' || !c) {
+			if (!grouplength) {
 				// Empty group length, not valid
-				if (!c || short_address[i + 1] != ':')
-					return _T("");
-				i++;
+				if (!c || s[i + 1] != ':')
+					return wxString();
+				++i;
 				break;
 			}
 
 			out += 4 - grouplength;
 			for (unsigned int j = grouplength; j > 0; j--)
-				*out++ = short_address[i - j];
+				*out++ = s[i - j];
 			// End of string...
-			if (!c)
-			{
+			if (!c) {
 				if (!*out)
 					// ...on time
 					return buffer;
 				else
 					// ...premature
-					return _T("");
+					return wxString();
 			}
-			else if (!*out)
-			{
+			else if (!*out) {
 				// Too long
-				return _T("");
+				return wxString();
 			}
 
-			out++;
+			++out;
 
 			grouplength = 0;
-			if (short_address[i + 1] == ':')
-			{
-				i++;
+			if (s[i + 1] == ':') {
+				++i;
 				break;
 			}
 			continue;
@@ -97,11 +78,11 @@ wxString GetIPV6LongForm(wxString short_address)
 				 (c < 'a' || c > 'f'))
 		{
 			// Invalid character
-			return _T("");
+			return wxString();
 		}
 		// Too long group
 		if (++grouplength > 4)
-			return _T("");
+			return wxString();
 	}
 
 	// Second half after ::
@@ -114,16 +95,16 @@ wxString GetIPV6LongForm(wxString short_address)
 		if (out < end_first)
 		{
 			// Too long
-			return _T("");
+			return wxString();
 		}
 
-		const wxChar& c = short_address[i];
+		const wxChar& c = s[i];
 		if (c == ':')
 		{
 			if (!grouplength)
 			{
 				// Empty group length, not valid
-				return _T("");
+				return wxString();
 			}
 
 			out -= 5 - grouplength;
@@ -135,24 +116,24 @@ wxString GetIPV6LongForm(wxString short_address)
 				 (c < 'a' || c > 'f'))
 		{
 			// Invalid character
-			return _T("");
+			return wxString();
 		}
 		// Too long group
 		if (++grouplength > 4)
-			return _T("");
+			return wxString();
 		*out-- = c;
 	}
 	if (!grouplength)
 	{
 		// Empty group length, not valid
-		return _T("");
+		return wxString();
 	}
 	out -= 5 - grouplength;
 	out += 2;
 
 	int diff = out - end_first;
 	if (diff < 0 || diff % 5)
-		return _T("");
+		return wxString();
 
 	return buffer;
 }
@@ -172,7 +153,7 @@ bool IsRoutableAddress(const wxString& address, enum CSocket::address_family fam
 	if (family == CSocket::ipv6)
 	{
 		wxString long_address = GetIPV6LongForm(address);
-		if (long_address.empty())
+		if (long_address.size() != 39)
 			return false;
 		if (long_address[0] == '0')
 		{
@@ -248,7 +229,7 @@ bool IsRoutableAddress(const wxString& address, enum CSocket::address_family fam
 
 bool IsIpAddress(const wxString& address)
 {
-	if (GetIPV6LongForm(address) != _T(""))
+	if (!GetIPV6LongForm(address).empty())
 		return true;
 
 	int segment = 0;
@@ -258,9 +239,10 @@ bool IsIpAddress(const wxString& address)
 		const char& c = address[i];
 		if (c == '.')
 		{
-			if (address[i + 1] == '.')
+			if (i + 1 < address.Len() && address[i + 1] == '.') {
 				// Disallow multiple dots in a row
 				return false;
+			}
 
 			if (segment > 255)
 				return false;
@@ -283,98 +265,37 @@ bool IsIpAddress(const wxString& address)
 	return true;
 }
 
-// RAND_MAX is different depending on platform.
-// For example on MSW, it is just 0x7fff, not even enough to cover
-// a full range of tcp ports.
-// On Linux it is identical to INT_MAX.
-//
-// The following code can generate random numbers using rand() for any
-// RAND_MAX.
-int GetRandomNumber(int low, int high)
+
+int GetRandomNumber(int min, int max)
 {
-	wxASSERT(low <= high);
-	if (low == high)
-		return low;
+	wxASSERT(min <= max);
+	if (min >= max)
+		return min;
 
-	const int range = high - low;
-	if (RAND_MAX < range)
-	{
-		// Calculate number of random bits rand() returns
-		int r = RAND_MAX;
-		unsigned int random_bits = 0;
-		bool zero = false;
-		while (r)
-		{
-			if (!(r & 1))
-				zero = true;
-			r >>= 1;
-			random_bits++;
-		}
-		if (zero)
-			random_bits--;
+	static std::mt19937_64 gen = std::mt19937_64(std::random_device()());
+	std::uniform_int_distribution<int> dist(min, max);
 
-		// Calculate number of bits in the range
-		unsigned int maxshift = 0;
-		r = range;
-		while (r)
-		{
-			r >>= 1;
-			maxshift++;
-		}
-
-		unsigned int s = 0;
-		do
-		{
-			unsigned int shift_remaining = maxshift;
-			while (shift_remaining)
-			{
-				int m;
-				if (shift_remaining >= random_bits)
-				{
-					m = (1 << random_bits) - 1;
-					s <<= random_bits;
-					s += (unsigned int)GetRandomNumber(0, m);
-					shift_remaining -= random_bits;
-				}
-				else
-				{
-					m = (1 << shift_remaining) - 1;
-					s <<= shift_remaining;
-					s += (unsigned int)GetRandomNumber(0, m);
-					shift_remaining = 0;
-				}
-			}
-		} while (s > (unsigned int)range);
-
-		return s;
-	}
-	else if (range == RAND_MAX)
-		return low + rand();
-	else
-	{
-		const unsigned int max = ((((unsigned int)RAND_MAX) + 1) / (range + 1)) * (range + 1);
-		unsigned int r;
-		do {
-			r = (unsigned int)rand();
-		} while (r >= max);
-		return (int)((r % (range + 1)) + low);
-	}
+	return dist(gen);
 }
 
 void MakeLowerAscii(wxString& str)
 {
-	for (size_t i = 0; i < str.Len(); i++)
-	{
-		wxChar& c = str[i];
-		if (c >= 'A' && c <= 'Z')
+	for (size_t i = 0; i < str.Len(); i++) {
+		wxChar c = str.GetChar(i);
+		if (c >= 'A' && c <= 'Z') {
 			c += 32;
+			str.SetChar(i, wxUniChar(c));
+		}
+		else if (c == 0x130 || c == 0x131) {
+			c = 'i';
+			str.SetChar(i, wxUniChar(c));
+		}
 	}
 }
 
 wxString GetDependencyVersion(dependency::type d)
 {
-	switch (d)
-	{
+	switch (d) {
 	case dependency::wxwidgets:
 		return wxVERSION_NUM_DOT_STRING_T;
 	case dependency::gnutls:
@@ -388,16 +309,13 @@ wxString GetDependencyVersion(dependency::type d)
 	case dependency::sqlite:
 		return wxString::FromUTF8(sqlite3_libversion());
 	default:
-		return _T("");
+		return wxString();
 	}
-
-	return _T("");
 }
 
 wxString GetDependencyName(dependency::type d)
 {
-	switch (d)
-	{
+	switch (d) {
 	case dependency::wxwidgets:
 		return _T("wxWidgets");
 	case dependency::gnutls:
@@ -405,13 +323,48 @@ wxString GetDependencyName(dependency::type d)
 	case dependency::sqlite:
 		return _T("SQLite");
 	default:
-		return _T("");
+		return wxString();
 	}
-
-	return _T("");
 }
 
 wxString ListTlsCiphers(const wxString& priority)
 {
 	return CTlsSocket::ListTlsCiphers(priority);
 }
+
+#ifdef __WXMSW__
+bool IsAtLeast(int major, int minor = 0)
+{
+	OSVERSIONINFOEX vi = { 0 };
+	vi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
+	vi.dwMajorVersion = major;
+	vi.dwMinorVersion = minor;
+	vi.dwPlatformId = VER_PLATFORM_WIN32_NT;
+
+	DWORDLONG mask = 0;
+	VER_SET_CONDITION(mask, VER_MAJORVERSION, VER_GREATER_EQUAL);
+	VER_SET_CONDITION(mask, VER_MINORVERSION, VER_GREATER_EQUAL);
+	VER_SET_CONDITION(mask, VER_PLATFORMID, VER_EQUAL);
+	return VerifyVersionInfo(&vi, VER_MAJORVERSION | VER_MINORVERSION | VER_PLATFORMID, mask) != 0;
+}
+#endif
+
+bool GetRealOsVersion(int& major, int& minor)
+{
+#ifndef __WXMSW__
+	return wxGetOsVersion(&major, &minor) != wxOS_UNKNOWN;
+#else
+	major = 4;
+	minor = 0;
+	while (IsAtLeast(++major, minor))
+	{
+	}
+	--major;
+	while (IsAtLeast(major, ++minor))
+	{
+	}
+	--minor;
+
+	return true;
+#endif
+}
