@@ -1,22 +1,13 @@
 #include <filezilla.h>
 #include "string_coalescer.h"
+#include <msgbox.h>
 
 #include <wx/wx.h>
 
-#if HAVE_TR1_UNORDERED_MAP
-#include <tr1/unordered_map>
-#else
 #include <unordered_map>
-#endif
 
 #include <algorithm>
 
-namespace std {
-namespace tr1 {
-}
-using namespace tr1;
-}
-
 unsigned int CalculateCapacity()
 {
 #ifdef __WXMSW__
@@ -64,9 +55,7 @@ struct fast_equal
 {
 	bool operator()(wxString const& lhs, wxString const& rhs) const
 	{
-		// wxString is CoW, yet it doesn't even do this fast pointer
-		// comparison in it's less and/or equal operator(s).
-		return lhs.c_str() == rhs.c_str() || lhs == rhs;
+		return lhs == rhs;
 	}
 };
 
@@ -129,7 +118,6 @@ void Coalesce(wxString& s)
 			lru_.pop_front();
 		}
 
-		tree::iterator it = tree_.insert(std::make_pair(s, backref_holder())).first;
 		lru_.push_back(it);
 		it->second.b_ = new backref(--lru_.end());
 	}
@@ -152,7 +140,7 @@ void BenchmarkStringCoalescer()
 	wxDateTime start = wxDateTime::UNow();
 	for (int i = 0; i < 100; ++i)
 	{
-		for( std::deque<wxString>::iterator it = s.begin(); it != s.end(); ++it)
+		for( auto it = s.begin(); it != s.end(); ++it)
 			Coalesce( *it );
 	}
 	wxDateTime stop = wxDateTime::UNow();
@@ -167,7 +155,7 @@ void BenchmarkStringCoalescer()
 	int median = stringLengths.empty() ? -1 : (stringLengths[stringLengths.size() / 2]);
 	float avg = tree_.empty() ? -1. : ((float)sum / tree_.size());
 
-	wxMessageBox(wxString::Format(_T("Looking up all strings a hundred times took %dms.\n\nEntries: %u\nAssumed memory consumption: %u\nAverage string length: %0.3f\nMedian string length: %d"),
+	wxMessageBoxEx(wxString::Format(_T("Looking up all strings a hundred times took %dms.\n\nEntries: %u\nAssumed memory consumption: %u\nAverage string length: %0.3f\nMedian string length: %d"),
 		(stop - start).GetMilliseconds().GetLo(),
 		(unsigned int)tree_.size(),
 		size_,
