@@ -15,12 +15,19 @@
 #include "setup.h"
 
 #ifdef __WXMSW__
+#ifndef NOMINMAX
+#define NOMINMAX
+#endif
+#ifndef STRICT
+#define STRICT 1
+#endif
 #include <windows.h>
 #endif
 
 #include <wx/datetime.h>
 #include <wx/event.h>
 #include <wx/string.h>
+#include <wx/translation.h>
 
 #include <list>
 #include <vector>
@@ -37,8 +44,6 @@
 
 #include "misc.h"
 
-#ifdef _DEBUG
-#define new DEBUG_NEW
-#endif
+#define TRANSLATE_T(str) _T(str)
 
 #endif //__LIBFILEZILLA_H__
