@@ -34,7 +34,7 @@ public:
 	static wxString GetUnit(COptionsBase* pOptions, _unit unit, enum _format = formats_count);
 	static wxString FormatUnit(COptionsBase* pOptions, const wxLongLong& size, _unit unit, int base = 1024);
 
-	static wxString Format(COptionsBase* pOptions, const wxLongLong& size, bool add_bytes_suffix, enum _format format, bool thousands_separator, int num_decimal_places);
+	static wxString Format(COptionsBase* pOptions, wxLongLong size, bool add_bytes_suffix, enum _format format, bool thousands_separator, int num_decimal_places);
 	static wxString Format(COptionsBase* pOptions, const wxLongLong& size, bool add_bytes_suffix = false);
 
 	static const wxString& GetThousandsSeparator();
