@@ -7,7 +7,7 @@
 
 class CSocketEventHandler;
 class CSocketEventSource;
-class CSocketEvent
+class CSocketEvent final
 {
 public:
 	enum EventType
@@ -44,7 +44,7 @@ protected:
 	friend class CSocketEventDispatcher;
 };
 
-class CSocketEventDispatcher : protected wxEvtHandler
+class CSocketEventDispatcher final : protected wxEvtHandler
 {
 public:
 	void SendEvent(CSocketEvent* evt);
@@ -178,6 +178,7 @@ public:
 		flag_keepalive = 0x02
 	};
 
+	int GetFlags() const { return m_flags; }
 	void SetFlags(int flags);
 
 	// If called on listen socket, sizes will be inherited by
