@@ -18,9 +18,9 @@ public:
 	wxString label;
 #endif
 	bool dir;
+	bool is_dir() const { return dir; }
 	wxLongLong size;
-	bool hasTime;
-	wxDateTime lastModified;
+	CDateTime time;
 	int attributes;
 };
 
@@ -34,7 +34,7 @@ public:
 	virtual ~CLocalListView();
 
 protected:
-	void OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString& data, const void* data2);
+	void OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString& data, const void*);
 	bool DisplayDir(wxString dirname);
 	void ApplyCurrentFilter();
 
@@ -61,7 +61,7 @@ protected:
 public:
 	virtual bool CanStartComparison(wxString* pError);
 	virtual void StartComparison();
-	virtual bool GetNextFile(wxString& name, bool &dir, wxLongLong &size, wxDateTime& date, bool &hasTime);
+	virtual bool GetNextFile(wxString& name, bool &dir, wxLongLong &size, CDateTime& date);
 	virtual void FinishComparison();
 
 	virtual bool ItemIsDir(int index) const;
@@ -84,15 +84,17 @@ protected:
 
 	wxString m_dir;
 
-	wxDropTarget* m_pDropTarget;
 	int m_dropTarget;
 
+	wxString MenuMkdir();
+
 	// Event handlers
 	DECLARE_EVENT_TABLE()
 	void OnItemActivated(wxListEvent& event);
 	void OnContextMenu(wxContextMenuEvent& event);
 	void OnMenuUpload(wxCommandEvent& event);
 	void OnMenuMkdir(wxCommandEvent& event);
+	void OnMenuMkdirChgDir(wxCommandEvent&);
 	void OnMenuDelete(wxCommandEvent& event);
 	void OnMenuRename(wxCommandEvent& event);
 	void OnKeyDown(wxKeyEvent& event);
