@@ -56,8 +56,13 @@
 #endif
 #ifndef __WXMAC__
 #include <wx/taskbar.h>
+#else
+#include <wx/combobox.h>
 #endif
 
+#include <functional>
+#include <map>
+
 #ifdef _DEBUG
 #define new DEBUG_NEW
 #endif
@@ -77,7 +82,43 @@ static int GetAvailableUpdateMenuId()
 }
 #endif
 
-BEGIN_EVENT_TABLE(CMainFrame, wxFrame)
+std::map<int, std::pair<std::function<void(wxTextEntry*)>, wxChar>> keyboardCommands;
+
+wxTextEntry* GetSpecialTextEntry(wxWindow* w, wxChar cmd)
+{
+#ifdef __WXMAC__
+	if( cmd == 'A' || cmd == 'V' ) {
+		wxTextCtrl* text = dynamic_cast<wxTextCtrl*>(w);
+		if( text && text->GetWindowStyle() & wxTE_PASSWORD ) {
+			return text;
+		}
+	}
+	wxComboBox* combo = dynamic_cast<wxComboBox*>(w);
+	if( combo ) {
+		return combo;
+	}
+#endif
+	return 0;
+}
+
+bool HandleKeyboardCommand(wxCommandEvent& event, wxWindow& parent)
+{
+	auto const& it = keyboardCommands.find(event.GetId());
+	if( it == keyboardCommands.end() ) {
+		return false;
+	}
+
+	wxTextEntry* e = GetSpecialTextEntry(parent.FindFocus(), it->second.second);
+	if( e ) {
+		it->second.first(e);
+	}
+	else {
+		event.Skip();
+	}
+	return true;
+}
+
+BEGIN_EVENT_TABLE(CMainFrame, wxNavigationEnabled<wxFrame>)
 	EVT_SIZE(CMainFrame::OnSize)
 	EVT_MENU(wxID_ANY, CMainFrame::OnMenuHandler)
 	EVT_FZ_NOTIFICATION(wxID_ANY, CMainFrame::OnEngineEvent)
@@ -118,7 +159,6 @@ BEGIN_EVENT_TABLE(CMainFrame, wxFrame)
 	EVT_TOOL_DROPDOWN(XRCID("ID_TOOLBAR_SITEMANAGER"), CMainFrame::OnSitemanagerDropdown)
 #endif
 	EVT_NAVIGATION_KEY(CMainFrame::OnNavigationKeyEvent)
-	EVT_SET_FOCUS(CMainFrame::OnGetFocus)
 	EVT_CHAR_HOOK(CMainFrame::OnChar)
 	EVT_MENU(XRCID("ID_MENU_VIEW_FILTERS"), CMainFrame::OnFilter)
 	EVT_ACTIVATE(CMainFrame::OnActivate)
@@ -131,7 +171,9 @@ BEGIN_EVENT_TABLE(CMainFrame, wxFrame)
 	EVT_MENU(XRCID("ID_COMPARE_DATE"), CMainFrame::OnDropdownComparisonMode)
 	EVT_MENU(XRCID("ID_COMPARE_HIDEIDENTICAL"), CMainFrame::OnDropdownComparisonHide)
 	EVT_TOOL(XRCID("ID_TOOLBAR_SYNCHRONIZED_BROWSING"), CMainFrame::OnSyncBrowse)
-#ifndef __WXMAC__
+#ifdef __WXMAC__
+	EVT_CHILD_FOCUS(CMainFrame::OnChildFocused)
+#else
 	EVT_ICONIZE(CMainFrame::OnIconize)
 #endif
 #ifdef __WXGTK__
@@ -218,6 +260,13 @@ protected:
 CMainFrame::CMainFrame()
 	: m_comparisonToggleAcceleratorId(wxNewId())
 {
+#ifdef __WXMAC__
+	keyboardCommands[wxNewId()] = std::make_pair([](wxTextEntry* e){ e->Cut(); }, 'X');
+	keyboardCommands[wxNewId()] = std::make_pair([](wxTextEntry* e){ e->Copy(); }, 'C');
+	keyboardCommands[wxNewId()] = std::make_pair([](wxTextEntry* e){ e->Paste(); }, 'V');
+	keyboardCommands[wxNewId()] = std::make_pair([](wxTextEntry* e){ e->SelectAll(); }, 'A');
+#endif
+
 	m_pActivityLed[0] = m_pActivityLed[1] = 0;
 
 	wxGetApp().AddStartupProfileRecord(_T("CMainFrame::CMainFrame"));
@@ -392,16 +441,19 @@ CMainFrame::CMainFrame()
 	if (!RestoreSplitterPositions())
 		SetDefaultSplitterPositions();
 
-	wxAcceleratorEntry entries[11];
+	std::vector<wxAcceleratorEntry> entries;
 	//entries[0].Set(wxACCEL_CMD | wxACCEL_SHIFT, 'I', XRCID("ID_MENU_VIEW_FILTERS"));
-	for (int i = 0; i < 10; i++)
-	{
+	for (int i = 0; i < 10; i++) {
 		tab_hotkey_ids[i] = wxNewId();
-		entries[i].Set(wxACCEL_CMD, (int)'0' + i, tab_hotkey_ids[i]);
+		entries.push_back(wxAcceleratorEntry(wxACCEL_CMD, (int)'0' + i, tab_hotkey_ids[i]));
 	}
-	entries[10].Set(wxACCEL_CMD | wxACCEL_SHIFT, 'O', m_comparisonToggleAcceleratorId);
-
-	wxAcceleratorTable accel(sizeof(entries) / sizeof(wxAcceleratorEntry), entries);
+	entries.push_back(wxAcceleratorEntry(wxACCEL_CMD | wxACCEL_SHIFT, 'O', m_comparisonToggleAcceleratorId));
+#ifdef __WXMAC__
+	for (auto it = keyboardCommands.begin(); it != keyboardCommands.end(); ++it) {
+		entries.push_back(wxAcceleratorEntry(wxACCEL_CMD, it->second.second, it->first));
+	}
+#endif
+	wxAcceleratorTable accel(entries.size(), &entries[0]);
 	SetAcceleratorTable(accel);
 
 	ConnectNavigationHandler(m_pStatusView);
@@ -410,6 +462,8 @@ CMainFrame::CMainFrame()
 	CEditHandler::Create()->SetQueue(m_pQueueView);
 
 	CAutoAsciiFiles::SettingsChanged();
+
+	FixTabOrder();
 }
 
 CMainFrame::~CMainFrame()
@@ -789,6 +843,9 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 	{
 		CServer server;
 		CState* pState = CContextManager::Get()->GetCurrentContext();
+		if (!pState) {
+			return;
+		}
 		const CServer* pServer = pState ? pState->GetServer() : 0;
 
 		CContextControl::_context_controls* controls = m_pContextControl->GetCurrentControls();
@@ -871,6 +928,9 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		if (pComparisonManager && pComparisonManager->IsComparing())
 			pComparisonManager->CompareListings();
 	}
+	else if (HandleKeyboardCommand(event, *this)) {
+		return;
+	}
 	else
 	{
 		for (int i = 0; i < 10; i++)
@@ -1185,28 +1245,23 @@ bool CMainFrame::CloseDialogsAndQuit(wxCloseEvent &event)
 
 void CMainFrame::OnClose(wxCloseEvent &event)
 {
-	if (!m_bQuit)
-	{
+	if (!m_bQuit) {
 		static bool quit_confirmation_displayed = false;
-		if (quit_confirmation_displayed && event.CanVeto())
-		{
+		if (quit_confirmation_displayed && event.CanVeto()) {
 			event.Veto();
 			return;
 		}
-		if (event.CanVeto())
-		{
+		if (event.CanVeto()) {
 			quit_confirmation_displayed = true;
 
-			if (m_pQueueView && m_pQueueView->IsActive())
-			{
+			if (m_pQueueView && m_pQueueView->IsActive()) {
 				CConditionalDialog dlg(this, CConditionalDialog::confirmexit, CConditionalDialog::yesno);
 				dlg.SetTitle(_("Close FileZilla"));
 
 				dlg.AddText(_("File transfers still in progress."));
 				dlg.AddText(_("Do you really want to close FileZilla?"));
 
-				if (!dlg.Run())
-				{
+				if (!dlg.Run()) {
 					event.Veto();
 					quit_confirmation_displayed = false;
 					return;
@@ -1216,8 +1271,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 			}
 
 			CEditHandler* pEditHandler = CEditHandler::Get();
-			if (pEditHandler)
-			{
+			if (pEditHandler) {
 				if (pEditHandler->GetFileCount(CEditHandler::remote, CEditHandler::edit) || pEditHandler->GetFileCount(CEditHandler::none, CEditHandler::upload) ||
 					pEditHandler->GetFileCount(CEditHandler::none, CEditHandler::upload_and_remove) ||
 					pEditHandler->GetFileCount(CEditHandler::none, CEditHandler::upload_and_remove_failed))
@@ -1229,8 +1283,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 					dlg.AddText(_("If you close FileZilla, your changes will be lost."));
 					dlg.AddText(_("Do you really want to close FileZilla?"));
 
-					if (!dlg.Run())
-					{
+					if (!dlg.Run()) {
 						event.Veto();
 						quit_confirmation_displayed = false;
 						return;
@@ -1242,8 +1295,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 			quit_confirmation_displayed = false;
 		}
 
-		if (m_pWindowStateManager)
-		{
+		if (m_pWindowStateManager) {
 			m_pWindowStateManager->Remember(OPTION_MAINWINDOW_POSITION);
 			delete m_pWindowStateManager;
 			m_pWindowStateManager = 0;
@@ -1288,13 +1340,15 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 
 	bool res = true;
 	const std::vector<CState*> *pStates = CContextManager::Get()->GetAllStates();
-	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); ++iter) {
-		CState* pState = *iter;
-		if (!pState->m_pCommandQueue)
-			continue;
-
-		if (!pState->m_pCommandQueue->Cancel())
-			res = false;
+	for (CState* pState : *pStates) {
+		if( pState->GetRecursiveOperationHandler() ) {
+			pState->GetRecursiveOperationHandler()->StopRecursiveOperation();
+		}
+	
+		if (pState->m_pCommandQueue) {
+			if (!pState->m_pCommandQueue->Quit())
+				res = false;
+		}
 	}
 
 	if (!res) {
@@ -1305,23 +1359,20 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 	}
 
 	CContextControl::_context_controls* controls = m_pContextControl ? m_pContextControl->GetCurrentControls() : 0;
-	if (controls)
-	{
+	if (controls) {
 		COptions::Get()->SetLastServer(controls->pState->GetLastServer());
 		COptions::Get()->SetOption(OPTION_LASTSERVERPATH, controls->pState->GetLastServerPath().GetSafePath());
-		COptions::Get()->SetOption(OPTION_LAST_CONNECTED_SITE, controls->site_bookmarks->path);
+		COptions::Get()->SetOption(OPTION_LAST_CONNECTED_SITE, controls->site_bookmarks ? controls->site_bookmarks->path : wxString());
 	}
 
-	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); ++iter)
-	{
+	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); ++iter) {
 		CState *pState = *iter;
 		pState->DestroyEngine();
 	}
 
 	CSiteManager::ClearIdMap();
 
-	if (controls)
-	{
+	if (controls) {
 		controls->pLocalListView->SaveColumnSettings(OPTION_LOCALFILELIST_COLUMN_WIDTHS, OPTION_LOCALFILELIST_COLUMN_SHOWN, OPTION_LOCALFILELIST_COLUMN_ORDER);
 		controls->pRemoteListView->SaveColumnSettings(OPTION_REMOTEFILELIST_COLUMN_WIDTHS, OPTION_REMOTEFILELIST_COLUMN_SHOWN, OPTION_REMOTEFILELIST_COLUMN_ORDER);
 	}
@@ -1750,7 +1801,6 @@ void CMainFrame::OnFilter(wxCommandEvent& event)
 	CFilterDialog dlg;
 	dlg.Create(this);
 	dlg.ShowModal();
-	CContextManager::Get()->NotifyAllHandlers(STATECHANGE_APPLYFILTER);
 }
 
 #if FZ_MANUALUPDATECHECK
@@ -2090,69 +2140,18 @@ void CMainFrame::ConnectNavigationHandler(wxEvtHandler* handler)
 
 void CMainFrame::OnNavigationKeyEvent(wxNavigationKeyEvent& event)
 {
-	if (wxGetKeyState(WXK_CONTROL))
-	{
+	if (wxGetKeyState(WXK_CONTROL) && event.IsFromTab()) {
 		if (m_pContextControl)
 			m_pContextControl->AdvanceTab(event.GetDirection());
 		return;
 	}
 
-	std::list<wxWindow*> windowOrder;
-	if (m_pQuickconnectBar)
-		windowOrder.push_back(m_pQuickconnectBar);
-	if (m_pStatusView)
-		windowOrder.push_back(m_pStatusView);
-
-	CContextControl::_context_controls* controls = m_pContextControl ? m_pContextControl->GetCurrentControls() : 0;
-	if (controls) {
-		if (COptions::Get()->GetOptionVal(OPTION_FILEPANE_SWAP) == 0) {
-			windowOrder.push_back(controls->pLocalViewHeader);
-			windowOrder.push_back(controls->pLocalTreeView);
-			windowOrder.push_back(controls->pLocalListView);
-			windowOrder.push_back(controls->pRemoteViewHeader);
-			windowOrder.push_back(controls->pRemoteTreeView);
-			windowOrder.push_back(controls->pRemoteListView);
-		}
-		else {
-			windowOrder.push_back(controls->pRemoteViewHeader);
-			windowOrder.push_back(controls->pRemoteTreeView);
-			windowOrder.push_back(controls->pRemoteListView);
-			windowOrder.push_back(controls->pLocalViewHeader);
-			windowOrder.push_back(controls->pLocalTreeView);
-			windowOrder.push_back(controls->pLocalListView);
-		}
-	}
-	windowOrder.push_back(m_pQueuePane);
-
-	std::list<wxWindow*>::iterator iter;
-	for (iter = windowOrder.begin(); iter != windowOrder.end(); ++iter)
-	{
-		if (*iter == event.GetEventObject())
-			break;
-	}
-
-	bool skipFirst;
-	if (iter == windowOrder.end())
-	{
-		iter = windowOrder.begin();
-		skipFirst = false;
-	}
-	else
-		skipFirst = true;
-
-	FocusNextEnabled(windowOrder, iter, skipFirst, event.GetDirection());
-}
-
-void CMainFrame::OnGetFocus(wxFocusEvent& event)
-{
-	wxNavigationKeyEvent evt;
-	OnNavigationKeyEvent(evt);
+	event.Skip();
 }
 
 void CMainFrame::OnChar(wxKeyEvent& event)
 {
-	if (event.GetKeyCode() != WXK_F6)
-	{
+	if (event.GetKeyCode() != WXK_F6) {
 		event.Skip();
 		return;
 	}
@@ -2163,8 +2162,7 @@ void CMainFrame::OnChar(wxKeyEvent& event)
 	if (m_pQuickconnectBar)
 		windowOrder.push_back(m_pQuickconnectBar);
 	CContextControl::_context_controls* controls = m_pContextControl->GetCurrentControls();
-	if (controls)
-	{
+	if (controls) {
 		windowOrder.push_back(controls->pLocalViewHeader);
 		windowOrder.push_back(controls->pRemoteViewHeader);
 	}
@@ -2173,24 +2171,19 @@ void CMainFrame::OnChar(wxKeyEvent& event)
 
 	bool skipFirst = false;
 	std::list<wxWindow*>::iterator iter;
-	if (!focused)
-	{
+	if (!focused) {
 		iter = windowOrder.begin();
 		skipFirst = false;
 	}
-	else
-	{
+	else {
 		wxWindow *parent = focused->GetParent();
-		for (iter = windowOrder.begin(); iter != windowOrder.end(); ++iter)
-		{
-			if (*iter == focused || *iter == parent)
-			{
+		for (iter = windowOrder.begin(); iter != windowOrder.end(); ++iter) {
+			if (*iter == focused || *iter == parent) {
 				skipFirst = true;
 				break;
 			}
 		}
-		if (iter == windowOrder.end())
-		{
+		if (iter == windowOrder.end()) {
 			iter = windowOrder.begin();
 			skipFirst = false;
 		}
@@ -2331,6 +2324,15 @@ void CMainFrame::OnActivate(wxActivateEvent& event)
 	if (!event.GetActive())
 		return;
 
+#ifdef __WXMAC__
+	// wxMac looses focus information if the window becomes inactive.
+	// Restore focus to the previously focused child, otherwise focus ends up
+	// in the quickconnect bar.
+	// Go via ID of the last focused child to avoid issues with window lifetime.
+	if (m_lastFocusedChild != -1)
+		m_winLastFocused = FindWindow(m_lastFocusedChild);
+#endif
+
 	CEditHandler* pEditHandler = CEditHandler::Get();
 	if (pEditHandler)
 		pEditHandler->CheckForModifications(true);
@@ -2803,8 +2805,10 @@ bool CMainFrame::ConnectToServer(const CServer &server, const CServerPath &path
 	}
 
 	CContextControl::_context_controls* controls = m_pContextControl->GetControlsFromState(pState);
-	if (!isReconnect && controls)
+	if (!isReconnect && controls) {
 		controls->site_bookmarks.reset();
+		m_pMenuBar->ClearBookmarks();
+	}
 
 	return pState->Connect(server, path);
 }
@@ -2822,3 +2826,18 @@ void CMainFrame::OnToggleToolBar(wxCommandEvent& event)
 	HandleResize();
 #endif
 }
+
+void CMainFrame::FixTabOrder()
+{
+	if (m_pQuickconnectBar && m_pTopSplitter) {
+		m_pQuickconnectBar->MoveBeforeInTabOrder(m_pTopSplitter);
+	}
+}
+
+#ifdef __WXMAC__
+void CMainFrame::OnChildFocused(wxChildFocusEvent& event)
+{
+	m_lastFocusedChild = event.GetWindow()->GetId();
+}
+#endif
+
