@@ -1,6 +1,8 @@
 #ifndef __OPTIONS_H__
 #define __OPTIONS_H__
 
+#include "local_path.h"
+
 enum interfaceOptions
 {
 	OPTION_NUMTRANSFERS = OPTIONS_ENGINE_NUM,
@@ -31,6 +33,7 @@ enum interfaceOptions
 	OPTION_FILEPANE_SWAP,
 	OPTION_LASTLOCALDIR,
 	OPTION_FILELIST_DIRSORT,
+	OPTION_FILELIST_NAMESORT,
 	OPTION_QUEUE_SUCCESSFUL_AUTOCLEAR,
 	OPTION_QUEUE_COLUMN_WIDTHS,
 	OPTION_LOCALFILELIST_COLUMN_WIDTHS,
@@ -85,7 +88,7 @@ enum interfaceOptions
 	OPTION_PROMPTPASSWORDSAVE,
 
 	// Default/internal options
-	OPTION_DEFAULT_SETTINGSDIR,
+	OPTION_DEFAULT_SETTINGSDIR, // guaranteed to be (back)slash-terminated
 	OPTION_DEFAULT_KIOSKMODE,
 	OPTION_DEFAULT_DISABLEUPDATECHECK,
 
@@ -95,6 +98,11 @@ enum interfaceOptions
 
 struct t_OptionsCache
 {
+	bool operator==(wxString const& v) const { return strValue == v; }
+	bool operator==(int v) const { return numValue == v; }
+	t_OptionsCache& operator=(wxString const& v) { strValue = v; return *this; }
+	t_OptionsCache& operator=(int v) { numValue = v; return *this; }
+
 	bool from_default;
 	int numValue;
 	wxString strValue;
@@ -109,7 +117,7 @@ public:
 	virtual wxString GetOption(unsigned int nID);
 
 	virtual bool SetOption(unsigned int nID, int value);
-	virtual bool SetOption(unsigned int nID, wxString value);
+	virtual bool SetOption(unsigned int nID, wxString const& value);
 
 	bool OptionFromFzDefaultsXml(unsigned int nID);
 
@@ -124,26 +132,30 @@ public:
 
 	void SaveIfNeeded();
 
+	static CLocalPath GetUnadjustedSettingsDir();
+
 protected:
 	COptions();
 	virtual ~COptions();
 
 	int Validate(unsigned int nID, int value);
-	wxString Validate(unsigned int nID, wxString value);
+	wxString Validate(unsigned int nID, wxString const& value);
 
-	void SetXmlValue(unsigned int nID, wxString value);
+	template<typename T> void ContinueSetOption(unsigned int nID, T const& value);
+	void SetXmlValue(unsigned int nID, int value);
+	void SetXmlValue(unsigned int nID, wxString const& value);
 
 	// path is element path below document root, separated by slashes
 	void SetServer(wxString path, const CServer& server);
 	bool GetServer(wxString path, CServer& server);
 
-	void CreateSettingsXmlElement();
+	TiXmlElement* CreateSettingsXmlElement();
 
-	void GetNameOptionMap(std::map<std::string, int>& nameOptionMap) const; //Give me C++1x
-	void LoadOptions(const std::map<std::string, int>& nameOptionMap, TiXmlElement* settings = 0);
-	void LoadGlobalDefaultOptions(const std::map<std::string, int>& nameOptionMap);
-	void LoadOptionFromElement(TiXmlElement* pOption, const std::map<std::string, int>& nameOptionMap, bool allowDefault);
-	void InitSettingsDir();
+	std::map<std::string, int> GetNameOptionMap() const;
+	void LoadOptions(std::map<std::string, int> const& nameOptionMap, TiXmlElement* settings = 0);
+	void LoadGlobalDefaultOptions(std::map<std::string, int> const& nameOptionMap);
+	void LoadOptionFromElement(TiXmlElement* pOption, std::map<std::string, int> const& nameOptionMap, bool allowDefault);
+	CLocalPath InitSettingsDir();
 	void SetDefaultValues();
 
 	void Save();
@@ -151,7 +163,6 @@ protected:
 	CXmlFile* m_pXmlFile;
 
 	t_OptionsCache m_optionsCache[OPTIONS_NUM];
-	bool m_acquired;
 
 	CServer* m_pLastServer;
 
