@@ -5,6 +5,7 @@
 #include "queue.h"
 
 #include <libfilezilla.h>
+#include <option_change_event_handler.h>
 
 #include <set>
 #include <wx/progdlg.h>
@@ -22,6 +23,7 @@ public:
 	const enum t_type m_type;
 
 	CFolderProcessingEntry(enum t_type type) : m_type(type) {}
+	virtual ~CFolderProcessingEntry() {}
 };
 
 class t_newEntry : public CFolderProcessingEntry
@@ -35,7 +37,7 @@ public:
 
 	wxString name;
 	wxLongLong size;
-	wxDateTime time;
+	CDateTime time;
 	int attributes;
 	bool dir;
 };
@@ -48,11 +50,12 @@ enum ActionAfterState
 	ActionAfterState_RunCommand,
 	ActionAfterState_ShowMessage,
 	ActionAfterState_PlaySound
-// On Windows, wx can reboot or shutdown the system as well.
-#ifdef __WXMSW__
+// On Windows and OS X, wx can reboot or shutdown the system as well.
+#if defined(__WXMSW__) || defined(__WXMAC__)
 	,
 	ActionAfterState_Reboot,
-	ActionAfterState_Shutdown
+	ActionAfterState_Shutdown,
+	ActionAfterState_Sleep
 #endif
 };
 
@@ -111,7 +114,7 @@ class CQueue;
 class CDesktopNotification;
 #endif
 
-class CQueueView : public CQueueViewBase
+class CQueueView : public CQueueViewBase, public COptionChangeEventHandler
 {
 	friend class CFolderProcessingThread;
 	friend class CQueueViewDropTarget;
@@ -124,25 +127,21 @@ public:
 		const wxString& localFile, const wxString& remoteFile,
 		const CLocalPath& localPath, const CServerPath& remotePath,
 		const CServer& server, const wxLongLong size, enum CEditHandler::fileType edit = CEditHandler::none,
-		QueuePriority priority = priority_normal);
+		QueuePriority priority = QueuePriority::normal);
 
 	void QueueFile_Finish(const bool start); // Need to be called after QueueFile
 	bool QueueFiles(const bool queueOnly, const CLocalPath& localPath, const CRemoteDataObject& dataObject);
-	int QueueFiles(const std::list<CFolderProcessingEntry*> &entryList, bool queueOnly, bool download, CServerItem* pServerItem, const enum CFileExistsNotification::OverwriteAction defaultFileExistsAction);
+	int QueueFiles(const std::list<CFolderProcessingEntry*> &entryList, bool queueOnly, bool download, CServerItem* pServerItem, const CFileExistsNotification::OverwriteAction defaultFileExistsAction);
 	bool QueueFolder(bool queueOnly, bool download, const CLocalPath& localPath, const CServerPath& remotePath, const CServer& server);
 
-	bool IsEmpty() const;
+	bool empty() const;
 	int IsActive() const { return m_activeMode; }
 	bool SetActive(bool active = true);
 	bool Quit();
 
-	// If the settings are changed, this function will recalculate some
-	// data like the list of ascii file types
-	void SettingsChanged();
-
 	// This sets the default file exists action for all files currently in queue.
 	// This includes queued folders which are yet to be processed
-	void SetDefaultFileExistsAction(enum CFileExistsNotification::OverwriteAction action, const enum TransferDirection direction);
+	void SetDefaultFileExistsAction(CFileExistsNotification::OverwriteAction action, const TransferDirection direction);
 
 	void UpdateItemSize(CFileItem* pItem, wxLongLong size);
 
@@ -178,6 +177,8 @@ protected:
 	WXLRESULT MSWWindowProc(WXUINT nMsg, WXWPARAM wParam, WXLPARAM lParam);
 #endif
 
+	virtual void OnOptionChanged(int option);
+
 	void AdvanceQueue(bool refresh = true);
 	bool TryStartNextTransfer();
 
@@ -221,8 +222,8 @@ protected:
 
 	bool IsActionAfter(enum ActionAfterState);
 	void ActionAfter(bool warned = false);
-#ifdef __WXMSW__
-	void ActionAfterWarnUser(bool shutdown);
+#if defined(__WXMSW__) || defined(__WXMAC__)
+	void ActionAfterWarnUser(ActionAfterState s);
 #endif
 
 	void ProcessNotification(t_EngineData* pEngineData, CNotification* pNotification);
@@ -233,7 +234,7 @@ protected:
 	void TryRefreshListings();
 	CServer m_last_refresh_server;
 	CServerPath m_last_refresh_path;
-	CTimeEx m_last_refresh_listing_time;
+	CMonotonicTime m_last_refresh_listing_time;
 
 	// Called from Process Reply.
 	// After a disconnect, check if there's another idle engine that
@@ -277,7 +278,7 @@ protected:
 
 	enum ActionAfterState m_actionAfterState;
 	wxString m_actionAfterRunCommand;
-#ifdef __WXMSW__
+#if defined(__WXMSW__) || defined(__WXMAC__)
 	wxTimer* m_actionAfterTimer;
 	wxProgressDialog* m_actionAfterWarnDialog;
 	int m_actionAfterTimerCount;
