@@ -312,6 +312,7 @@ public:
 
 	wxSize GetTextSize() const { return m_textSize; }
 
+	bool AcceptsFocus() const { return false; }
 protected:
 	wxString m_text;
 
@@ -874,14 +875,12 @@ void CRemoteListView::SetDirectoryListing(std::shared_ptr<CDirectoryListing> con
 
 	SortList(-1, -1, false);
 
-	if (IsComparing())
-	{
+	if (IsComparing()) {
 		m_originalIndexMapping.clear();
 		RefreshComparison();
 		ReselectItems(selectedNames, prevFocused, ensureVisible);
 	}
-	else
-	{
+	else {
 		ReselectItems(selectedNames, prevFocused, ensureVisible);
 		RefreshListOnly(eraseBackground);
 	}
@@ -1341,7 +1340,7 @@ void CRemoteListView::OnMenuMkdirChgDir(wxCommandEvent&)
 {
 	CServerPath newdir = MenuMkdir();
 	if (!newdir.empty()) {
-		m_pState->ChangeRemoteDir(newdir);
+		m_pState->ChangeRemoteDir(newdir, wxString(), 0, true);
 	}
 }
 
@@ -1526,28 +1525,29 @@ void CRemoteListView::OnMenuDelete(wxCommandEvent&)
 
 void CRemoteListView::OnMenuRename(wxCommandEvent&)
 {
-	if (!m_pState->IsRemoteIdle())
-	{
+	if (GetEditControl()) {
+		GetEditControl()->SetFocus();
+		return;
+	}
+
+	if (!m_pState->IsRemoteIdle()) {
 		wxBell();
 		return;
 	}
 
 	int item = GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-	if (item <= 0)
-	{
+	if (item <= 0) {
 		wxBell();
 		return;
 	}
 
-	if (GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED) != -1)
-	{
+	if (GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED) != -1) {
 		wxBell();
 		return;
 	}
 
 	int index = GetItemIndex(item);
-	if (index == -1 || m_fileData[index].comparison_flags == fill)
-	{
+	if (index == -1 || m_fileData[index].comparison_flags == fill) {
 		wxBell();
 		return;
 	}
@@ -2862,16 +2862,13 @@ void CRemoteListView::OnMenuRefresh(wxCommandEvent&)
 
 void CRemoteListView::OnNavigationEvent(bool forward)
 {
-	if (!forward)
-	{
-		if (!m_pState->IsRemoteIdle())
-		{
+	if (!forward) {
+		if (!m_pState->IsRemoteIdle()) {
 			wxBell();
 			return;
 		}
 
-		if (!m_pDirectoryListing)
-		{
+		if (!m_pDirectoryListing) {
 			wxBell();
 			return;
 		}
