@@ -221,9 +221,6 @@ EVT_TREE_ITEM_EXPANDING(wxID_ANY, CRemoteTreeView::OnItemExpanding)
 EVT_TREE_SEL_CHANGED(wxID_ANY, CRemoteTreeView::OnSelectionChanged)
 EVT_TREE_ITEM_ACTIVATED(wxID_ANY, CRemoteTreeView::OnItemActivated)
 EVT_TREE_BEGIN_DRAG(wxID_ANY, CRemoteTreeView::OnBeginDrag)
-#ifndef __WXMSW__
-EVT_KEY_DOWN(CRemoteTreeView::OnKeyDown)
-#endif //__WXMSW__
 EVT_TREE_ITEM_MENU(wxID_ANY, CRemoteTreeView::OnContextMenu)
 EVT_MENU(XRCID("ID_CHMOD"), CRemoteTreeView::OnMenuChmod)
 EVT_MENU(XRCID("ID_DOWNLOAD"), CRemoteTreeView::OnMenuDownload)
@@ -316,9 +313,11 @@ void CRemoteTreeView::SetDirectoryListing(std::shared_ptr<CDirectoryListing> con
 		return;
 	}
 	Enable(true);
+#ifdef __WXGTK__
+	GetParent()->m_dirtyTabOrder = true;
+#endif
 
-	if (pListing->get_unsure_flags() && !(pListing->get_unsure_flags() & ~(CDirectoryListing::unsure_unknown | CDirectoryListing::unsure_file_mask)))
-	{
+	if (pListing->get_unsure_flags() && !(pListing->get_unsure_flags() & ~(CDirectoryListing::unsure_unknown | CDirectoryListing::unsure_file_mask))) {
 		// Just files changed, does not affect directory tree
 		m_busy = false;
 		return;
@@ -925,24 +924,6 @@ void CRemoteTreeView::OnBeginDrag(wxTreeEvent& event)
 #endif
 }
 
-#ifndef __WXMSW__
-void CRemoteTreeView::OnKeyDown(wxKeyEvent& event)
-{
-	if (event.GetKeyCode() != WXK_TAB)
-	{
-		event.Skip();
-		return;
-	}
-
-	wxNavigationKeyEvent navEvent;
-	navEvent.SetEventObject(this);
-	navEvent.SetDirection(!event.ShiftDown());
-	navEvent.SetFromTab(true);
-	navEvent.ResumePropagation(1);
-	ProcessEvent(navEvent);
-}
-#endif
-
 void CRemoteTreeView::OnContextMenu(wxTreeEvent& event)
 {
 	m_contextMenuItem = event.GetItem();
@@ -1401,8 +1382,7 @@ void CRemoteTreeView::ApplyFilters()
 
 	const wxTreeItemId root = GetRootItem();
 	wxTreeItemIdValue cookie;
-	for (wxTreeItemId child = GetFirstChild(root, cookie); child; child = GetNextSibling(child))
-	{
+	for (wxTreeItemId child = GetFirstChild(root, cookie); child; child = GetNextSibling(child)) {
 		CServerPath path = GetPathFromItem(child);
 		if (path.empty())
 			continue;
@@ -1414,29 +1394,24 @@ void CRemoteTreeView::ApplyFilters()
 	}
 
 	CFilterManager filter;
-	while (!parents.empty())
-	{
+	while (!parents.empty()) {
 		struct _parents parent = parents.back();
 		parents.pop_back();
 
 		CDirectoryListing listing;
 		if (m_pState->m_pEngine->CacheLookup(parent.path, listing) == FZ_REPLY_OK)
 			RefreshItem(parent.item, listing, false);
-		else if (filter.HasActiveFilters())
-		{
-			for (wxTreeItemId child = GetFirstChild(parent.item, cookie); child; child = GetNextSibling(child))
-			{
+		else if (filter.HasActiveFilters()) {
+			for (wxTreeItemId child = GetFirstChild(parent.item, cookie); child; child = GetNextSibling(child)) {
 				CServerPath path = GetPathFromItem(child);
 				if (path.empty())
 					continue;
 
-				if (filter.FilenameFiltered(GetItemText(child), path.GetPath(), true, -1, false, 0, CDateTime()))
-				{
+				if (filter.FilenameFiltered(GetItemText(child), path.GetPath(), true, -1, false, 0, CDateTime())) {
 					wxTreeItemId sel = GetSelection();
 					while (sel && sel != child)
 						sel = GetItemParent(sel);
-					if (!sel)
-					{
+					if (!sel) {
 						Delete(child);
 						continue;
 					}
@@ -1451,8 +1426,7 @@ void CRemoteTreeView::ApplyFilters()
 			// The stuff below has already been done above in this one case
 			continue;
 		}
-		for (wxTreeItemId child = GetFirstChild(parent.item, cookie); child; child = GetNextSibling(child))
-		{
+		for (wxTreeItemId child = GetFirstChild(parent.item, cookie); child; child = GetNextSibling(child)) {
 			CServerPath path = GetPathFromItem(child);
 			if (path.empty())
 				continue;
