@@ -59,9 +59,6 @@ protected:
 	void OnSelectionChanged(wxTreeEvent& event);
 	void OnItemActivated(wxTreeEvent& event);
 	void OnBeginDrag(wxTreeEvent& event);
-#ifndef __WXMSW__
-	void OnKeyDown(wxKeyEvent& event);
-#endif
 	void OnContextMenu(wxTreeEvent& event);
 	void OnMenuChmod(wxCommandEvent&);
 	void OnMenuDownload(wxCommandEvent& event);
