@@ -18,14 +18,14 @@ bool CAboutDialog::Create(wxWindow* parent)
 	if (!Load(parent, _T("ID_ABOUT")))
 		return false;
 
-	XRCCTRL(*this, "ID_URL", wxHyperlinkCtrl)->SetLabel(_T("https://filezilla-project.org"));
+	XRCCTRL(*this, "ID_URL", wxHyperlinkCtrl)->SetLabel(_T("https://filezilla-project.org/"));
 
-	XRCCTRL(*this, "ID_COPYRIGHT", wxStaticText)->SetLabel(_T("Copyright (C) 2004-2013  Tim Kosse"));
+	XRCCTRL(*this, "ID_COPYRIGHT", wxStaticText)->SetLabel(_T("Copyright (C) 2004-2014  Tim Kosse"));
 
 	wxString version = CBuildInfo::GetVersion();
 	if (CBuildInfo::GetBuildType() == _T("nightly"))
 		version += _T("-nightly");
-	if (!SetLabel(XRCID("ID_VERSION"), version))
+	if (!SetChildLabel(XRCID("ID_VERSION"), version))
 		return false;
 
 	wxStaticText* pHost = XRCCTRL(*this, "ID_HOST", wxStaticText);
@@ -37,7 +37,7 @@ bool CAboutDialog::Create(wxWindow* parent)
 		return false;
 
 	wxString host = CBuildInfo::GetHostname();
-	if (host == _T(""))
+	if (host.empty())
 	{
 		pHost->Hide();
 		pHostDesc->Hide();
@@ -54,7 +54,7 @@ bool CAboutDialog::Create(wxWindow* parent)
 		return false;
 
 	wxString build = CBuildInfo::GetBuildSystem();
-	if (build == _T(""))
+	if (build.empty())
 	{
 		pBuild->Hide();
 		pBuildDesc->Hide();
@@ -62,10 +62,10 @@ bool CAboutDialog::Create(wxWindow* parent)
 	else
 		pBuild->SetLabel(build);
 
-	if (!SetLabel(XRCID("ID_BUILDDATE"), CBuildInfo::GetBuildDateString()))
+	if (!SetChildLabel(XRCID("ID_BUILDDATE"), CBuildInfo::GetBuildDateString()))
 		return false;
 
-	if (!SetLabel(XRCID("ID_COMPILEDWITH"), CBuildInfo::GetCompiler(), 200))
+	if (!SetChildLabel(XRCID("ID_COMPILEDWITH"), CBuildInfo::GetCompiler(), 200))
 		return false;
 
 	wxStaticText* pCompilerFlags = XRCCTRL(*this, "ID_CFLAGS", wxStaticText);
@@ -77,7 +77,7 @@ bool CAboutDialog::Create(wxWindow* parent)
 		return false;
 
 	wxString compilerFlags = CBuildInfo::GetCompilerFlags();
-	if (compilerFlags == _T(""))
+	if (compilerFlags.empty())
 	{
 		pCompilerFlags->Hide();
 		pCompilerFlagsDesc->Hide();
@@ -126,9 +126,15 @@ bool CAboutDialog::Create(wxWindow* parent)
 		return false;
 
 	int major, minor;
-	if (wxGetOsVersion(&major, &minor) != wxOS_UNKNOWN)
+	if (GetRealOsVersion(major, minor))
 	{
 		wxString version = wxString::Format(_T("%d.%d"), major, minor);
+		int fakeMajor, fakeMinor;
+		if (wxGetOsVersion(&fakeMajor, &fakeMinor) != wxOS_UNKNOWN && (fakeMajor != major || fakeMinor != minor))
+		{
+			version += _T(" ");
+			version += wxString::Format(_("(app-compat is set to %d.%d)"), fakeMajor, fakeMinor);
+		}
 		pSystemVersion->SetLabel(version);
 	}
 	else
@@ -161,12 +167,12 @@ bool CAboutDialog::Create(wxWindow* parent)
 	return true;
 }
 
-void CAboutDialog::OnOK(wxCommandEvent& event)
+void CAboutDialog::OnOK(wxCommandEvent&)
 {
 	EndModal(wxID_OK);
 }
 
-void CAboutDialog::OnCopy(wxCommandEvent& event)
+void CAboutDialog::OnCopy(wxCommandEvent&)
 {
 	wxString text = _T("FileZilla Client\n");
 	text += _T("----------------\n\n");
@@ -198,8 +204,8 @@ void CAboutDialog::OnCopy(wxCommandEvent& event)
 	for (int i = 0; i < dependency::count; ++i)
 	{
 		text += wxString::Format(_T("  % -15s %s\n"),
-			(GetDependencyName(dependency::type(i)) + _T(":")).c_str(),
-			GetDependencyVersion(dependency::type(i)).c_str());
+			(GetDependencyName(dependency::type(i)) + _T(":")),
+			GetDependencyVersion(dependency::type(i)));
 	}
 
 	text += _T("\nOperating system:\n");
@@ -208,8 +214,17 @@ void CAboutDialog::OnCopy(wxCommandEvent& event)
 		text += _T("  Name:           ") + os + _T("\n");
 
 	int major, minor;
-	if (wxGetOsVersion(&major, &minor) != wxOS_UNKNOWN)
-		text += wxString::Format(_T("  Version:        %d.%d\n"), major, minor);
+	if (GetRealOsVersion(major, minor))
+	{
+		wxString version = wxString::Format(_T("%d.%d"), major, minor);
+		int fakeMajor, fakeMinor;
+		if (wxGetOsVersion(&fakeMajor, &fakeMinor) != wxOS_UNKNOWN && (fakeMajor != major || fakeMinor != minor))
+		{
+			version += _T(" ");
+			version += wxString::Format(_("(app-compat is set to %d.%d)"), fakeMajor, fakeMinor);
+		}
+		text += wxString::Format(_T("  Version:        %s\n"), version);
+	}
 
 #if defined(__WXMSW__)
 	if (::wxIsPlatform64Bit())
@@ -224,7 +239,7 @@ void CAboutDialog::OnCopy(wxCommandEvent& event)
 
 	if (!wxTheClipboard->Open())
 	{
-		wxMessageBox(_("Could not open clipboard"), _("Could not copy data"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("Could not open clipboard"), _("Could not copy data"), wxICON_EXCLAMATION);
 		return;
 	}
 
