@@ -439,9 +439,8 @@ bool CAsyncRequestQueue::CheckWindowState()
 {
 	m_timer.Stop();
 	wxMouseState mouseState = wxGetMouseState();
-	if (mouseState.LeftIsDown() || mouseState.MiddleIsDown() || mouseState.RightIsDown())
-	{
-		m_timer.Start(1000, true);
+	if (mouseState.LeftIsDown() || mouseState.MiddleIsDown() || mouseState.RightIsDown()) {
+		m_timer.Start(100, true);
 		return false;
 	}
 
