@@ -9,7 +9,7 @@ class CClearPrivateDataDialog : public wxDialogEx
 public:
 
 	static CClearPrivateDataDialog* Create(CMainFrame* pMainFrame) { return new CClearPrivateDataDialog(pMainFrame); }
-	void Show();
+	void Run();
 
 	void Delete();
 
@@ -25,7 +25,7 @@ protected:
 
 	wxTimer m_timer;
 
-	DECLARE_EVENT_TABLE();
+	DECLARE_EVENT_TABLE()
 	void OnTimer(wxTimerEvent& event);
 };
 
