@@ -59,10 +59,10 @@ wxString CCommandLine::GetOption(enum CCommandLine::t_option option) const
 	case local:
 		if (m_parser.Found(_T("a"), &value))
 			return value;
-		break;		
+		break;
 	}
 
-	return _T("");
+	return wxString();
 }
 
 bool CCommandLine::Parse()
@@ -71,36 +71,36 @@ bool CCommandLine::Parse()
 	if (res != 0)
 		return false;
 
-	if (HasSwitch(sitemanager) && GetOption(site) != _T(""))
+	if (HasSwitch(sitemanager) && !GetOption(site).empty())
 	{
-		wxMessageBox(_("-s and -c cannot be present at the same time."), _("Syntax error in command line"));
+		wxMessageBoxEx(_("-s and -c cannot be present at the same time."), _("Syntax error in command line"));
 		return false;
 	}
 
 	if (HasSwitch(sitemanager) && m_parser.GetParamCount())
 	{
-		wxMessageBox(_("-s cannot be used together with an FTP URL."), _("Syntax error in command line"));
+		wxMessageBoxEx(_("-s cannot be used together with an FTP URL."), _("Syntax error in command line"));
 		return false;
 	}
 
-	if (GetOption(site) != _T("") && m_parser.GetParamCount())
+	if (!GetOption(site).empty() && m_parser.GetParamCount())
 	{
-		wxMessageBox(_("-c cannot be used together with an FTP URL."), _("Syntax error in command line"));
+		wxMessageBoxEx(_("-c cannot be used together with an FTP URL."), _("Syntax error in command line"));
 		return false;
 	}
 
 	wxString type = GetOption(logontype);
-	if (type != _T(""))
+	if (!type.empty())
 	{
 		if (!m_parser.GetParamCount())
 		{
-			wxMessageBox(_("-l can only be used together with an FTP URL."), _("Syntax error in command line"));
+			wxMessageBoxEx(_("-l can only be used together with an FTP URL."), _("Syntax error in command line"));
 			return false;
 		}
 
 		if (type != _T("ask") && type != _T("interactive"))
 		{
-			wxMessageBox(_("Logontype has to be either 'ask' or 'interactive' (without the quotes)."), _("Syntax error in command line"));
+			wxMessageBoxEx(_("Logontype has to be either 'ask' or 'interactive' (without the quotes)."), _("Syntax error in command line"));
 			return false;
 		}
 	}
@@ -119,7 +119,7 @@ void CCommandLine::DisplayUsage()
 wxString CCommandLine::GetParameter() const
 {
 	if (!m_parser.GetParamCount())
-		return _T("");
+		return wxString();
 
 	return m_parser.GetParam();
 }
