@@ -77,7 +77,7 @@ public:
 		wxString name; // The name of the file
 		wxString file; // The actual local filename
 		fileState state;
-		wxDateTime modificationTime;
+		CDateTime modificationTime;
 		CServerPath remotePath;
 		CServer server;
 	};
@@ -90,7 +90,6 @@ public:
 	// Returns command to open the file. If association is set but
 	// program does not exist, program_exists is set to false.
 	wxString GetOpenCommand(const wxString& file, bool& program_exists);
-	wxString GetSystemOpenCommand(wxString file, bool &program_exists);
 
 protected:
 	CEditHandler();
@@ -169,7 +168,7 @@ class CNewAssociationDialog : protected wxDialogEx
 public:
 	CNewAssociationDialog(wxWindow* parent);
 
-	bool Show(const wxString& file);
+	bool Run(const wxString& file);
 
 protected:
 	void SetCtrlState();
