@@ -128,9 +128,8 @@ protected:
 	void SetCtrlState();
 
 	DECLARE_EVENT_TABLE()
-	void OnOK(wxCommandEvent& event);
+	void OnOkOrApply(wxCommandEvent& event);
 	void OnCancel(wxCommandEvent& event);
-	void OnApply(wxCommandEvent& event);
 	void OnEdit(wxCommandEvent& event);
 	void OnFilterSelect(wxCommandEvent& event);
 	void OnMouseEvent(wxMouseEvent& event);
