@@ -85,7 +85,7 @@ bool CFilterConditionsDialog::CreateListControl(int conditions /*=common*/)
 	ReplaceControl(wnd, m_pListCtrl);
 	CalcMinListWidth();
 
-	if (stringConditionTypes.IsEmpty())
+	if (stringConditionTypes.empty())
 	{
 		stringConditionTypes.Add(_("contains"));
 		stringConditionTypes.Add(_("is equal to"));
@@ -479,6 +479,8 @@ void CFilterConditionsDialog::MakeControls(const CFilterCondition& condition, in
 	{
 		delete controls.pValue;
 		controls.pValue = 0;
+		delete controls.pLabel;
+		controls.pLabel = 0;
 
 		pos = wxPoint(posx, posy);
 		wxSize size(maxwidth, -1);
@@ -601,13 +603,13 @@ CFilter CFilterConditionsDialog::GetFilter()
 		{
 		case filter_name:
 		case filter_path:
-			if (controls.pValue->GetValue() == _T(""))
+			if (controls.pValue->GetValue().empty())
 				continue;
 			condition.strValue = controls.pValue->GetValue();
 			break;
 		case filter_size:
 			{
-				if (controls.pValue->GetValue() == _T(""))
+				if (controls.pValue->GetValue().empty())
 					continue;
 				condition.strValue = controls.pValue->GetValue();
 				unsigned long tmp;
@@ -629,11 +631,15 @@ CFilter CFilterConditionsDialog::GetFilter()
 			}
 			break;
 		case filter_date:
-			if (controls.pValue->GetValue() == _T(""))
-				continue;
-			condition.strValue = controls.pValue->GetValue();
-			if (!condition.date.ParseFormat(condition.strValue, _T("%Y-%m-%d")) || !condition.date.IsValid())
+			if (controls.pValue->GetValue().empty())
 				continue;
+			else {
+				condition.strValue = controls.pValue->GetValue();
+				wxDateTime t;
+				if (!t.ParseFormat(condition.strValue, _T("%Y-%m-%d")) || !t.IsValid())
+					continue;
+				condition.date = CDateTime(t, CDateTime::days);
+			}
 			break;
 		default:
 			wxFAIL_MSG(_T("Unhandled condition"));
@@ -695,7 +701,7 @@ bool CFilterConditionsDialog::ValidateFilter(wxString& error, bool allow_empty /
 		const CFilterControls& controls = m_filterControls[i];
 		enum t_filterType type = GetTypeFromTypeSelection(controls.pType->GetSelection());
 
-		if ((type == filter_name || type == filter_path) && controls.pValue->GetValue() == _T(""))
+		if ((type == filter_name || type == filter_path) && controls.pValue->GetValue().empty())
 		{
 			if (allow_empty)
 				continue;
@@ -709,7 +715,7 @@ bool CFilterConditionsDialog::ValidateFilter(wxString& error, bool allow_empty /
 		else if (type == filter_size)
 		{
 			const wxString v = controls.pValue->GetValue();
-			if (v == _T("") && allow_empty)
+			if (v.empty() && allow_empty)
 				continue;
 
 			long number;
@@ -725,7 +731,7 @@ bool CFilterConditionsDialog::ValidateFilter(wxString& error, bool allow_empty /
 		else if (type == filter_date)
 		{
 			const wxString d = controls.pValue->GetValue();
-			if (d == _T("") && allow_empty)
+			if (d.empty() && allow_empty)
 				continue;
 
 			wxDateTime date;
@@ -800,7 +806,7 @@ void CFilterConditionsDialog::OnNavigationKeyEvent(wxNavigationKeyEvent& event)
 			{
 				target = m_filterControls[i].pValue;
 				if (!target)
-					m_filterControls[i].pSet;
+					target = m_filterControls[i].pSet;
 				break;
 			}
 			if (m_filterControls[i].pSet == source || m_filterControls[i].pValue == source)
@@ -851,7 +857,7 @@ void CFilterConditionsDialog::OnNavigationKeyEvent(wxNavigationKeyEvent& event)
 				{
 					target = m_filterControls[i].pValue;
 					if (!target)
-						m_filterControls[i].pSet;
+						target = m_filterControls[i].pSet;
 					break;
 				}
 			}
