@@ -21,7 +21,7 @@ public:
 
 protected:
 
-	DECLARE_EVENT_TABLE();
+	DECLARE_EVENT_TABLE()
 	void OnOK(wxCommandEvent& event);
 	void OnCancel(wxCommandEvent& event);
 	void OnNew(wxCommandEvent& event);
