@@ -1,4 +1,5 @@
 #include <filezilla.h>
+#include "filezillaapp.h"
 #include "import.h"
 #include "xmlfunctions.h"
 #include "ipcmutex.h"
@@ -10,10 +11,10 @@ CImportDialog::CImportDialog(wxWindow* parent, CQueueView* pQueueView)
 {
 }
 
-void CImportDialog::Show()
+void CImportDialog::Run()
 {
-	wxFileDialog dlg(m_parent, _("Select file to import settings from"), _T(""), 
-					_T("FileZilla.xml"), _T("XML files (*.xml)|*.xml"), 
+	wxFileDialog dlg(m_parent, _("Select file to import settings from"), wxString(),
+					_T("FileZilla.xml"), _T("XML files (*.xml)|*.xml"),
 					wxFD_OPEN | wxFD_FILE_MUST_EXIST);
 	dlg.CenterOnParent();
 
@@ -21,35 +22,21 @@ void CImportDialog::Show()
 		return;
 
 	wxFileName fn(dlg.GetPath());
-	const wxString& path = fn.GetPath();
-	const wxString& settings(COptions::Get()->GetOption(OPTION_DEFAULT_SETTINGSDIR));
-	if (path == settings)
-	{
-		wxMessageBox(_("You cannot import settings from FileZilla's own settings directory."), _("Error importing"), wxICON_ERROR, m_parent);
+	wxString const path = fn.GetPath();
+	wxString const settings(COptions::Get()->GetOption(OPTION_DEFAULT_SETTINGSDIR));
+	if (path == settings) {
+		wxMessageBoxEx(_("You cannot import settings from FileZilla's own settings directory."), _("Error importing"), wxICON_ERROR, m_parent);
 		return;
 	}
 
-	TiXmlDocument* xmlDocument = new TiXmlDocument();
-	xmlDocument->SetCondenseWhiteSpace(false);
-
-	if (!LoadXmlDocument(xmlDocument, dlg.GetPath()))
-	{
-		delete xmlDocument;
-		wxMessageBox(_("Cannot load file, not a valid XML file."), _("Error importing"), wxICON_ERROR, m_parent);
-		return;
-	}
-
-	TiXmlElement* fz3Root = xmlDocument->FirstChildElement("FileZilla3");
-	TiXmlElement* fz2Root = xmlDocument->FirstChildElement("FileZilla");
-
-	if (fz3Root)
-	{
+	CXmlFile fz3(dlg.GetPath());
+	TiXmlElement* fz3Root = fz3.Load();
+	if (fz3Root) {
 		bool settings = fz3Root->FirstChildElement("Settings") != 0;
 		bool queue = fz3Root->FirstChildElement("Queue") != 0;
 		bool sites = fz3Root->FirstChildElement("Servers") != 0;
 
-		if (settings || queue || sites)
-		{
+		if (settings || queue || sites) {
 			Load(m_parent, _T("ID_IMPORT"));
 			if (!queue)
 				XRCCTRL(*this, "ID_QUEUE", wxCheckBox)->Hide();
@@ -57,67 +44,56 @@ void CImportDialog::Show()
 				XRCCTRL(*this, "ID_SITEMANAGER", wxCheckBox)->Hide();
 			if (!settings)
 				XRCCTRL(*this, "ID_SETTINGS", wxCheckBox)->Hide();
-			Fit();
+			GetSizer()->Fit(this);
 
-			if (ShowModal() != wxID_OK)
-			{
-				delete xmlDocument;
+			if (ShowModal() != wxID_OK) {
 				return;
 			}
 
-			if (queue && XRCCTRL(*this, "ID_QUEUE", wxCheckBox)->IsChecked())
-			{
+			if (queue && XRCCTRL(*this, "ID_QUEUE", wxCheckBox)->IsChecked()) {
 				m_pQueueView->ImportQueue(fz3Root->FirstChildElement("Queue"), true);
 			}
 
-			if (sites && XRCCTRL(*this, "ID_SITEMANAGER", wxCheckBox)->IsChecked())
-			{
+			if (sites && XRCCTRL(*this, "ID_SITEMANAGER", wxCheckBox)->IsChecked()) {
 				ImportSites(fz3Root->FirstChildElement("Servers"));
 			}
 
-			if (settings && XRCCTRL(*this, "ID_SETTINGS", wxCheckBox)->IsChecked())
-			{
+			if (settings && XRCCTRL(*this, "ID_SETTINGS", wxCheckBox)->IsChecked()) {
 				COptions::Get()->Import(fz3Root->FirstChildElement("Settings"));
-				wxMessageBox(_("The settings have been imported. You have to restart FileZilla for all settings to have effect."), _("Import successful"), wxOK, this);
+				wxMessageBoxEx(_("The settings have been imported. You have to restart FileZilla for all settings to have effect."), _("Import successful"), wxOK, this);
 			}
-			
-			wxMessageBox(_("The selected categories have been imported."), _("Import successful"), wxOK, this);
 
-			delete xmlDocument;
+			wxMessageBoxEx(_("The selected categories have been imported."), _("Import successful"), wxOK, this);
 			return;
 		}
 	}
-	else if (fz2Root)
-	{
-		bool sites_fz2 = fz2Root->FirstChildElement("Sites") != 0;
-		if (sites_fz2)
-		{
-			int res = wxMessageBox(_("The file you have selected contains site manager data from a previous version of FileZilla.\nDue to differences in the storage format, only host, port, username and password will be imported.\nContinue with the import?"),
+
+	CXmlFile fz2(dlg.GetPath(), _T("FileZilla"));
+	TiXmlElement* fz2Root = fz2.Load();
+	if (fz2Root) {
+		TiXmlElement* sites_fz2 = fz2Root->FirstChildElement("Sites");
+		if (sites_fz2) {
+			int res = wxMessageBoxEx(_("The file you have selected contains site manager data from a previous version of FileZilla.\nDue to differences in the storage format, only host, port, username and password will be imported.\nContinue with the import?"),
 				_("Import data from older version"), wxICON_QUESTION | wxYES_NO);
-			
-			if (res == wxYES)
-				ImportLegacySites(fz2Root->FirstChildElement("Sites"));
 
-			delete xmlDocument;
+			if (res == wxYES)
+				ImportLegacySites(sites_fz2);
 			return;
 		}
 	}
 
-	delete xmlDocument;
-
-	wxMessageBox(_("File does not contain any importable data."), _("Error importing"), wxICON_ERROR, m_parent);
+	wxMessageBoxEx(_("File does not contain any importable data."), _("Error importing"), wxICON_ERROR, m_parent);
 }
 
 bool CImportDialog::ImportLegacySites(TiXmlElement* pSites)
 {
 	CInterProcessMutex mutex(MUTEX_SITEMANAGER);
 
-	CXmlFile file(_T("sitemanager"));
+	CXmlFile file(wxGetApp().GetSettingsFile(_T("sitemanager")));
 	TiXmlElement* pDocument = file.Load();
-	if (!pDocument)
-	{
-		wxString msg = wxString::Format(_("Could not load \"%s\", please make sure the file is valid and can be accessed.\nAny changes made in the Site Manager will not be saved."), file.GetFileName().GetFullPath().c_str());
-		wxMessageBox(msg, _("Error loading xml file"), wxICON_ERROR);
+	if (!pDocument) {
+		wxString msg = wxString::Format(_("Could not load \"%s\", please make sure the file is valid and can be accessed.\nAny changes made in the Site Manager will not be saved."), file.GetFileName());
+		wxMessageBoxEx(msg, _("Error loading xml file"), wxICON_ERROR);
 
 		return false;
 	}
@@ -129,11 +105,15 @@ bool CImportDialog::ImportLegacySites(TiXmlElement* pSites)
 	if (!ImportLegacySites(pSites, pCurrentSites))
 		return false;
 
-	return file.Save();
+	return file.Save(true);
 }
 
 wxString CImportDialog::DecodeLegacyPassword(wxString pass)
 {
+	if( pass.size() % 3 ) {
+		return wxString();
+	}
+
 	wxString output;
 	const char* key = "FILEZILLA1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZ";
 
@@ -143,10 +123,10 @@ wxString CImportDialog::DecodeLegacyPassword(wxString pass)
 		if (pass[i] < '0' || pass[i] > '9' ||
 			pass[i + 1] < '0' || pass[i + 1] > '9' ||
 			pass[i + 2] < '0' || pass[i + 2] > '9')
-			return _T("");
+			return wxString();
 		int number = (pass[i] - '0') * 100 +
 						(pass[i + 1] - '0') * 10 +
-						pass[i + 2] - '0';
+						(pass[i + 2] - '0');
 		wxChar c = number ^ key[(i / 3 + pos) % strlen(key)];
 		output += c;
 	}
@@ -156,31 +136,28 @@ wxString CImportDialog::DecodeLegacyPassword(wxString pass)
 
 bool CImportDialog::ImportLegacySites(TiXmlElement* pSitesToImport, TiXmlElement* pExistingSites)
 {
-	for (TiXmlElement* pImportFolder = pSitesToImport->FirstChildElement("Folder"); pImportFolder; pImportFolder = pImportFolder->NextSiblingElement("Folder"))
-	{
+	for (TiXmlElement* pImportFolder = pSitesToImport->FirstChildElement("Folder"); pImportFolder; pImportFolder = pImportFolder->NextSiblingElement("Folder")) {
 		wxString name = GetTextAttribute(pImportFolder, "Name");
-		if (name == _T(""))
+		if (name.empty())
 			continue;
 
 		wxString newName = name;
 		int i = 2;
 		TiXmlElement* pFolder;
-		while (!(pFolder = GetFolderWithName(pExistingSites, newName)))
-		{
-			newName = wxString::Format(_T("%s %d"), name.c_str(), i++);
+		while (!(pFolder = GetFolderWithName(pExistingSites, newName))) {
+			newName = wxString::Format(_T("%s %d"), name, i++);
 		}
-		
+
 		ImportLegacySites(pImportFolder, pFolder);
 	}
 
-	for (TiXmlElement* pImportSite = pSitesToImport->FirstChildElement("Site"); pImportSite; pImportSite = pImportSite->NextSiblingElement("Site"))
-	{
+	for (TiXmlElement* pImportSite = pSitesToImport->FirstChildElement("Site"); pImportSite; pImportSite = pImportSite->NextSiblingElement("Site")) {
 		wxString name = GetTextAttribute(pImportSite, "Name");
-		if (name == _T(""))
+		if (name.empty())
 			continue;
 
 		wxString host = GetTextAttribute(pImportSite, "Host");
-		if (host == _T(""))
+		if (host.empty())
 			continue;
 
 		int port = GetAttributeInt(pImportSite, "Port");
@@ -223,15 +200,14 @@ bool CImportDialog::ImportLegacySites(TiXmlElement* pSitesToImport, TiXmlElement
 		wxString user = GetTextAttribute(pImportSite, "User");
 		wxString pass = DecodeLegacyPassword(GetTextAttribute(pImportSite, "Pass"));
 		wxString account = GetTextAttribute(pImportSite, "Account");
-		if (logontype && user == _T(""))
+		if (logontype && user.empty())
 			continue;
 
 		// Find free name
 		wxString newName = name;
 		int i = 2;
-		while (HasEntryWithName(pExistingSites, newName))
-		{
-			newName = wxString::Format(_T("%s %d"), name.c_str(), i++);
+		while (HasEntryWithName(pExistingSites, newName)) {
+			newName = wxString::Format(_T("%s %d"), name, i++);
 		}
 
 		TiXmlElement* pServer = pExistingSites->LinkEndChild(new TiXmlElement("Server"))->ToElement();
@@ -252,16 +228,14 @@ bool CImportDialog::ImportLegacySites(TiXmlElement* pSitesToImport, TiXmlElement
 bool CImportDialog::HasEntryWithName(TiXmlElement* pElement, const wxString& name)
 {
 	TiXmlElement* pChild;
-	for (pChild = pElement->FirstChildElement("Server"); pChild; pChild = pChild->NextSiblingElement("Server"))
-	{
+	for (pChild = pElement->FirstChildElement("Server"); pChild; pChild = pChild->NextSiblingElement("Server")) {
 		wxString childName = GetTextElement(pChild);
 		childName.Trim(true);
 		childName.Trim(false);
 		if (!name.CmpNoCase(childName))
 			return true;
 	}
-	for (pChild = pElement->FirstChildElement("Folder"); pChild; pChild = pChild->NextSiblingElement("Folder"))
-	{
+	for (pChild = pElement->FirstChildElement("Folder"); pChild; pChild = pChild->NextSiblingElement("Folder")) {
 		wxString childName = GetTextElement(pChild);
 		childName.Trim(true);
 		childName.Trim(false);
@@ -275,8 +249,7 @@ bool CImportDialog::HasEntryWithName(TiXmlElement* pElement, const wxString& nam
 TiXmlElement* CImportDialog::GetFolderWithName(TiXmlElement* pElement, const wxString& name)
 {
 	TiXmlElement* pChild;
-	for (pChild = pElement->FirstChildElement("Server"); pChild; pChild = pChild->NextSiblingElement("Server"))
-	{
+	for (pChild = pElement->FirstChildElement("Server"); pChild; pChild = pChild->NextSiblingElement("Server")) {
 		wxString childName = GetTextElement(pChild);
 		childName.Trim(true);
 		childName.Trim(false);
@@ -284,8 +257,7 @@ TiXmlElement* CImportDialog::GetFolderWithName(TiXmlElement* pElement, const wxS
 			return 0;
 	}
 
-	for (pChild = pElement->FirstChildElement("Folder"); pChild; pChild = pChild->NextSiblingElement("Folder"))
-	{
+	for (pChild = pElement->FirstChildElement("Folder"); pChild; pChild = pChild->NextSiblingElement("Folder")) {
 		wxString childName = GetTextElement(pChild);
 		childName.Trim(true);
 		childName.Trim(false);
@@ -303,12 +275,11 @@ bool CImportDialog::ImportSites(TiXmlElement* pSites)
 {
 	CInterProcessMutex mutex(MUTEX_SITEMANAGER);
 
-	CXmlFile file(_T("sitemanager"));
+	CXmlFile file(wxGetApp().GetSettingsFile(_T("sitemanager")));
 	TiXmlElement* pDocument = file.Load();
-	if (!pDocument)
-	{
-		wxString msg = wxString::Format(_("Could not load \"%s\", please make sure the file is valid and can be accessed.\nAny changes made in the Site Manager will not be saved."), file.GetFileName().GetFullPath().c_str());
-		wxMessageBox(msg, _("Error loading xml file"), wxICON_ERROR);
+	if (!pDocument) {
+		wxString msg = wxString::Format(_("Could not load \"%s\", please make sure the file is valid and can be accessed.\nAny changes made in the Site Manager will not be saved."), file.GetFileName());
+		wxMessageBoxEx(msg, _("Error loading xml file"), wxICON_ERROR);
 
 		return false;
 	}
@@ -320,17 +291,16 @@ bool CImportDialog::ImportSites(TiXmlElement* pSites)
 	if (!ImportSites(pSites, pCurrentSites))
 		return false;
 
-	return file.Save();
+	return file.Save(true);
 }
 
 bool CImportDialog::ImportSites(TiXmlElement* pSitesToImport, TiXmlElement* pExistingSites)
 {
-	for (TiXmlElement* pImportFolder = pSitesToImport->FirstChildElement("Folder"); pImportFolder; pImportFolder = pImportFolder->NextSiblingElement("Folder"))
-	{
-		wxString name = GetTextElement(pImportFolder);
-		name.Trim(true);
-		name.Trim(false);
-		if (name == _T(""))
+	for (TiXmlElement* pImportFolder = pSitesToImport->FirstChildElement("Folder"); pImportFolder; pImportFolder = pImportFolder->NextSiblingElement("Folder")) {
+		wxString name = GetTextElement_Trimmed(pImportFolder, "Name");
+		if (name.empty())
+			name = GetTextElement_Trimmed(pImportFolder);
+		if (name.empty())
 			continue;
 
 		wxString newName = name;
@@ -338,29 +308,28 @@ bool CImportDialog::ImportSites(TiXmlElement* pSitesToImport, TiXmlElement* pExi
 		TiXmlElement* pFolder;
 		while (!(pFolder = GetFolderWithName(pExistingSites, newName)))
 		{
-			newName = wxString::Format(_T("%s %d"), name.c_str(), i++);
+			newName = wxString::Format(_T("%s %d"), name, i++);
 		}
-		
+
 		ImportSites(pImportFolder, pFolder);
 	}
 
-	for (TiXmlElement* pImportSite = pSitesToImport->FirstChildElement("Server"); pImportSite; pImportSite = pImportSite->NextSiblingElement("Server"))
-	{
-		wxString name = GetTextElement(pImportSite);
-		name.Trim(true);
-		name.Trim(false);
-		if (name == _T(""))
+	for (TiXmlElement* pImportSite = pSitesToImport->FirstChildElement("Server"); pImportSite; pImportSite = pImportSite->NextSiblingElement("Server")) {
+		wxString name = GetTextElement_Trimmed(pImportSite, "Name");
+		if (name.empty())
+			name = GetTextElement_Trimmed(pImportSite);
+		if (name.empty())
 			continue;
 
 		// Find free name
 		wxString newName = name;
 		int i = 2;
-		while (HasEntryWithName(pExistingSites, newName))
-		{
-			newName = wxString::Format(_T("%s %d"), name.c_str(), i++);
+		while (HasEntryWithName(pExistingSites, newName)) {
+			newName = wxString::Format(_T("%s %d"), name, i++);
 		}
 
 		TiXmlElement* pServer = pExistingSites->InsertEndChild(*pImportSite)->ToElement();
+		AddTextElement(pServer, "Name", newName, true);
 		AddTextElement(pServer, newName);
 	}
 
