@@ -21,7 +21,7 @@
 DECLARE_EVENT_TYPE(fzEVT_POSTSCROLL, -1)
 DEFINE_EVENT_TYPE(fzEVT_POSTSCROLL)
 
-BEGIN_EVENT_TABLE(wxListCtrlEx, wxListCtrl)
+BEGIN_EVENT_TABLE(wxListCtrlEx, wxListCtrlExBase)
 EVT_COMMAND(wxID_ANY, fzEVT_POSTSCROLL, wxListCtrlEx::OnPostScrollEvent)
 EVT_SCROLLWIN(wxListCtrlEx::OnScrollEvent)
 EVT_MOUSEWHEEL(wxListCtrlEx::OnMouseWheel)
@@ -44,16 +44,9 @@ wxListCtrlEx::wxListCtrlEx(wxWindow *parent,
 						   long style,
 						   const wxValidator& validator,
 						   const wxString& name)
-						   : wxListCtrl(parent, id, pos, size, style, validator, name)
 {
-#ifdef __WXMSW__
-	m_pHeaderImageList = 0;
-#endif
-	m_header_icon_index.down = m_header_icon_index.up = -1;
-
-	m_pVisibleColumnMapping = 0;
-	m_prefixSearch_enabled = false;
-
+	Create(parent, id, pos, size, style, validator, name);
+	
 #ifndef __WXMSW__
 	m_editing = false;
 #else
@@ -70,12 +63,23 @@ wxListCtrlEx::~wxListCtrlEx()
 	delete [] m_pVisibleColumnMapping;
 }
 
-#ifndef __WXMSW__
-wxWindow* wxListCtrlEx::GetMainWindow() const
+wxWindow* wxListCtrlEx::GetMainWindow()
 {
+#ifdef __WXMSW__
+	return this;
+#else
 	return reinterpret_cast<wxWindow*>(m_mainWin);
-}
 #endif
+}
+
+wxWindow const* wxListCtrlEx::GetMainWindow() const
+{
+#ifdef __WXMSW__
+	return this;
+#else
+	return reinterpret_cast<wxWindow const*>(m_mainWin);
+#endif
+}
 
 void wxListCtrlEx::OnPostScroll()
 {
@@ -285,7 +289,10 @@ void wxListCtrlEx::OnKeyDown(wxKeyEvent& event)
 
 	// Get the actual key
 	BYTE state[256];
-	GetKeyboardState(state);
+	if (!GetKeyboardState(state)) {
+		event.Skip();
+		return;
+	}
 	wxChar buffer[1];
 	int res = ToUnicode(event.GetRawKeyCode(), 0, state, buffer, 1, 0);
 	if (res != 1)
@@ -967,11 +974,7 @@ void wxListCtrlEx::SetHeaderSortIconIndex(int col, int icon)
 void wxListCtrlEx::RefreshListOnly(bool eraseBackground /*=true*/)
 {
 	// See comment in wxGenericListCtrl::Refresh
-#ifdef __WXMSW__
-	Refresh(eraseBackground);
-#else
 	GetMainWindow()->Refresh(eraseBackground);
-#endif
 }
 
 void wxListCtrlEx::CancelLabelEdit()
@@ -1152,18 +1155,13 @@ bool wxListCtrlEx::HasSelection() const
 
 wxRect wxListCtrlEx::GetListRect() const
 {
-#ifdef __WXMSW__
-	wxRect windowRect = GetClientRect();
-	{
-		wxRect topRect;
-		if (GetItemRect(0, topRect))
-		{
-			windowRect.height -= topRect.y;
-			windowRect.y += topRect.y;
-		}
-	}
-#else
 	wxRect windowRect = GetMainWindow()->GetClientRect();
+#ifdef __WXMSW__
+	wxRect topRect;
+	if (GetItemRect(0, topRect)) {
+		windowRect.height -= topRect.y;
+		windowRect.y += topRect.y;
+	}
 #endif
 
 	return windowRect;
@@ -1275,11 +1273,7 @@ bool CListCtrlDropTarget::IsBottomScroll(wxPoint p) const
 void CListCtrlDropTarget::OnTimer(wxTimerEvent& /*event*/)
 {
 	wxPoint p = wxGetMousePosition();
-#ifdef __WXMSW__
-	wxWindow* ctrl = m_pListCtrl;
-#else
 	wxWindow* ctrl = m_pListCtrl->GetMainWindow();
-#endif
 	p = ctrl->ScreenToClient(p);
 
 	if (IsTopScroll(p))
