@@ -7,15 +7,13 @@
 #endif
 #include <string>
 #include <locale.h>
+#include <sys/stat.h>
 
 #ifdef ENABLE_BINRELOC
 	#define BR_PTHREADS 0
 	#include "prefix.h"
 #endif
 
-// Custom main method to initialize proper locale
-#ifdef __WXGTK__
-
 struct t_fallbacks
 {
 	const char* locale;
@@ -50,6 +48,21 @@ struct t_fallbacks fallbacks[] = {
 	{ 0, 0 }
 };
 
+wxString GetFallbackLocale( wxString const& locale )
+{
+	int i = 0;
+	while (fallbacks[i].locale) {
+		if (fallbacks[i].locale == locale)
+			return fallbacks[i].fallback;
+		i++;
+	}
+
+	return wxString();
+}
+
+// Custom main method to initialize proper locale
+#ifdef __WXGTK__
+
 bool CInitializer::error = false;
 
 static std::string mkstr(const char* str)
@@ -165,23 +178,22 @@ std::string CInitializer::GetDefaultsXmlFile()
 	if (!file.empty())
 		return file;
 
-	std::string home = mkstr(getenv("HOME"));
-	if (!home.empty())
-	{
-		if (home[home.size() - 1] != '/')
-			home += '/';
-		home += ".filezilla/fzdefaults.xml";
+	file = GetUnadjustedSettingsDir() + "fzdefaults.xml";
 
-		struct stat buf;
-		if (!stat(home.c_str(), &buf))
-			return home;
+	{
+		struct stat buf{};
+		if (!stat(file.c_str(), &buf)) {
+			return file;
+		}
 	}
 
 	file = "/etc/filezilla/fzdefaults.xml";
 
-	struct stat buf;
-	if (!stat(file.c_str(), &buf))
-		return file;
+	{
+		struct stat buf{};
+		if (!stat(file.c_str(), &buf))
+			return file;
+	}
 
 
 	file = CheckPathForDefaults(mkstr(SELFPATH), 2, "share/filezilla/fzdefaults.xml");
@@ -232,7 +244,7 @@ std::string CInitializer::ReadSettingsFromDefaults(std::string file)
 			dir = dir.substr(pos + 1);
 		}
 
-		if (token[0] == '$')
+		if (!token.empty() && token[0] == '$')
 		{
 			if (token[1] == '$')
 				result += token.substr(1);
@@ -288,7 +300,55 @@ std::string CInitializer::GetSettingFromFile(std::string file, const std::string
 	return "";
 }
 
-std::string CInitializer::GetSettingsDir()
+namespace {
+std::string TryDirectory( std::string const& env, std::string const& suffix, bool check_exists )
+{
+	std::string path = mkstr(getenv(env.c_str()));
+	if( !path.empty() && path[0] == '/' ) {
+		if( path[path.size()-1] != '/' ) {
+			path += '/';
+		}
+
+		path += suffix;
+
+		if( check_exists ) {
+			struct stat buf{};
+			int res = stat(path.c_str(), &buf);
+			if( res || !S_ISDIR(buf.st_mode) ) {
+				path.clear();
+			}
+		}
+	}
+	else {
+		path.clear();
+	}
+	return path;
+}
+}
+
+std::string CInitializer::GetUnadjustedSettingsDir()
+{
+	std::string cfg = TryDirectory("XDG_CONFIG_HOME", "filezilla/", true);
+	if( cfg.empty() ) {
+		cfg = TryDirectory("HOME", ".config/filezilla/", true);
+	}
+	if( cfg.empty() ) {
+		cfg = TryDirectory("HOME", ".filezilla/", true);
+	}
+	if( cfg.empty() ) {
+		cfg = TryDirectory("XDG_CONFIG_HOME", "filezilla/", false);
+	}
+	if( cfg.empty() ) {
+		cfg = TryDirectory("HOME", ".config/filezilla/", false);
+	}
+	if( cfg.empty() ) {
+		cfg = TryDirectory("HOME", ".filezilla/", false);
+	}
+
+	return cfg;
+}
+
+std::string CInitializer::GetAdjustedSettingsDir()
 {
 	std::string defaults = GetDefaultsXmlFile();
 	if (!defaults.empty())
@@ -298,20 +358,12 @@ std::string CInitializer::GetSettingsDir()
 			return dir;
 	}
 
-	std::string home = mkstr(getenv("HOME"));
-	if (home.empty())
-		 return "";
-
-	if (home[home.size() - 1] != '/')
-		home += '/';
-	home += ".filezilla/";
-
-	return home;
+	return GetUnadjustedSettingsDir();
 }
 
 std::string CInitializer::GetLocaleOption()
 {
-	const std::string dir = GetSettingsDir();
+	const std::string dir = GetAdjustedSettingsDir();
 	if (dir.empty())
 		return "";
 
