@@ -1,5 +1,7 @@
 #include <filezilla.h>
 #include "loginmanager.h"
+
+#include "dialogex.h"
 #include "filezillaapp.h"
 
 CLoginManager CLoginManager::m_theLoginManager;
@@ -9,19 +11,16 @@ bool CLoginManager::GetPassword(CServer &server, bool silent, wxString const& na
 	wxASSERT(!silent || server.GetLogonType() == ASK || server.GetLogonType() == INTERACTIVE);
 	wxASSERT(challenge.empty() || server.GetLogonType() == INTERACTIVE);
 
-	if (server.GetLogonType() == ASK)
-	{
-		std::list<t_passwordcache>::const_iterator iter;
-		for (iter = m_passwordCache.begin(); iter != m_passwordCache.end(); ++iter)
-		{
-			if (iter->host != server.GetHost())
+	if (server.GetLogonType() == ASK) {
+		for (auto const& it : m_passwordCache) {
+			if (it.host != server.GetHost())
 				continue;
-			if (iter->port != server.GetPort())
+			if (it.port != server.GetPort())
 				continue;
-			if (iter->user != server.GetUser())
+			if (it.user != server.GetUser())
 				continue;
 
-			server.SetUser(server.GetUser(), iter->password);
+			server.SetUser(server.GetUser(), it.password);
 			return true;
 		}
 	}
@@ -33,22 +32,22 @@ bool CLoginManager::GetPassword(CServer &server, bool silent, wxString const& na
 
 bool CLoginManager::DisplayDialog(CServer &server, wxString const& name, wxString challenge)
 {
-	wxDialog pwdDlg;
-	wxXmlResource::Get()->LoadDialog(&pwdDlg, wxGetApp().GetTopWindow(), _T("ID_ENTERPASSWORD"));
-	if (name.empty())
-	{
+	wxDialogEx pwdDlg;
+	if (!pwdDlg.Load(wxGetApp().GetTopWindow(), _T("ID_ENTERPASSWORD"))) {
+		return false;
+	}
+
+	if (name.empty()) {
 		pwdDlg.GetSizer()->Show(XRCCTRL(pwdDlg, "ID_NAMELABEL", wxStaticText), false, true);
 		pwdDlg.GetSizer()->Show(XRCCTRL(pwdDlg, "ID_NAME", wxStaticText), false, true);
 	}
 	else
 		XRCCTRL(pwdDlg, "ID_NAME", wxStaticText)->SetLabel(name);
-	if (challenge.empty())
-	{
+	if (challenge.empty()) {
 		pwdDlg.GetSizer()->Show(XRCCTRL(pwdDlg, "ID_CHALLENGELABEL", wxStaticText), false, true);
 		pwdDlg.GetSizer()->Show(XRCCTRL(pwdDlg, "ID_CHALLENGE", wxTextCtrl), false, true);
 	}
-	else
-	{
+	else {
 #ifdef __WXMSW__
 		challenge.Replace(_T("\n"), _T("\r\n"));
 #endif
@@ -58,15 +57,13 @@ bool CLoginManager::DisplayDialog(CServer &server, wxString const& name, wxStrin
 	}
 	XRCCTRL(pwdDlg, "ID_HOST", wxStaticText)->SetLabel(server.FormatHost());
 
-	if (server.GetUser().empty())
-	{
+	if (server.GetUser().empty()) {
 		pwdDlg.SetTitle(_("Enter username and password"));
 		XRCCTRL(pwdDlg, "ID_OLD_USER_LABEL", wxStaticText)->Hide();
 		XRCCTRL(pwdDlg, "ID_OLD_USER", wxStaticText)->Hide();
 
 		XRCCTRL(pwdDlg, "ID_HEADER_PASS", wxStaticText)->Hide();
-		if (server.GetLogonType() == INTERACTIVE)
-		{
+		if (server.GetLogonType() == INTERACTIVE) {
 			XRCCTRL(pwdDlg, "ID_PASSWORD_LABEL", wxStaticText)->Hide();
 			XRCCTRL(pwdDlg, "ID_PASSWORD", wxTextCtrl)->Hide();
 			XRCCTRL(pwdDlg, "ID_REMEMBER", wxCheckBox)->Hide();
@@ -77,8 +74,7 @@ bool CLoginManager::DisplayDialog(CServer &server, wxString const& name, wxStrin
 
 		XRCCTRL(pwdDlg, "ID_NEW_USER", wxTextCtrl)->SetFocus();
 	}
-	else
-	{
+	else {
 		XRCCTRL(pwdDlg, "ID_OLD_USER", wxStaticText)->SetLabel(server.GetUser());
 		XRCCTRL(pwdDlg, "ID_NEW_USER_LABEL", wxStaticText)->Hide();
 		XRCCTRL(pwdDlg, "ID_NEW_USER", wxTextCtrl)->Hide();
@@ -91,16 +87,13 @@ bool CLoginManager::DisplayDialog(CServer &server, wxString const& name, wxStrin
 	pwdDlg.GetSizer()->SetSizeHints(&pwdDlg);
 
 	wxString user;
-	while (user.empty())
-	{
+	while (user.empty()) {
 		if (pwdDlg.ShowModal() != wxID_OK)
 			return false;
 
-		if (server.GetUser().empty())
-		{
+		if (server.GetUser().empty()) {
 			user = XRCCTRL(pwdDlg, "ID_NEW_USER", wxTextCtrl)->GetValue();
-			if (user.empty())
-			{
+			if (user.empty()) {
 				wxMessageBoxEx(_("No username given."), _("Invalid input"), wxICON_EXCLAMATION);
 				continue;
 			}
@@ -111,8 +104,7 @@ bool CLoginManager::DisplayDialog(CServer &server, wxString const& name, wxStrin
 
 	server.SetUser(user, XRCCTRL(pwdDlg, "ID_PASSWORD", wxTextCtrl)->GetValue());
 
-	if (server.GetLogonType() == ASK && XRCCTRL(pwdDlg, "ID_REMEMBER", wxCheckBox)->GetValue())
-	{
+	if (server.GetLogonType() == ASK && XRCCTRL(pwdDlg, "ID_REMEMBER", wxCheckBox)->GetValue()) {
 		t_passwordcache entry;
 		entry.host = server.GetHost();
 		entry.port = server.GetPort();
@@ -129,8 +121,7 @@ void CLoginManager::CachedPasswordFailed(const CServer& server)
 	if (server.GetLogonType() != ASK)
 		return;
 
-	for (auto iter = m_passwordCache.begin(); iter != m_passwordCache.end(); ++iter)
-	{
+	for (auto iter = m_passwordCache.begin(); iter != m_passwordCache.end(); ++iter) {
 		if (iter->host != server.GetHost())
 			continue;
 		if (iter->port != server.GetPort())
