@@ -38,7 +38,7 @@ CManualTransfer::~CManualTransfer()
 	delete m_pLastSite;
 }
 
-void CManualTransfer::Show(wxWindow* pParent, CState* pState)
+void CManualTransfer::Run(wxWindow* pParent, CState* pState)
 {
 	if (!Load(pParent, _T("ID_MANUALTRANSFER")))
 		return;
@@ -109,7 +109,7 @@ void CManualTransfer::SetAutoAsciiState()
 	if (XRCCTRL(*this, "ID_DOWNLOAD", wxRadioButton)->GetValue())
 	{
 		wxString remote_file = XRCCTRL(*this, "ID_REMOTEFILE", wxTextCtrl)->GetValue();
-		if (remote_file == _T(""))
+		if (remote_file.empty())
 		{
 			XRCCTRL(*this, "ID_TYPE_AUTO_ASCII", wxStaticText)->Hide();
 			XRCCTRL(*this, "ID_TYPE_AUTO_BINARY", wxStaticText)->Hide();
@@ -174,7 +174,7 @@ void CManualTransfer::DisplayServer()
 			XRCCTRL(*this, "ID_PORT", wxTextCtrl)->ChangeValue(_T(""));
 
 		const wxString& protocolName = CServer::GetProtocolName(m_pServer->GetProtocol());
-		if (protocolName != _T(""))
+		if (!protocolName.empty())
 			XRCCTRL(*this, "ID_PROTOCOL", wxChoice)->SetStringSelection(protocolName);
 		else
 			XRCCTRL(*this, "ID_PROTOCOL", wxChoice)->SetStringSelection(CServer::GetProtocolName(FTP));
@@ -306,48 +306,48 @@ void CManualTransfer::OnOK(wxCommandEvent& event)
 
 	if (!m_pServer)
 	{
-		wxMessageBox(_("You need to specify a server."), _("Manual transfer"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("You need to specify a server."), _("Manual transfer"), wxICON_EXCLAMATION);
 		return;
 	}
 
 	wxString local_file = XRCCTRL(*this, "ID_LOCALFILE", wxTextCtrl)->GetValue();
-	if (local_file == _T(""))
+	if (local_file.empty())
 	{
-		wxMessageBox(_("You need to specify a local file."), _("Manual transfer"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("You need to specify a local file."), _("Manual transfer"), wxICON_EXCLAMATION);
 		return;
 	}
 
 	CLocalFileSystem::local_fileType type = CLocalFileSystem::GetFileType(local_file);
 	if (type == CLocalFileSystem::dir)
 	{
-		wxMessageBox(_("Local file is a directory instead of a regular file."), _("Manual transfer"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("Local file is a directory instead of a regular file."), _("Manual transfer"), wxICON_EXCLAMATION);
 		return;
 	}
 	if (!download && type != CLocalFileSystem::file && start)
 	{
-		wxMessageBox(_("Local file does not exist."), _("Manual transfer"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("Local file does not exist."), _("Manual transfer"), wxICON_EXCLAMATION);
 		return;
 	}
 
 	wxString remote_file = XRCCTRL(*this, "ID_REMOTEFILE", wxTextCtrl)->GetValue();
 
-	if (remote_file == _T(""))
+	if (remote_file.empty())
 	{
-		wxMessageBox(_("You need to specify a remote file."), _("Manual transfer"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("You need to specify a remote file."), _("Manual transfer"), wxICON_EXCLAMATION);
 		return;
 	}
 
 	wxString remote_path_str = XRCCTRL(*this, "ID_REMOTEPATH", wxTextCtrl)->GetValue();
-	if (remote_path_str == _T(""))
+	if (remote_path_str.empty())
 	{
-		wxMessageBox(_("You need to specify a remote path."), _("Manual transfer"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("You need to specify a remote path."), _("Manual transfer"), wxICON_EXCLAMATION);
 		return;
 	}
 
 	CServerPath path(remote_path_str, m_pServer->GetType());
-	if (path.IsEmpty())
+	if (path.empty())
 	{
-		wxMessageBox(_("Remote path could not be parsed."), _("Manual transfer"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("Remote path could not be parsed."), _("Manual transfer"), wxICON_EXCLAMATION);
 		return;
 	}
 
@@ -366,7 +366,7 @@ void CManualTransfer::OnOK(wxCommandEvent& event)
 
 	if (name.empty())
 	{
-		wxMessageBox(_("Local file is not a valid filename."), _("Manual transfer"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("Local file is not a valid filename."), _("Manual transfer"), wxICON_EXCLAMATION);
 		return;
 	}
 
@@ -397,7 +397,7 @@ bool CManualTransfer::UpdateServer()
 	XRCCTRL(*this, "ID_PORT", wxTextCtrl)->GetValue().ToULong(&port);
 	wxString host = XRCCTRL(*this, "ID_HOST", wxTextCtrl)->GetValue();
 	// SetHost does not accept URL syntax
-	if (host[0] == '[')
+	if (!host.empty() && host[0] == '[')
 	{
 		host.RemoveLast();
 		host = host.Mid(1);
@@ -427,10 +427,10 @@ bool CManualTransfer::UpdateServer()
 bool CManualTransfer::VerifyServer()
 {
 	const wxString& host = XRCCTRL(*this, "ID_HOST", wxTextCtrl)->GetValue();
-	if (host == _T(""))
+	if (host.empty())
 	{
 		XRCCTRL(*this, "ID_HOST", wxTextCtrl)->SetFocus();
-		wxMessageBox(_("You have to enter a hostname."));
+		wxMessageBoxEx(_("You have to enter a hostname."));
 		return false;
 	}
 
@@ -442,7 +442,7 @@ bool CManualTransfer::VerifyServer()
 		logon_type == ACCOUNT)
 	{
 		XRCCTRL(*this, "ID_LOGONTYPE", wxChoice)->SetFocus();
-		wxMessageBox(_("'Account' logontype not supported by selected protocol"));
+		wxMessageBoxEx(_("'Account' logontype not supported by selected protocol"));
 		return false;
 	}
 
@@ -460,7 +460,7 @@ bool CManualTransfer::VerifyServer()
 		XRCCTRL(*this, "ID_LOGONTYPE", wxChoice)->SetStringSelection(CServer::GetNameFromLogonType(ASK));
 		XRCCTRL(*this, "ID_PASS", wxTextCtrl)->SetValue(_T(""));
 		logon_type = ASK;
-		wxMessageBox(msg, _("Cannot remember password"), wxICON_INFORMATION, this);
+		wxMessageBoxEx(msg, _("Cannot remember password"), wxICON_INFORMATION, this);
 	}
 
 	CServer server;
@@ -476,7 +476,7 @@ bool CManualTransfer::VerifyServer()
 	if (!server.ParseUrl(host, XRCCTRL(*this, "ID_PORT", wxTextCtrl)->GetValue(), _T(""), _T(""), error, path))
 	{
 		XRCCTRL(*this, "ID_HOST", wxTextCtrl)->SetFocus();
-		wxMessageBox(error);
+		wxMessageBoxEx(error);
 		return false;
 	}
 
@@ -484,7 +484,7 @@ bool CManualTransfer::VerifyServer()
 	XRCCTRL(*this, "ID_PORT", wxTextCtrl)->ChangeValue(wxString::Format(_T("%d"), server.GetPort()));
 
 	protocolName = CServer::GetProtocolName(server.GetProtocol());
-	if (protocolName == _T(""))
+	if (protocolName.empty())
 		CServer::GetProtocolName(FTP);
 	XRCCTRL(*this, "ID_PROTOCOL", wxChoice)->SetStringSelection(protocolName);
 
@@ -493,15 +493,15 @@ bool CManualTransfer::VerifyServer()
 	if (logon_type != ANONYMOUS &&
 		logon_type != ASK &&
 		logon_type != INTERACTIVE &&
-		user == _T(""))
+		user.empty())
 	{
 		XRCCTRL(*this, "ID_USER", wxTextCtrl)->SetFocus();
-		wxMessageBox(_("You have to specify a user name"));
+		wxMessageBoxEx(_("You have to specify a user name"));
 		return false;
 	}
 
 	// The way TinyXML handles blanks, we can't use username of only spaces
-	if (user != _T(""))
+	if (!user.empty())
 	{
 		bool space_only = true;
 		for (unsigned int i = 0; i < user.Len(); ++i)
@@ -515,7 +515,7 @@ bool CManualTransfer::VerifyServer()
 		if (space_only)
 		{
 			XRCCTRL(*this, "ID_USER", wxTextCtrl)->SetFocus();
-			wxMessageBox(_("Username cannot be a series of spaces"));
+			wxMessageBoxEx(_("Username cannot be a series of spaces"));
 			return false;
 		}
 
@@ -523,10 +523,10 @@ bool CManualTransfer::VerifyServer()
 
 	// Require account for account logon type
 	if (logon_type == ACCOUNT &&
-		XRCCTRL(*this, "ID_ACCOUNT", wxTextCtrl)->GetValue() == _T(""))
+		XRCCTRL(*this, "ID_ACCOUNT", wxTextCtrl)->GetValue().empty())
 	{
 		XRCCTRL(*this, "ID_ACCOUNT", wxTextCtrl)->SetFocus();
-		wxMessageBox(_("You have to enter an account name"));
+		wxMessageBoxEx(_("You have to enter an account name"));
 		return false;
 	}
 
@@ -546,8 +546,7 @@ void CManualTransfer::OnSelectSite(wxCommandEvent& event)
 
 void CManualTransfer::OnSelectedSite(wxCommandEvent& event)
 {
-	wxString path;
-	CSiteManagerItemData_Site* pData = CSiteManager::GetSiteById(event.GetId(), path);
+	CSiteManagerItemData_Site* pData = CSiteManager::GetSiteById(event.GetId());
 	if (!pData)
 		return;
 
