@@ -137,16 +137,16 @@ void CNetConfWizard::OnPageChanging(wxWizardEvent& event)
 		{
 			wxTextCtrl* control = XRCCTRL(*this, "ID_ACTIVEIP", wxTextCtrl);
 			wxString ip = control->GetValue();
-			if (ip == _T(""))
+			if (ip.empty())
 			{
-				wxMessageBox(_("Please enter your external IP address"));
+				wxMessageBoxEx(_("Please enter your external IP address"));
 				control->SetFocus();
 				event.Veto();
 				return;
 			}
 			if (!IsIpAddress(ip))
 			{
-				wxMessageBox(_("You have to enter a valid IP address."));
+				wxMessageBoxEx(_("You have to enter a valid IP address."));
 				control->SetFocus();
 				event.Veto();
 				return;
@@ -156,9 +156,9 @@ void CNetConfWizard::OnPageChanging(wxWizardEvent& event)
 		{
 			wxTextCtrl* pResolver = XRCCTRL(*this, "ID_ACTIVERESOLVER", wxTextCtrl);
 			wxString address = pResolver->GetValue();
-			if (address == _T(""))
+			if (address.empty())
 			{
-				wxMessageBox(_("Please enter an URL where to get your external address from"));
+				wxMessageBoxEx(_("Please enter an URL where to get your external address from"));
 				pResolver->SetFocus();
 				event.Veto();
 				return;
@@ -179,7 +179,7 @@ void CNetConfWizard::OnPageChanging(wxWizardEvent& event)
 			if (!portMin.ToLong(&min) || !portMax.ToLong(&max) ||
 				min < 1024 || max > 65535 || min > max)
 			{
-				wxMessageBox(_("Please enter a valid portrange."));
+				wxMessageBoxEx(_("Please enter a valid portrange."));
 				pPortMin->SetFocus();
 				event.Veto();
 				return;
@@ -550,7 +550,7 @@ void CNetConfWizard::CloseSocket()
 	if (!m_connectSuccessful)
 	{
 		text[0] = _("Connection with the test server failed.");
-		text[1] = _("Please check on http://filezilla-project.org/probe.php that the server is running and carefully check your settings again.");
+		text[1] = _("Please check on https://filezilla-project.org/probe.php that the server is running and carefully check your settings again.");
 		text[2] = _("If the problem persists, some router and/or firewall keeps blocking FileZilla.");
 	}
 	else
@@ -561,7 +561,7 @@ void CNetConfWizard::CloseSocket()
 			text[0] = _("Connection with server got closed prematurely.");
 			text[1] = _("Please ensure you have a stable internet connection and carefully check your settings again.");
 			text[2] = _("If the problem persists, some router and/or firewall keeps interrupting the connection.");
-			text[3] = _("See also: http://wiki.filezilla-project.org/Network_Configuration");
+			text[3] = _("See also: https://wiki.filezilla-project.org/Network_Configuration");
 			break;
 		case successful:
 			text[0] = _("Congratulations, your configuration seems to be working.");
@@ -574,7 +574,7 @@ void CNetConfWizard::CloseSocket()
 			text[0] = _("The server sent an unexpected or unrecognized reply.");
 			text[1] = _("This means that some router and/or firewall is still interfering with FileZilla.");
 			text[2] = _("Re-run the wizard and carefully check your settings and configure all routers and firewalls accordingly.");
-			text[3] = _("See also: http://wiki.filezilla-project.org/Network_Configuration");
+			text[3] = _("See also: https://wiki.filezilla-project.org/Network_Configuration");
 			break;
 		case tainted:
 			text[0] = _("Active mode FTP test failed. FileZilla knows the correct external IP address, but your router or firewall has misleadingly modified the sent address.");
@@ -615,7 +615,7 @@ void CNetConfWizard::CloseSocket()
 		case externalfailed:
 			text[0] = _("Failed to retrieve the external IP address.");
 			text[1] = _("Please make sure FileZilla is allowed to establish outgoing connections and make sure you typed the address of the address resolver correctly.");
-			text[2] = wxString::Format(_("The address you entered was: %s"), XRCCTRL(*this, "ID_ACTIVERESOLVER", wxTextCtrl)->GetValue().c_str());
+			text[2] = wxString::Format(_("The address you entered was: %s"), XRCCTRL(*this, "ID_ACTIVERESOLVER", wxTextCtrl)->GetValue());
 			break;
 		case datatainted:
 			text[0] = _("Transferred data got tainted.");
@@ -687,7 +687,7 @@ wxString CNetConfWizard::GetExternalIPAddress()
 		{
 			PrintMessage(_("Failed to retrieve local ip address. Aborting"), 1);
 			CloseSocket();
-			return _T("");
+			return wxString();
 		}
 
 		return addr.IPAddress();
@@ -704,12 +704,12 @@ wxString CNetConfWizard::GetExternalIPAddress()
 			wxTextCtrl* pResolver = XRCCTRL(*this, "ID_ACTIVERESOLVER", wxTextCtrl);
 			wxString address = pResolver->GetValue();
 
-			PrintMessage(wxString::Format(_("Retrieving external IP address from %s"), address.c_str()), 0);
+			PrintMessage(wxString::Format(_("Retrieving external IP address from %s"), address), 0);
 
 			m_pIPResolver = new CExternalIPResolver(this);
 			m_pIPResolver->GetExternalIP(address, CSocket::ipv4, true);
 			if (!m_pIPResolver->Done())
-				return _T("");
+				return wxString();
 		}
 		if (!m_pIPResolver->Successful())
 		{
@@ -720,7 +720,7 @@ wxString CNetConfWizard::GetExternalIPAddress()
 
 			m_testResult = externalfailed;
 			CloseSocket();
-			return _T("");
+			return wxString();
 		}
 
 		wxString ip = m_pIPResolver->GetIP();
@@ -731,7 +731,7 @@ wxString CNetConfWizard::GetExternalIPAddress()
 		return ip;
 	}
 
-	return _T("");
+	return wxString();
 }
 
 void CNetConfWizard::OnExternalIPAddress(fzExternalIPResolveEvent& event)
@@ -764,9 +764,9 @@ void CNetConfWizard::SendNextCommand()
 		{
 			PrintMessage(_("Checking for correct external IP address"), 0);
 			wxString ip = GetExternalIPAddress();
-			if (ip == _T(""))
+			if (ip.empty())
 				return;
-			if (!GetIPV6LongForm(ip).IsEmpty())
+			if (!GetIPV6LongForm(ip).empty())
 			{
 				PrintMessage(_("You appear to be using an IPv6-only host. This wizard does not support this environment."), 1);
 				CloseSocket();
@@ -775,13 +775,13 @@ void CNetConfWizard::SendNextCommand()
 			m_externalIP = ip;
 
 			wxString hexIP = ip;
-			for (unsigned int i = 0; i < hexIP.Length(); i++)
-			{
-				wxChar& c = hexIP[i];
+			for (unsigned int i = 0; i < hexIP.Length(); i++) {
+				wxChar c = hexIP[i];
 				if (c == '.')
 					c = '-';
 				else
 					c = c - '0' + 'a';
+				hexIP.SetChar(i, c);
 			}
 
 			if (!Send(_T("IP ") + ip + _T(" ") + hexIP))
@@ -804,7 +804,7 @@ void CNetConfWizard::SendNextCommand()
 		}
 	case 5:
 		{
-			wxString cmd = wxString::Format(_T("PORT %s,%d,%d"), m_externalIP.c_str(), m_listenPort / 256, m_listenPort % 256);
+			wxString cmd = wxString::Format(_T("PORT %s,%d,%d"), m_externalIP, m_listenPort / 256, m_listenPort % 256);
 			cmd.Replace(_T("."), _T(","));
 			Send(cmd);
 		}
@@ -849,7 +849,7 @@ void CNetConfWizard::OnFinish(wxWizardEvent& event)
 {
 	if (m_testResult != successful)
 	{
-		if (wxMessageBox(_("The test did not succeed. Do you really want to save the settings?"), _("Save settings?"), wxYES_NO | wxICON_QUESTION) != wxYES)
+		if (wxMessageBoxEx(_("The test did not succeed. Do you really want to save the settings?"), _("Save settings?"), wxYES_NO | wxICON_QUESTION) != wxYES)
 			return;
 	}
 
