@@ -6,17 +6,7 @@
 #include <sqlite3.h>
 #include <wx/wx.h>
 
-#if HAVE_TR1_UNORDERED_MAP
-#include <tr1/unordered_map>
-#else
 #include <unordered_map>
-#endif
-
-namespace std {
-namespace tr1 {
-}
-using namespace tr1;
-}
 
 #define INVALID_DATA -1
 
@@ -28,7 +18,7 @@ enum _column_type
 
 enum _column_flags
 {
-	not_null,
+	not_null = 1,
 	autoincrement
 };
 
@@ -133,9 +123,7 @@ struct fast_equal
 {
 	bool operator()(wxString const& lhs, wxString const& rhs) const
 	{
-		// wxString is CoW, yet it doesn't even do this fast pointer
-		// comparison in it's less and/or equal operator(s).
-		return lhs.c_str() == rhs.c_str() || lhs == rhs;
+		return lhs == rhs;
 	}
 };
 
@@ -159,8 +147,9 @@ public:
 	void CreateTables();
 	wxString CreateColumnDefs(_column* columns, size_t count);
 
-	void PrepareStatements();
+	bool PrepareStatements();
 
+	sqlite3_stmt* PrepareStatement(const wxString& query);
 	sqlite3_stmt* PrepareInsertStatement(const wxString& name, const _column*, unsigned int count);
 
 	bool SaveServer(const CServerItem& item);
@@ -466,21 +455,39 @@ sqlite3_stmt* CQueueStorage::Impl::PrepareInsertStatement(const wxString& name,
 
 	query += _T(")");
 
+	return PrepareStatement(query);
+}
+
+
+sqlite3_stmt* CQueueStorage::Impl::PrepareStatement(const wxString& query)
+{
 	sqlite3_stmt* ret = 0;
-	if (sqlite3_prepare_v2(db_, query.ToUTF8(), -1, &ret, 0) != SQLITE_OK)
+
+	int res;
+	do
+	{
+		res = sqlite3_prepare_v2(db_, query.ToUTF8(), -1, &ret, 0);
+	} while (res == SQLITE_BUSY);
+
+	if (res != SQLITE_OK)
 		ret = 0;
 
 	return ret;
 }
 
-void CQueueStorage::Impl::PrepareStatements()
+
+bool CQueueStorage::Impl::PrepareStatements()
 {
+	if (!db_)
+		return false;
+
 	insertServerQuery_ = PrepareInsertStatement(_T("servers"), server_table_columns, sizeof(server_table_columns) / sizeof(_column));
 	insertFileQuery_ = PrepareInsertStatement(_T("files"), file_table_columns, sizeof(file_table_columns) / sizeof(_column));
 	insertLocalPathQuery_ = PrepareInsertStatement(_T("local_paths"), path_table_columns, sizeof(path_table_columns) / sizeof(_column));
 	insertRemotePathQuery_ = PrepareInsertStatement(_T("remote_paths"), path_table_columns, sizeof(path_table_columns) / sizeof(_column));
+	if (!insertServerQuery_ || !insertFileQuery_ || !insertLocalPathQuery_ || !insertRemotePathQuery_)
+		return false;
 
-	if (db_)
 	{
 		wxString query = _T("SELECT ");
 		for (unsigned int i = 0; i < (sizeof(server_table_columns) / sizeof(_column)); ++i)
@@ -492,11 +499,10 @@ void CQueueStorage::Impl::PrepareStatements()
 
 		query += _T(" FROM servers ORDER BY id ASC");
 
-		if (sqlite3_prepare_v2(db_, query.ToUTF8(), -1, &selectServersQuery_, 0) != SQLITE_OK)
-			selectServersQuery_ = 0;
+		if (!(selectServersQuery_ = PrepareStatement(query)))
+			return false;
 	}
 
-	if (db_)
 	{
 		wxString query = _T("SELECT ");
 		for (unsigned int i = 0; i < (sizeof(file_table_columns) / sizeof(_column)); ++i)
@@ -508,23 +514,22 @@ void CQueueStorage::Impl::PrepareStatements()
 
 		query += _T(" FROM files WHERE server=:server ORDER BY id ASC");
 
-		if (sqlite3_prepare_v2(db_, query.ToUTF8(), -1, &selectFilesQuery_, 0) != SQLITE_OK)
-			selectFilesQuery_ = 0;
+		if (!(selectFilesQuery_ = PrepareStatement(query)))
+			return false;
 	}
 
-	if (db_)
 	{
 		wxString query = _T("SELECT id, path FROM local_paths");
-		if (sqlite3_prepare_v2(db_, query.ToUTF8(), -1, &selectLocalPathQuery_, 0) != SQLITE_OK)
-			selectLocalPathQuery_ = 0;
+		if (!(selectLocalPathQuery_ = PrepareStatement(query)))
+			return false;
 	}
 
-	if (db_)
 	{
 		wxString query = _T("SELECT id, path FROM remote_paths");
-		if (sqlite3_prepare_v2(db_, query.ToUTF8(), -1, &selectRemotePathQuery_, 0) != SQLITE_OK)
-			selectRemotePathQuery_ = 0;
+		if (!(selectRemotePathQuery_ = PrepareStatement(query)))
+			return false;
 	}
+	return true;
 }
 
 
@@ -541,27 +546,20 @@ bool CQueueStorage::Impl::Bind(sqlite3_stmt* statement, int index, wxLongLong_t
 }
 
 
+#ifndef __WXMSW__
 extern "C" {
 static void custom_free(void* v)
 {
-#ifdef __WXMSW__
-	wxStringData* data = reinterpret_cast<wxStringData*>(v) - 1;
-	data->Unlock();
-#else
 	char* s = reinterpret_cast<char*>(v);
 	delete [] s;
+}
+}
 #endif
-}
-}
 
 bool CQueueStorage::Impl::Bind(sqlite3_stmt* statement, int index, const wxString& value)
 {
 #ifdef __WXMSW__
-	// Increase string reference and pass the data to sqlite with a custom deallocator that
-	// reduces the reference once sqlite is done with it.
-	wxStringData* data = reinterpret_cast<wxStringData*>(const_cast<wxChar*>(value.c_str())) - 1;
-	data->Lock();
-	return sqlite3_bind_text16(statement, index, data + 1, data->nDataLength * 2, custom_free) == SQLITE_OK;
+	return sqlite3_bind_text16(statement, index, value.wc_str(), value.length() * 2, SQLITE_TRANSIENT) == SQLITE_OK;
 #else
 	char* out = new char[value.size() * 2];
 	size_t outlen = utf16_.FromWChar(out, value.size() * 2, value.c_str(), value.size());
@@ -705,9 +703,9 @@ bool CQueueStorage::Impl::SaveServer(const CServerItem& item)
 		for (std::vector<CQueueItem*>::const_iterator it = children.begin() + item.GetRemovedAtFront(); it != children.end(); ++it)
 		{
 			CQueueItem* item = *it;
-			if (item->GetType() == QueueItemType_File)
+			if (item->GetType() == QueueItemType::File)
 				ret &= SaveFile(serverId, *reinterpret_cast<CFileItem*>(item));
-			else if (item->GetType() == QueueItemType_Folder)
+			else if (item->GetType() == QueueItemType::Folder)
 				ret &= SaveDirectory(serverId, *reinterpret_cast<CFolderItem*>(item));
 		}
 	}
@@ -743,7 +741,7 @@ bool CQueueStorage::Impl::SaveFile(wxLongLong server, const CFileItem& file)
 		Bind(insertFileQuery_, file_table_column_names::error_count, file.m_errorCount);
 	else
 		BindNull(insertFileQuery_, file_table_column_names::error_count);
-	Bind(insertFileQuery_, file_table_column_names::priority, file.GetPriority());
+	Bind(insertFileQuery_, file_table_column_names::priority, static_cast<int>(file.GetPriority()));
 	Bind(insertFileQuery_, file_table_column_names::ascii_file, file.m_transferSettings.binary ? 0 : 1);
 
 	if (file.m_defaultFileExistsAction != CFileExistsNotification::unknown)
@@ -764,7 +762,7 @@ bool CQueueStorage::Impl::SaveFile(wxLongLong server, const CFileItem& file)
 
 bool CQueueStorage::Impl::SaveDirectory(wxLongLong server, const CFolderItem& directory)
 {
-	if (download)
+	if (directory.Download())
 		BindNull(insertFileQuery_, file_table_column_names::source_file);
 	else
 		Bind(insertFileQuery_, file_table_column_names::source_file, directory.GetSourceFile());
@@ -784,7 +782,7 @@ bool CQueueStorage::Impl::SaveDirectory(wxLongLong server, const CFolderItem& di
 		Bind(insertFileQuery_, file_table_column_names::error_count, directory.m_errorCount);
 	else
 		BindNull(insertFileQuery_, file_table_column_names::error_count);
-	Bind(insertFileQuery_, file_table_column_names::priority, directory.GetPriority());
+	Bind(insertFileQuery_, file_table_column_names::priority, static_cast<int>(directory.GetPriority()));
 	BindNull(insertFileQuery_, file_table_column_names::ascii_file);
 
 	BindNull(insertFileQuery_, file_table_column_names::default_exists_action);
@@ -814,12 +812,14 @@ wxString CQueueStorage::Impl::GetColumnText(sqlite3_stmt* statement, int index,
 	int len = sqlite3_column_bytes16(statement, index);
 	if (text)
 	{
-		wxChar* out = ret.GetWriteBuf( len );
+		wxStringBuffer buffer(ret, len);
+		wxChar* out = buffer;
+
 		int outlen = utf16_.ToWChar( out, len, text, len );
-		ret.UngetWriteBuf( outlen );
-		if (shrink)
-			ret.Shrink();
+		buffer[outlen] = 0;
 	}
+	if (shrink)
+		ret.Shrink();
 #endif
 
 	return ret;
@@ -846,7 +846,7 @@ wxLongLong_t CQueueStorage::Impl::ParseServerFromRow(CServer& server)
 	server = CServer();
 
 	wxString host = GetColumnText(selectServersQuery_, server_table_column_names::host);
-	if (host == _T(""))
+	if (host.empty())
 		return INVALID_DATA;
 
 	int port = GetColumnInt(selectServersQuery_, server_table_column_names::port);
@@ -888,7 +888,7 @@ wxLongLong_t CQueueStorage::Impl::ParseServerFromRow(CServer& server)
 		if ((long)ACCOUNT == logonType)
 		{
 			wxString account = GetColumnText(selectServersQuery_, server_table_column_names::account);
-			if (account == _T(""))
+			if (account.empty())
 				return INVALID_DATA;
 			if (!server.SetAccount(account))
 				return INVALID_DATA;
@@ -971,9 +971,9 @@ wxLongLong_t CQueueStorage::Impl::ParseFileFromRow(CFileItem** pItem)
 
 	if (localPathId == -1 || remotePathId == -1)
 	{
-		// QueueItemType_Folder
+		// QueueItemType::Folder
 		if ((download && localPath.empty()) ||
-			(!download && remotePath.IsEmpty()))
+			(!download && remotePath.empty()))
 		{
 			return INVALID_DATA;
 		}
@@ -987,15 +987,15 @@ wxLongLong_t CQueueStorage::Impl::ParseFileFromRow(CFileItem** pItem)
 	{
 		wxLongLong size = GetColumnInt64(selectFilesQuery_, file_table_column_names::size);
 		int errorCount = GetColumnInt(selectFilesQuery_, file_table_column_names::error_count);
-		int priority = GetColumnInt(selectFilesQuery_, file_table_column_names::priority, priority_normal);
+		int priority = GetColumnInt(selectFilesQuery_, file_table_column_names::priority, static_cast<int>(QueuePriority::normal));
 
 		bool binary = GetColumnInt(selectFilesQuery_, file_table_column_names::ascii_file) == 0;
 		int overwrite_action = GetColumnInt(selectFilesQuery_, file_table_column_names::default_exists_action, CFileExistsNotification::unknown);
 
 		if (sourceFile.empty() || localPath.empty() ||
-			remotePath.IsEmpty() ||
+			remotePath.empty() ||
 			size < -1 ||
-			priority < 0 || priority >= PRIORITY_COUNT ||
+			priority < 0 || priority >= static_cast<int>(QueuePriority::count) ||
 			errorCount < 0)
 		{
 			return INVALID_DATA;
@@ -1004,7 +1004,7 @@ wxLongLong_t CQueueStorage::Impl::ParseFileFromRow(CFileItem** pItem)
 		CFileItem* fileItem = new CFileItem(0, true, download, sourceFile, targetFile, localPath, remotePath, size);
 		*pItem = fileItem;
 		fileItem->m_transferSettings.binary = binary;
-		fileItem->SetPriorityRaw((enum QueuePriority)priority);
+		fileItem->SetPriorityRaw(QueuePriority(priority));
 		fileItem->m_errorCount = errorCount;
 
 		if (overwrite_action > 0 && overwrite_action < CFileExistsNotification::ACTION_COUNT)
