@@ -5,59 +5,46 @@
 #include "Options.h"
 #include "xmlfunctions.h"
 
-CXmlFile CRecentServerList::m_XmlFile;
-std::list<CServer> CRecentServerList::m_mostRecentServers;
-
 const std::list<CServer> CRecentServerList::GetMostRecentServers(bool lockMutex /*=true*/)
 {
+	std::list<CServer> mostRecentServers;
+
 	CInterProcessMutex mutex(MUTEX_MOSTRECENTSERVERS, false);
 	if (lockMutex)
 		mutex.Lock();
 
-	if (!m_XmlFile.HasFileName() || m_XmlFile.Modified())
-		m_XmlFile.Load(_T("recentservers"));
-	else
-		return m_mostRecentServers;
-
-	TiXmlElement* pElement = m_XmlFile.GetElement();
+	CXmlFile xmlFile(wxGetApp().GetSettingsFile(_T("recentservers")));
+	TiXmlElement* pElement = xmlFile.Load();
 	if (!pElement || !(pElement = pElement->FirstChildElement("RecentServers")))
-		return m_mostRecentServers;
+		return mostRecentServers;
 
-	m_mostRecentServers.clear();
-    
 	bool modified = false;
 	TiXmlElement* pServer = pElement->FirstChildElement("Server");
-	while (pServer)
-	{
+	while (pServer) {
 		CServer server;
-		if (!GetServer(pServer, server) || m_mostRecentServers.size() >= 10)
-		{
+		if (!GetServer(pServer, server) || mostRecentServers.size() >= 10) {
 			TiXmlElement* pRemove = pServer;
 			pServer = pServer->NextSiblingElement("Server");
 			pElement->RemoveChild(pRemove);
 			modified = true;
 		}
-		else
-		{
+		else {
 			std::list<CServer>::const_iterator iter;
-			for (iter = m_mostRecentServers.begin(); iter != m_mostRecentServers.end(); iter++)
-			{
+			for (iter = mostRecentServers.begin(); iter != mostRecentServers.end(); ++iter) {
 				if (*iter == server)
 					break;
 			}
-			if (iter == m_mostRecentServers.end())
-				m_mostRecentServers.push_back(server);
+			if (iter == mostRecentServers.end())
+				mostRecentServers.push_back(server);
 			pServer = pServer->NextSiblingElement("Server");
 		}
 	}
 
-	if (modified)
-	{
-		wxString error;
-		m_XmlFile.Save(&error);
+	if (modified) {
+		xmlFile.Save(false);
 	}
 
-	return m_mostRecentServers;
+	return mostRecentServers;
 }
 
 void CRecentServerList::SetMostRecentServer(const CServer& server)
@@ -65,58 +52,48 @@ void CRecentServerList::SetMostRecentServer(const CServer& server)
 	CInterProcessMutex mutex(MUTEX_MOSTRECENTSERVERS);
 
 	// Make sure list is initialized
-	GetMostRecentServers(false);
+	auto mostRecentServers = GetMostRecentServers(false);
 
 	bool relocated = false;
-	for (std::list<CServer>::iterator iter = m_mostRecentServers.begin(); iter != m_mostRecentServers.end(); iter++)
-	{
-		if (iter->EqualsNoPass(server))
-		{
-			m_mostRecentServers.erase(iter);
-			m_mostRecentServers.push_front(server);
+	for (auto iter = mostRecentServers.begin(); iter != mostRecentServers.end(); ++iter) {
+		if (iter->EqualsNoPass(server)) {
+			mostRecentServers.erase(iter);
+			mostRecentServers.push_front(server);
 			relocated = true;
 			break;
 		}
 	}
-	if (!relocated)
-	{
-		m_mostRecentServers.push_front(server);
-		if (m_mostRecentServers.size() > 10)
-			m_mostRecentServers.pop_back();
+	if (!relocated) {
+		mostRecentServers.push_front(server);
+		if (mostRecentServers.size() > 10)
+			mostRecentServers.pop_back();
 	}
 
 	if (COptions::Get()->GetOptionVal(OPTION_DEFAULT_KIOSKMODE) == 2)
 		return;
 
-	TiXmlElement* pDocument = m_XmlFile.GetElement();
+	CXmlFile xmlFile(wxGetApp().GetSettingsFile(_T("recentservers")));
+	TiXmlElement* pDocument = xmlFile.CreateEmpty();
 	if (!pDocument)
 		return;
-	
+
 	TiXmlElement* pElement = pDocument->FirstChildElement("RecentServers");
 	if (!pElement)
 		pElement = pDocument->LinkEndChild(new TiXmlElement("RecentServers"))->ToElement();
 
-	pElement->Clear();
-	for (std::list<CServer>::const_iterator iter = m_mostRecentServers.begin(); iter != m_mostRecentServers.end(); iter++)
-	{
+	for (std::list<CServer>::const_iterator iter = mostRecentServers.begin(); iter != mostRecentServers.end(); ++iter) {
 		TiXmlElement* pServer = pElement->LinkEndChild(new TiXmlElement("Server"))->ToElement();
 		SetServer(pServer, *iter);
 	}
 
-	wxString error;
-	m_XmlFile.Save(&error);
+	xmlFile.Save(true);
 }
 
 void CRecentServerList::Clear()
 {
-	m_mostRecentServers.clear();
-
 	CInterProcessMutex mutex(MUTEX_MOSTRECENTSERVERS);
-	if (!m_XmlFile.HasFileName())
-		m_XmlFile.SetFileName(_T("recentservers"));
-
-	m_XmlFile.CreateEmpty();
-
-	wxString error;
-	m_XmlFile.Save(&error);
+	
+	CXmlFile xmlFile(wxGetApp().GetSettingsFile(_T("recentservers"))); 
+	xmlFile.CreateEmpty();
+	xmlFile.Save(true);
 }
