@@ -43,18 +43,16 @@ public:
 	void SetQueue(CQueueView* pQueue);
 
 	bool ChangeOperationMode(enum OperationMode mode);
-	
+
 protected:
 	// Processes the directory listing in case of a recursive operation
 	void ProcessDirectoryListing(const CDirectoryListing* pDirectoryListing);
 	bool NextOperation();
 
-	virtual void OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString& data, const void* data2);
+	virtual void OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString&, const void* data2);
 
 	enum OperationMode m_operationMode;
 
-	CState* m_pState;
-
 	class CNewDir
 	{
 	public:
@@ -86,12 +84,12 @@ protected:
 	std::set<CServerPath> m_visitedDirs;
 	std::list<CNewDir> m_dirsToVisit;
 
-	bool m_allowParent;
+	bool m_allowParent{};
 
 	// Needed for recursive_chmod
-	CChmodDialog* m_pChmodDlg;
+	CChmodDialog* m_pChmodDlg{};
 
-	CQueueView* m_pQueue;
+	CQueueView* m_pQueue{};
 
 	std::list<CFilter> m_filters;
 
