@@ -60,21 +60,18 @@ bool COptionsPageConnectionSFTP::LoadPage()
 bool COptionsPageConnectionSFTP::SavePage()
 {
 	// Don't save keys on process error
-	if (!m_initialized || m_pProcess)
-	{
+	if (!m_initialized || m_pProcess) {
 		wxString keyFiles;
 		wxListCtrl* pKeys = XRCCTRL(*this, "ID_KEYS", wxListCtrl);
-		for (int i = 0; i < pKeys->GetItemCount(); i++)
-		{
-			if (keyFiles != _T(""))
+		for (int i = 0; i < pKeys->GetItemCount(); i++) {
+			if (!keyFiles.empty())
 				keyFiles += _T("\n");
 			keyFiles += pKeys->GetItemText(i);
 		}
 		m_pOptions->SetOption(OPTION_SFTP_KEYFILES, keyFiles);
 	}
 
-	if (m_pProcess)
-	{
+	if (m_pProcess) {
 		m_pProcess->CloseOutput();
 		m_pProcess->Detach();
 		m_pProcess = 0;
@@ -94,7 +91,7 @@ bool COptionsPageConnectionSFTP::LoadProcess()
 	int pos = executable.Find(wxFileName::GetPathSeparator(), true);
 	if (pos == -1)
 	{
-		wxMessageBox(_("fzputtygen could not be started.\nPlease make sure this executable exists in the same directory as the main FileZilla executable."), _("Error starting program"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("fzputtygen could not be started.\nPlease make sure this executable exists in the same directory as the main FileZilla executable."), _("Error starting program"), wxICON_EXCLAMATION);
 		return false;
 	}
 	else
@@ -104,7 +101,7 @@ bool COptionsPageConnectionSFTP::LoadProcess()
 		executable += _T(".exe");
 #endif
 		// Restore quotes
-		if (executable[0] == '"')
+		if (!executable.empty() && executable[0] == '"')
 			executable += '"';
 	}
 
@@ -116,7 +113,7 @@ bool COptionsPageConnectionSFTP::LoadProcess()
 		delete m_pProcess;
 		m_pProcess = 0;
 
-		wxMessageBox(_("fzputtygen could not be started.\nPlease make sure this executable exists in the same directory as the main FileZilla executable."), _("Error starting program"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("fzputtygen could not be started.\nPlease make sure this executable exists in the same directory as the main FileZilla executable."), _("Error starting program"), wxICON_EXCLAMATION);
 		return false;
 	}
 
@@ -136,7 +133,7 @@ bool COptionsPageConnectionSFTP::Send(const wxString& cmd)
 
 	if (stream->GetLastError() != wxSTREAM_NO_ERROR || stream->LastWrite() != len)
 	{
-		wxMessageBox(_("Could not send command to fzputtygen."), _("Command failed"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("Could not send command to fzputtygen."), _("Command failed"), wxICON_EXCLAMATION);
 		return false;
 	}
 
@@ -150,7 +147,7 @@ enum COptionsPageConnectionSFTP::ReplyCode COptionsPageConnectionSFTP::GetReply(
 	wxInputStream *pStream = m_pProcess->GetInputStream();
 	if (!pStream)
 	{
-		wxMessageBox(_("Could not get reply from fzputtygen."), _("Command failed"), wxICON_EXCLAMATION);
+		wxMessageBoxEx(_("Could not get reply from fzputtygen."), _("Command failed"), wxICON_EXCLAMATION);
 		return failure;
 	}
 
@@ -167,7 +164,7 @@ enum COptionsPageConnectionSFTP::ReplyCode COptionsPageConnectionSFTP::GetReply(
 			int read;
 			if (pStream->Eof() || !(read = pStream->LastRead()))
 			{
-				wxMessageBox(_("Could not get reply from fzputtygen."), _("Command failed"), wxICON_EXCLAMATION);
+				wxMessageBoxEx(_("Could not get reply from fzputtygen."), _("Command failed"), wxICON_EXCLAMATION);
 				return failure;
 			}
 			buffer[read] = 0;
@@ -190,6 +187,9 @@ enum COptionsPageConnectionSFTP::ReplyCode COptionsPageConnectionSFTP::GetReply(
 			input = input.Mid(pos + 1);
 			continue;
 		}
+		if( input.empty() ) {
+			continue;
+		}
 		wxChar c = input[0];
 
 		reply = input.Mid(1, pos2 - 1);
@@ -219,8 +219,8 @@ bool COptionsPageConnectionSFTP::LoadKeyFile(wxString& keyFile, bool silent, wxS
 	{
 		if (!silent)
 		{
-			const wxString msg = wxString::Format(_("The file '%s' could not be loaded or does not contain a private key."), keyFile.c_str());
-			wxMessageBox(msg, _("Could not load keyfile"), wxICON_EXCLAMATION);
+			const wxString msg = wxString::Format(_("The file '%s' could not be loaded or does not contain a private key."), keyFile);
+			wxMessageBoxEx(msg, _("Could not load keyfile"), wxICON_EXCLAMATION);
 		}
 		return false;
 	}
@@ -263,20 +263,20 @@ bool COptionsPageConnectionSFTP::LoadKeyFile(wxString& keyFile, bool silent, wxS
 		if (needs_conversion)
 		{
 			if (!encrypted)
-				msg = wxString::Format(_("The file '%s' is not in a format supported by FileZilla.\nWould you like to convert it into a supported format?"), keyFile.c_str());
+				msg = wxString::Format(_("The file '%s' is not in a format supported by FileZilla.\nWould you like to convert it into a supported format?"), keyFile);
 			else
-				msg = wxString::Format(_("The file '%s' is not in a format supported by FileZilla.\nThe file is also password protected. Password protected keyfiles are not supported by FileZilla yet.\nWould you like to convert it into a supported, unprotected format?"), keyFile.c_str());
+				msg = wxString::Format(_("The file '%s' is not in a format supported by FileZilla.\nThe file is also password protected. Password protected keyfiles are not supported by FileZilla yet.\nWould you like to convert it into a supported, unprotected format?"), keyFile);
 		}
 		else if (encrypted)
-			msg = wxString::Format(_("The file '%s' is password protected. Password protected keyfiles are not supported by FileZilla yet.\nWould you like to convert it into an unprotected file?"), keyFile.c_str());
+			msg = wxString::Format(_("The file '%s' is password protected. Password protected keyfiles are not supported by FileZilla yet.\nWould you like to convert it into an unprotected file?"), keyFile);
 
-		int res = wxMessageBox(msg, _("Convert keyfile"), wxICON_QUESTION | wxYES_NO);
+		int res = wxMessageBoxEx(msg, _("Convert keyfile"), wxICON_QUESTION | wxYES_NO);
 		if (res != wxYES)
 			return false;
 
 		if (encrypted)
 		{
-			wxString msg = wxString::Format(_("Enter the password for the file '%s'.\nPlease note that the converted file will not be password protected."), keyFile.c_str());
+			wxString msg = wxString::Format(_("Enter the password for the file '%s'.\nPlease note that the converted file will not be password protected."), keyFile);
 			CInputDialog dlg;
 			if (!dlg.Create(this, _("Password required"), msg))
 				return false;
@@ -296,23 +296,23 @@ bool COptionsPageConnectionSFTP::LoadKeyFile(wxString& keyFile, bool silent, wxS
 			return false;
 		if (code != success)
 		{
-			wxString msg = wxString::Format(_("Failed to load private key: %s"), reply.c_str());
-			wxMessageBox(msg, _("Could not load private key"), wxICON_EXCLAMATION);
+			wxString msg = wxString::Format(_("Failed to load private key: %s"), reply);
+			wxMessageBoxEx(msg, _("Could not load private key"), wxICON_EXCLAMATION);
 			return false;
 		}
 
-		wxFileDialog dlg(this, _("Select filename for converted keyfile"), _T(""), _T(""), _T("PuTTY private key files (*.ppk)|*.ppk"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
+		wxFileDialog dlg(this, _("Select filename for converted keyfile"), wxString(), wxString(), _T("PuTTY private key files (*.ppk)|*.ppk"), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
 		if (dlg.ShowModal() != wxID_OK)
 			return false;
 
 		wxString newName = dlg.GetPath();
-		if (newName == _T(""))
+		if (newName .empty())
 			return false;
 
 		if (newName == keyFile)
 		{
 			// Not actually a requirement by fzputtygen, but be on the safe side. We don't want the user to lose his keys.
-			wxMessageBox(_("Source and target file may not be the same"), _("Could not convert private key"), wxICON_EXCLAMATION);
+			wxMessageBoxEx(_("Source and target file may not be the same"), _("Could not convert private key"), wxICON_EXCLAMATION);
 			return false;
 		}
 
@@ -322,7 +322,7 @@ bool COptionsPageConnectionSFTP::LoadKeyFile(wxString& keyFile, bool silent, wxS
 			return false;
 		if (code != success)
 		{
-			wxMessageBox(wxString::Format(_("Could not write keyfile: %s"), reply.c_str()), _("Could not convert private key"), wxICON_EXCLAMATION);
+			wxMessageBoxEx(wxString::Format(_("Could not write keyfile: %s"), reply), _("Could not convert private key"), wxICON_EXCLAMATION);
 			return false;
 		}
 		keyFile = newName;
@@ -357,7 +357,7 @@ void COptionsPageConnectionSFTP::OnEndProcess(wxProcessEvent& event)
 
 void COptionsPageConnectionSFTP::OnAdd(wxCommandEvent& event)
 {
-	wxFileDialog dlg(this, _("Select file containing private key"), _T(""), _T(""), wxFileSelectorDefaultWildcardStr, wxFD_OPEN | wxFD_FILE_MUST_EXIST);
+	wxFileDialog dlg(this, _("Select file containing private key"), wxString(), wxString(), wxFileSelectorDefaultWildcardStr, wxFD_OPEN | wxFD_FILE_MUST_EXIST);
 	if (dlg.ShowModal() != wxID_OK)
 		return;
 
@@ -386,7 +386,7 @@ bool COptionsPageConnectionSFTP::AddKey(wxString keyFile, bool silent)
 	if (KeyFileExists(keyFile))
 	{
 		if (!silent)
-			wxMessageBox(_("Selected file is already loaded"), _("Cannot load keyfile"), wxICON_INFORMATION);
+			wxMessageBoxEx(_("Selected file is already loaded"), _("Cannot load keyfile"), wxICON_INFORMATION);
 		return false;
 	}
 
