@@ -16,7 +16,7 @@ bool COptionsPageDateFormatting::LoadPage()
 	const wxString& dateFormat = m_pOptions->GetOption(OPTION_DATE_FORMAT);
 	if (dateFormat == _T("1"))
 		SetRCheck(XRCID("ID_DATEFORMAT_ISO"), true, failure);
-	else if (dateFormat[0] == '2')
+	else if (!dateFormat.empty() && dateFormat[0] == '2')
 	{
 		SetRCheck(XRCID("ID_DATEFORMAT_CUSTOM"), true, failure);
 		SetText(XRCID("ID_CUSTOM_DATEFORMAT"), dateFormat.Mid(1), failure);
@@ -27,7 +27,7 @@ bool COptionsPageDateFormatting::LoadPage()
 	const wxString& timeFormat = m_pOptions->GetOption(OPTION_TIME_FORMAT);
 	if (timeFormat == _T("1"))
 		SetRCheck(XRCID("ID_TIMEFORMAT_ISO"), true, failure);
-	else if (timeFormat[0] == '2')
+	else if (!timeFormat.empty() && timeFormat[0] == '2')
 	{
 		SetRCheck(XRCID("ID_TIMEFORMAT_CUSTOM"), true, failure);
 		SetText(XRCID("ID_CUSTOM_TIMEFORMAT"), timeFormat.Mid(1), failure);
@@ -66,11 +66,25 @@ bool COptionsPageDateFormatting::SavePage()
 
 bool COptionsPageDateFormatting::Validate()
 {
-	if (GetRCheck(XRCID("ID_DATEFORMAT_CUSTOM")) && XRCCTRL(*this, "ID_CUSTOM_DATEFORMAT", wxTextCtrl)->GetValue() == _T(""))
-		return DisplayError(_T("ID_CUSTOM_DATEFORMAT"), _("Please enter a custom date format."));
-
-	if (GetRCheck(XRCID("ID_TIMEFORMAT_CUSTOM")) && XRCCTRL(*this, "ID_CUSTOM_TIMEFORMAT", wxTextCtrl)->GetValue() == _T(""))
-		return DisplayError(_T("ID_CUSTOM_TIMEFORMAT"), _("Please enter a custom time format."));
+	if (GetRCheck(XRCID("ID_DATEFORMAT_CUSTOM"))) {
+		wxString const dateformat = XRCCTRL(*this, "ID_CUSTOM_DATEFORMAT", wxTextCtrl)->GetValue();
+		if (dateformat.empty()) {
+			return DisplayError(_T("ID_CUSTOM_DATEFORMAT"), _("Please enter a custom date format."));
+		}
+		if (!CDateTime::VerifyFormat(dateformat)) {
+			return DisplayError(_T("ID_CUSTOM_DATEFORMAT"), _("The custom date format is invalid or contains unsupported format specifiers."));
+		}
+	}
+		
+	if (GetRCheck(XRCID("ID_TIMEFORMAT_CUSTOM"))) {
+		wxString const timeformat = XRCCTRL(*this, "ID_CUSTOM_TIMEFORMAT", wxTextCtrl)->GetValue();
+		if (timeformat.empty()) {
+			return DisplayError(_T("ID_CUSTOM_TIMEFORMAT"), _("Please enter a custom time format."));
+		}
+		if (!CDateTime::VerifyFormat(timeformat)) {
+			return DisplayError(_T("ID_CUSTOM_TIMEFORMAT"), _("The custom time format is invalid or contains unsupported format specifiers."));
+		}
+	}
 
 	return true;
 }
