@@ -120,7 +120,7 @@ void CContextManager::UnregisterHandler(CStateEventHandler* pHandler, enum t_sta
 		for (int i = 0; i < STATECHANGE_MAX; i++)
 		{
 			std::list<t_handler> &handlers = m_handlers[i];
-			for (std::list<t_handler>::iterator iter = handlers.begin(); iter != handlers.end(); ++iter)
+			for (auto iter = handlers.begin(); iter != handlers.end(); ++iter)
 			{
 				if (iter->pHandler == pHandler)
 				{
@@ -133,7 +133,7 @@ void CContextManager::UnregisterHandler(CStateEventHandler* pHandler, enum t_sta
 	else
 	{
 		std::list<t_handler> &handlers = m_handlers[notification];
-		for (std::list<t_handler>::iterator iter = handlers.begin(); iter != handlers.end(); ++iter)
+		for (auto iter = handlers.begin(); iter != handlers.end(); ++iter)
 		{
 			if (iter->pHandler == pHandler)
 			{
@@ -228,7 +228,7 @@ CState::~CState()
 	// Unregister all handlers
 	for (int i = 0; i < STATECHANGE_MAX; i++)
 	{
-		for (std::list<t_handler>::iterator iter = m_handlers[i].begin(); iter != m_handlers[i].end(); ++iter)
+		for (auto iter = m_handlers[i].begin(); iter != m_handlers[i].end(); ++iter)
 		{
 			iter->pHandler->m_pState = 0;
 		}
@@ -242,11 +242,11 @@ CLocalPath CState::GetLocalDir() const
 	return m_localDir;
 }
 
-bool CState::SetLocalDir(const wxString& dir, wxString *error /*=0*/)
+bool CState::SetLocalDir(const wxString& dir, wxString *error, bool rememberPreviousSubdir)
 {
 	if (m_sync_browse.is_changing)
 	{
-		wxMessageBox(_T("Cannot change directory, there already is a synchronized browsing operation in progress."), _("Synchronized browsing"));
+		wxMessageBoxEx(_T("Cannot change directory, there already is a synchronized browsing operation in progress."), _("Synchronized browsing"));
 		return false;
 	}
 
@@ -273,28 +273,28 @@ bool CState::SetLocalDir(const wxString& dir, wxString *error /*=0*/)
 		if (p != m_sync_browse.local_root && !p.IsSubdirOf(m_sync_browse.local_root))
 		{
 			wxString msg = wxString::Format(_("The local directory '%s' is not below the synchronization root (%s).\nDisable synchronized browsing and continue changing the local directory?"),
-					p.GetPath().c_str(),
-					m_sync_browse.local_root.GetPath().c_str());
-			if (wxMessageBox(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
+					p.GetPath(),
+					m_sync_browse.local_root.GetPath());
+			if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
 				return false;
 			SetSyncBrowse(false);
 		}
 		else if (!IsRemoteIdle())
 		{
 			wxString msg(_("A remote operation is in progress and synchronized browsing is enabled.\nDisable synchronized browsing and continue changing the local directory?"));
-			if (wxMessageBox(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
+			if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
 				return false;
 			SetSyncBrowse(false);
 		}
 		else
 		{
 			CServerPath remote_path = GetSynchronizedDirectory(p);
-			if (remote_path.IsEmpty())
+			if (remote_path.empty())
 			{
 				SetSyncBrowse(false);
 				wxString msg = wxString::Format(_("Could not obtain corresponding remote directory for the local directory '%s'.\nSynchronized browsing has been disabled."),
-					p.GetPath().c_str());
-				wxMessageBox(msg, _("Synchronized browsing"));
+					p.GetPath());
+				wxMessageBoxEx(msg, _("Synchronized browsing"));
 				return false;
 			}
 
@@ -307,11 +307,9 @@ bool CState::SetLocalDir(const wxString& dir, wxString *error /*=0*/)
 		}
 	}
 
-	if (p == m_localDir.GetParent())
-	{
+	if (p == m_localDir.GetParent() && rememberPreviousSubdir) {
 #ifdef __WXMSW__
-		if (p.GetPath() == _T("\\"))
-		{
+		if (p.GetPath() == _T("\\")) {
 			m_previouslyVisitedLocalSubdir = m_localDir.GetPath();
 			m_previouslyVisitedLocalSubdir.RemoveLast();
 		}
@@ -332,10 +330,9 @@ bool CState::SetLocalDir(const wxString& dir, wxString *error /*=0*/)
 	return true;
 }
 
-bool CState::SetRemoteDir(const CDirectoryListing *pDirectoryListing, bool modified /*=false*/)
+bool CState::SetRemoteDir(std::shared_ptr<CDirectoryListing> const& pDirectoryListing, bool modified)
 {
-	if (!pDirectoryListing)
-	{
+	if (!pDirectoryListing) {
 		SetSyncBrowse(false);
 		if (modified)
 			return false;
@@ -357,12 +354,9 @@ bool CState::SetRemoteDir(const CDirectoryListing *pDirectoryListing, bool modif
 	else
 		m_previouslyVisitedRemoteSubdir = _T("");
 
-	if (modified)
-	{
-		if (!m_pDirectoryListing || m_pDirectoryListing->path != pDirectoryListing->path)
-		{
+	if (modified) {
+		if (!m_pDirectoryListing || m_pDirectoryListing->path != pDirectoryListing->path) {
 			// We aren't interested in these listings
-			delete pDirectoryListing;
 			return true;
 		}
 	}
@@ -370,10 +364,9 @@ bool CState::SetRemoteDir(const CDirectoryListing *pDirectoryListing, bool modif
 		m_last_path = pDirectoryListing->path;
 
 	if (m_pDirectoryListing && m_pDirectoryListing->path == pDirectoryListing->path &&
-		pDirectoryListing->m_failed)
+		pDirectoryListing->failed())
 	{
 		// We still got an old listing, no need to display the new one
-		delete pDirectoryListing;
 		return true;
 	}
 
@@ -384,35 +377,31 @@ bool CState::SetRemoteDir(const CDirectoryListing *pDirectoryListing, bool modif
 	else
 		NotifyHandlers(STATECHANGE_REMOTE_DIR_MODIFIED);
 
-	if (m_sync_browse.is_changing && !modified)
-	{
+	if (m_sync_browse.is_changing && !modified) {
 		m_sync_browse.is_changing = false;
 		if (m_pDirectoryListing->path != m_sync_browse.remote_root && !m_pDirectoryListing->path.IsSubdirOf(m_sync_browse.remote_root, false))
 		{
 			SetSyncBrowse(false);
 			wxString msg = wxString::Format(_("Current remote directory (%s) is not below the synchronization root (%s).\nSynchronized browsing has been disabled."),
-					m_pDirectoryListing->path.GetPath().c_str(),
-					m_sync_browse.remote_root.GetPath().c_str());
-			wxMessageBox(msg, _("Synchronized browsing"));
+					m_pDirectoryListing->path.GetPath(),
+					m_sync_browse.remote_root.GetPath());
+			wxMessageBoxEx(msg, _("Synchronized browsing"));
 		}
-		else
-		{
+		else {
 			CLocalPath local_path = GetSynchronizedDirectory(m_pDirectoryListing->path);
-			if (local_path.empty())
-			{
+			if (local_path.empty()) {
 				SetSyncBrowse(false);
 				wxString msg = wxString::Format(_("Could not obtain corresponding local directory for the remote directory '%s'.\nSynchronized browsing has been disabled."),
-					m_pDirectoryListing->path.GetPath().c_str());
-				wxMessageBox(msg, _("Synchronized browsing"));
+					m_pDirectoryListing->path.GetPath());
+				wxMessageBoxEx(msg, _("Synchronized browsing"));
 				return true;
 			}
 
 			wxString error;
-			if (!local_path.Exists(&error))
-			{
+			if (!local_path.Exists(&error)) {
 				SetSyncBrowse(false);
 				wxString msg = error + _T("\n") + _("Synchronized browsing has been disabled.");
-				wxMessageBox(msg, _("Synchronized browsing"));
+				wxMessageBoxEx(msg, _("Synchronized browsing"));
 				return true;
 			}
 
@@ -429,7 +418,7 @@ bool CState::SetRemoteDir(const CDirectoryListing *pDirectoryListing, bool modif
 	return true;
 }
 
-CSharedPointer<const CDirectoryListing> CState::GetRemoteDir() const
+std::shared_ptr<CDirectoryListing> CState::GetRemoteDir() const
 {
 	return m_pDirectoryListing;
 }
@@ -510,13 +499,13 @@ void CState::SetServer(const CServer* server)
 	if (server)
 	{
 		if (m_last_server != *server)
-			m_last_path.Clear();
+			m_last_path.clear();
 		m_last_server = *server;
 
 		m_pServer = new CServer(*server);
 
 		const wxString& name = server->GetName();
-		if (!name.IsEmpty())
+		if (!name.empty())
 			m_title = name + _T(" - ") + server->FormatServer();
 		else
 			m_title = server->FormatServer();
@@ -630,7 +619,7 @@ void CState::UnregisterHandler(CStateEventHandler* pHandler, enum t_statechange_
 		for (int i = 0; i < STATECHANGE_MAX; i++)
 		{
 			std::list<t_handler> &handlers = m_handlers[i];
-			for (std::list<t_handler>::iterator iter = handlers.begin(); iter != handlers.end(); ++iter)
+			for (auto iter = handlers.begin(); iter != handlers.end(); ++iter)
 			{
 				if (iter->pHandler == pHandler)
 				{
@@ -643,7 +632,7 @@ void CState::UnregisterHandler(CStateEventHandler* pHandler, enum t_statechange_
 	else
 	{
 		std::list<t_handler> &handlers = m_handlers[notification];
-		for (std::list<t_handler>::iterator iter = handlers.begin(); iter != handlers.end(); ++iter)
+		for (auto iter = handlers.begin(); iter != handlers.end(); ++iter)
 		{
 			if (iter->pHandler == pHandler)
 			{
@@ -719,7 +708,7 @@ void CState::UploadDroppedFiles(const wxFileDataObject* pFileDataObject, const w
 	CServerPath path = m_pDirectoryListing->path;
 	if (subdir == _T("..") && path.HasParent())
 		path = path.GetParent();
-	else if (subdir != _T(""))
+	else if (!subdir.empty())
 		path.AddSegment(subdir);
 
 	UploadDroppedFiles(pFileDataObject, path, queueOnly);
@@ -838,8 +827,8 @@ void CState::HandleDroppedFiles(const wxFileDataObject* pFileDataObject, const C
 			}
 		}
 	}
-	if (!error.IsEmpty())
-		wxMessageBox(error, _("Could not complete operation"));
+	if (!error.empty())
+		wxMessageBoxEx(error, _("Could not complete operation"));
 #endif
 
 	RefreshLocal();
@@ -881,7 +870,7 @@ bool CState::RecursiveCopy(CLocalPath source, const CLocalPath& target)
 		wxString file;
 		while (fs.GetNextFile(file, is_link, is_dir, 0, 0, 0))
 		{
-			if (file == _T(""))
+			if (file.empty())
 			{
 				wxGetApp().DisplayEncodingWarning();
 				continue;
@@ -966,90 +955,6 @@ bool CState::IsRemoteIdle() const
 	return m_pCommandQueue->Idle();
 }
 
-wxString CState::GetAsURL(const wxString& dir)
-{
-	// Cheap URL encode
-	wxString encoded;
-	const wxWX2MBbuf utf8 = dir.mb_str(wxConvUTF8);
-
-	if (!utf8)
-		return wxEmptyString;
-
-	const char* p = utf8;
-	while (*p)
-	{
-		// List of characters that don't need to be escaped taken
-		// from the BNF grammar in RFC 1738
-		// Again attention seeking Windows wants special treatment...
-		const unsigned char c = (unsigned char)*p++;
-		if ((c >= 'a' && c <= 'z') ||
-			(c >= 'A' && c <= 'Z') ||
-			(c >= '0' && c <= '9') ||
-			c == '$' ||
-			c == '_' ||
-			c == '-' ||
-			c == '.' ||
-			c == '+' ||
-			c == '!' ||
-			c == '*' ||
-#ifndef __WXMSW__
-			c == '\'' ||
-#endif
-			c == '(' ||
-			c == ')' ||
-			c == ',' ||
-			c == '?' ||
-			c == ':' ||
-			c == '@' ||
-			c == '&' ||
-			c == '=' ||
-			c == '/')
-		{
-			encoded += (wxChar)c;
-		}
-#ifdef __WXMSW__
-		else if (c == '\\')
-			encoded += '/';
-#endif
-		else
-			encoded += wxString::Format(_T("%%%x"), (unsigned int)c);
-	}
-#ifdef __WXMSW__
-	if (encoded.Left(2) == _T("//"))
-	{
-		// UNC path
-		encoded = encoded.Mid(2);
-	}
-	else
-		encoded = _T("/") + encoded;
-#endif
-	return _T("file://") + encoded;
-}
-
-bool CState::OpenInFileManager(const wxString& dir)
-{
-	bool ret = false;
-#ifdef __WXMSW__
-	// Unfortunately under Windows, UTF-8 encoded file:// URLs don't work, so use native paths.
-	// Unfortunatelier, we cannot use this for UNC paths, have to use file:// here
-	// Unfortunateliest, we again have a problem with UTF-8 characters which we cannot fix...
-	if (dir.Left(2) != _T("\\\\") && dir != _T("/"))
-		ret = wxLaunchDefaultBrowser(dir);
-	else
-#endif
-	{
-		wxString url = GetAsURL(dir);
-		if (!url.IsEmpty())
-			ret = wxLaunchDefaultBrowser(url);
-	}
-
-
-	if (!ret)
-		wxBell();
-
-	return ret;
-}
-
 void CState::ListingFailed(int error)
 {
 	m_sync_browse.is_changing = false;
@@ -1077,23 +982,23 @@ bool CState::ChangeRemoteDir(const CServerPath& path, const wxString& subdir /*=
 		if (!subdir.empty() && !p.ChangePath(subdir))
 		{
 			wxString msg = wxString::Format(_("Could not get full remote path."));
-			wxMessageBox(msg, _("Synchronized browsing"));
+			wxMessageBoxEx(msg, _("Synchronized browsing"));
 			return false;
 		}
 
 		if (p != m_sync_browse.remote_root && !p.IsSubdirOf(m_sync_browse.remote_root, false))
 		{
 			wxString msg = wxString::Format(_("The remote directory '%s' is not below the synchronization root (%s).\nDisable synchronized browsing and continue changing the remote directory?"),
-					p.GetPath().c_str(),
-					m_sync_browse.remote_root.GetPath().c_str());
-			if (wxMessageBox(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
+					p.GetPath(),
+					m_sync_browse.remote_root.GetPath());
+			if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
 				return false;
 			SetSyncBrowse(false);
 		}
 		else if (!IsRemoteIdle() && !ignore_busy)
 		{
 			wxString msg(_("Another remote operation is already in progress, cannot change directory now."));
-			wxMessageBox(msg, _("Synchronized browsing"), wxICON_EXCLAMATION);
+			wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_EXCLAMATION);
 			return false;
 		}
 		else
@@ -1103,15 +1008,15 @@ bool CState::ChangeRemoteDir(const CServerPath& path, const wxString& subdir /*=
 			if (local_path.empty())
 			{
 				wxString msg = wxString::Format(_("Could not obtain corresponding local directory for the remote directory '%s'.\nDisable synchronized browsing and continue changing the remote directory?"),
-					p.GetPath().c_str());
-				if (wxMessageBox(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
+					p.GetPath());
+				if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
 					return false;
 				SetSyncBrowse(false);
 			}
 			else if (!local_path.Exists(&error))
 			{
 				wxString msg = error + _T("\n") + _("Disable synchronized browsing and continue changing the remote directory?");
-				if (wxMessageBox(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
+				if (wxMessageBoxEx(msg, _("Synchronized browsing"), wxICON_QUESTION | wxYES_NO) != wxYES)
 					return false;
 				SetSyncBrowse(false);
 			}
@@ -1136,16 +1041,16 @@ bool CState::SetSyncBrowse(bool enable, const CServerPath& assumed_remote_root /
 
 	if (!enable)
 	{
-		wxASSERT(assumed_remote_root.IsEmpty());
+		wxASSERT(assumed_remote_root.empty());
 		m_sync_browse.local_root.clear();
-		m_sync_browse.remote_root.Clear();
+		m_sync_browse.remote_root.clear();
 		m_sync_browse.is_changing = false;
 
 		NotifyHandlers(STATECHANGE_SYNC_BROWSE);
 		return false;
 	}
 
-	if (!m_pDirectoryListing && assumed_remote_root.IsEmpty())
+	if (!m_pDirectoryListing && assumed_remote_root.empty())
 	{
 		NotifyHandlers(STATECHANGE_SYNC_BROWSE);
 		return false;
@@ -1154,7 +1059,7 @@ bool CState::SetSyncBrowse(bool enable, const CServerPath& assumed_remote_root /
 	m_sync_browse.is_changing = false;
 	m_sync_browse.local_root = m_localDir;
 
-	if (assumed_remote_root.IsEmpty())
+	if (assumed_remote_root.empty())
 		m_sync_browse.remote_root = m_pDirectoryListing->path;
 	else
 	{
