@@ -3,6 +3,8 @@
 
 #include "local_path.h"
 
+#include <memory>
+
 enum t_statechange_notifications
 {
 	STATECHANGE_NONE, // Used to unregister all notifications
@@ -95,24 +97,21 @@ public:
 	CState(CMainFrame* pMainFrame);
 	~CState();
 
+	CState(CState const&) = delete;
+	CState& operator=(CState const&) = delete;
+
 	bool CreateEngine();
 	void DestroyEngine();
 
 	CLocalPath GetLocalDir() const;
-	bool SetLocalDir(const wxString& dir, wxString *error = 0);
-
-	// Opens specified directory in local file manager, e.g. Explorer on Windows
-	static bool OpenInFileManager(const wxString& dir);
-	
-	// Returns a file:// URL
-	static wxString GetAsURL(const wxString& dir);
+	bool SetLocalDir(const wxString& dir, wxString *error = 0, bool rememberPreviousSubdir = true);
 
 	bool Connect(const CServer& server, const CServerPath& path = CServerPath());
 	bool Disconnect();
 
 	bool ChangeRemoteDir(const CServerPath& path, const wxString& subdir = _T(""), int flags = 0, bool ignore_busy = false);
-	bool SetRemoteDir(const CDirectoryListing *m_pDirectoryListing, bool modified = false);
-	CSharedPointer<const CDirectoryListing> GetRemoteDir() const;
+	bool SetRemoteDir(std::shared_ptr<CDirectoryListing> const& pDirectoryListing, bool modified = false);
+	std::shared_ptr<CDirectoryListing> GetRemoteDir() const;
 	const CServerPath GetRemotePath() const;
 
 	const CServer* GetServer() const;
@@ -171,12 +170,14 @@ public:
 	// returns the relative name of the subdirectory.
 	wxString GetPreviouslyVisitedLocalSubdir() const { return m_previouslyVisitedLocalSubdir; }
 	wxString GetPreviouslyVisitedRemoteSubdir() const { return m_previouslyVisitedRemoteSubdir; }
+	void ClearPreviouslyVisitedLocalSubdir() { m_previouslyVisitedLocalSubdir = _T(""); }
+	void ClearPreviouslyVisitedRemoteSubdir() { m_previouslyVisitedRemoteSubdir = _T(""); }
 
 protected:
 	void SetServer(const CServer* server);
 
 	CLocalPath m_localDir;
-	CSharedPointer<const CDirectoryListing> m_pDirectoryListing;
+	std::shared_ptr<CDirectoryListing> m_pDirectoryListing;
 
 	CServer* m_pServer;
 	wxString m_title;
