@@ -7,8 +7,10 @@
 #include "themeprovider.h"
 #include "verifycertdialog.h"
 
+#include <wx/dcclient.h>
+
 static const int statbarWidths[3] = {
-	-3, 0, 35
+	-3, 0, 25
 };
 #define FIELD_QUEUESIZE 1
 
@@ -89,11 +91,7 @@ void wxStatusBarEx::FixupFieldWidth(int field)
 	if (field != GetFieldsCount() - 1)
 		return;
 
-#ifdef __WXMSW__
-	// Gripper overlaps last field if not maximized
-	if (!m_parentWasMaximized && m_columnWidths[field] > 0)
-		m_columnWidths[field] += 6;
-#elif __WXGTK20__
+#if __WXGTK20__
 	// Gripper overlaps last all the time
 	if (m_columnWidths[field] > 0)
 		m_columnWidths[field] += 15;
@@ -103,29 +101,29 @@ void wxStatusBarEx::FixupFieldWidth(int field)
 void wxStatusBarEx::SetFieldWidth(int field, int width)
 {
 	field = GetFieldIndex(field);
+	if( field < 0 ) {
+		return;
+	}
+
 	m_columnWidths[field] = width;
-
 	FixupFieldWidth(field);
-
 	wxStatusBar::SetStatusWidths(GetFieldsCount(), m_columnWidths);
 }
 
 int wxStatusBarEx::GetFieldIndex(int field)
 {
-	if (field >= 0)
-	{
-		wxASSERT(field <= GetFieldsCount());
+	if (field >= 0) {
+		wxCHECK(field <= GetFieldsCount(), -1);
 	}
-	else
-	{
+	else {
 		field = GetFieldsCount() + field;
-		wxASSERT(field >= 0);
+		wxCHECK(field >= 0, -1);
 	}
 
 	return field;
 }
 
-void wxStatusBarEx::OnSize(wxSizeEvent& event)
+void wxStatusBarEx::OnSize(wxSizeEvent&)
 {
 #ifdef __WXMSW__
 	const int count = GetFieldsCount();
@@ -138,9 +136,9 @@ void wxStatusBarEx::OnSize(wxSizeEvent& event)
 			m_parentWasMaximized = isMaximized;
 
 			if (isMaximized)
-				m_columnWidths[count - 1] -= 6;
+				m_columnWidths[count - 1] -= 16;
 			else
-				m_columnWidths[count - 1] += 6;
+				m_columnWidths[count - 1] += 16;
 
 			wxStatusBar::SetStatusWidths(count, m_columnWidths);
 			Refresh();
@@ -152,16 +150,9 @@ void wxStatusBarEx::OnSize(wxSizeEvent& event)
 #ifdef __WXGTK__
 void wxStatusBarEx::SetStatusText(const wxString& text, int number /*=0*/)
 {
-	// Basically identical to the wx one, but not calling Update
-	wxString oldText = m_statusStrings[number];
-	if (oldText != text)
-	{
-		m_statusStrings[number] = text;
-
-		wxRect rect;
-		GetFieldRect(number, rect);
-
-		Refresh(true, &rect);
+	wxString oldText = GetStatusText(number);
+	if (oldText != text) {
+		wxStatusBar::SetStatusText(text, number);
 	}
 }
 #endif
@@ -205,9 +196,12 @@ void CWidgetsStatusBar::OnSize(wxSizeEvent& event)
 #endif
 }
 
-void CWidgetsStatusBar::AddChild(int field, int idx, wxWindow* pChild)
+bool CWidgetsStatusBar::AddField(int field, int idx, wxWindow* pChild)
 {
 	field = GetFieldIndex(field);
+	if( field < 0 ) {
+		return false;
+	}
 
 	t_statbar_child data;
 	data.field = field;
@@ -216,13 +210,14 @@ void CWidgetsStatusBar::AddChild(int field, int idx, wxWindow* pChild)
 	m_children[idx] = data;
 
 	PositionChildren(field);
+
+	return true;
 }
 
-void CWidgetsStatusBar::RemoveChild(int idx)
+void CWidgetsStatusBar::RemoveField(int idx)
 {
-	std::map<int, struct t_statbar_child>::iterator iter = m_children.find(idx);
-	if (iter != m_children.end())
-	{
+	auto iter = m_children.find(idx);
+	if (iter != m_children.end()) {
 		int field = iter->second.field;
 		m_children.erase(iter);
 		PositionChildren(field);
@@ -236,13 +231,15 @@ void CWidgetsStatusBar::PositionChildren(int field)
 
 	int offset = 2;
 
+#ifndef __WXMSW__
 	if (field + 1 == GetFieldsCount())
 	{
 		rect.SetWidth(m_columnWidths[field]);
 		offset += 5 + GetGripperWidth();
 	}
+#endif
 
-	for (std::map<int, struct t_statbar_child>::iterator iter = m_children.begin(); iter != m_children.end(); ++iter)
+	for (auto iter = m_children.begin(); iter != m_children.end(); ++iter)
 	{
 		if (iter->second.field != field)
 			continue;
@@ -263,44 +260,11 @@ void CWidgetsStatusBar::SetFieldWidth(int field, int width)
 		PositionChildren(i);
 }
 
-#ifdef __WXMSW__
-class wxStaticBitmapEx : public wxStaticBitmap
-{
-public:
-	wxStaticBitmapEx(wxWindow* parent, int id, const wxBitmap& bmp)
-		: wxStaticBitmap(parent, id, bmp)
-	{
-	};
-
-protected:
-	DECLARE_EVENT_TABLE()
-
-	// Make sure it is truly transparent, i.e. also works with
-	// themed status bars.
-	void OnErase(wxEraseEvent& event)
-	{
-	}
-
-	void OnPaint(wxPaintEvent& event)
-	{
-		wxPaintDC dc(this);
-		dc.DrawBitmap(GetBitmap(), 0, 0, true);
-	}
-};
-
-BEGIN_EVENT_TABLE(wxStaticBitmapEx, wxStaticBitmap)
-EVT_ERASE_BACKGROUND(wxStaticBitmapEx::OnErase)
-EVT_PAINT(wxStaticBitmapEx::OnPaint)
-END_EVENT_TABLE()
-#else
-#define wxStaticBitmapEx wxStaticBitmap
-#endif
-
-class CIndicator : public wxStaticBitmapEx
+class CIndicator : public wxStaticBitmap
 {
 public:
 	CIndicator(CStatusBar* pStatusBar, const wxBitmap& bmp)
-		: wxStaticBitmapEx(pStatusBar, wxID_ANY, bmp)
+		: wxStaticBitmap(pStatusBar, wxID_ANY, bmp)
 	{
 		m_pStatusBar = pStatusBar;
 	}
@@ -309,17 +273,17 @@ protected:
 	CStatusBar* m_pStatusBar;
 
 	DECLARE_EVENT_TABLE()
-	void OnLeftMouseUp(wxMouseEvent& event)
+	void OnLeftMouseUp(wxMouseEvent&)
 	{
 		m_pStatusBar->OnHandleLeftClick(this);
 	}
-	void OnRightMouseUp(wxMouseEvent& event)
+	void OnRightMouseUp(wxMouseEvent&)
 	{
 		m_pStatusBar->OnHandleRightClick(this);
 	}
 };
 
-BEGIN_EVENT_TABLE(CIndicator, wxStaticBitmapEx)
+BEGIN_EVENT_TABLE(CIndicator, wxStaticBitmap)
 EVT_LEFT_UP(CIndicator::OnLeftMouseUp)
 EVT_RIGHT_UP(CIndicator::OnRightMouseUp)
 END_EVENT_TABLE()
@@ -390,7 +354,7 @@ void CStatusBar::DisplayQueueSize(wxLongLong totalSize, bool hasUnknown)
 	}
 
 	wxString queueSize = wxString::Format(_("Queue: %s%s"), hasUnknown ? _T(">") : _T(""),
-		CSizeFormat::Format(totalSize, true, m_sizeFormat, m_sizeFormatThousandsSep, m_sizeFormatDecimalPlaces).c_str());
+		CSizeFormat::Format(totalSize, true, m_sizeFormat, m_sizeFormatThousandsSep, m_sizeFormatDecimalPlaces));
 
 	SetStatusText(queueSize, FIELD_QUEUESIZE);
 }
@@ -406,7 +370,7 @@ void CStatusBar::DisplayDataType()
 	{
 		if (m_pDataTypeIndicator)
 		{
-			RemoveChild(widget_datatype);
+			RemoveField(widget_datatype);
 			m_pDataTypeIndicator->Destroy();
 			m_pDataTypeIndicator = 0;
 		}
@@ -437,7 +401,7 @@ void CStatusBar::DisplayDataType()
 		if (!m_pDataTypeIndicator)
 		{
 			m_pDataTypeIndicator = new CIndicator(this, bmp);
-			AddChild(0, widget_datatype, m_pDataTypeIndicator);
+			AddField(0, widget_datatype, m_pDataTypeIndicator);
 		}
 		else
 			m_pDataTypeIndicator->SetBitmap(bmp);
@@ -459,7 +423,7 @@ void CStatusBar::MeasureQueueSizeWidth()
 		for (int i = 0; i < m_sizeFormatDecimalPlaces; i++)
 			tmp += _T("8");
 	}
-	s.IncTo(dc.GetTextExtent(wxString::Format(_("Queue: %s MiB"), tmp.c_str())));
+	s.IncTo(dc.GetTextExtent(wxString::Format(_("Queue: %s MiB"), tmp)));
 
 	SetFieldWidth(FIELD_QUEUESIZE, s.x + 10);
 }
@@ -475,7 +439,7 @@ void CStatusBar::DisplayEncrypted()
 	{
 		if (m_pEncryptionIndicator)
 		{
-			RemoveChild(widget_encryption);
+			RemoveField(widget_encryption);
 			m_pEncryptionIndicator->Destroy();
 			m_pEncryptionIndicator = 0;
 		}
@@ -486,7 +450,7 @@ void CStatusBar::DisplayEncrypted()
 		if (!m_pEncryptionIndicator)
 		{
 			m_pEncryptionIndicator = new CIndicator(this, bmp);
-			AddChild(0, widget_encryption, m_pEncryptionIndicator);
+			AddField(0, widget_encryption, m_pEncryptionIndicator);
 			m_pEncryptionIndicator->SetToolTip(_("The connection is encrypted. Click icon for details."));
 		}
 		else
@@ -528,7 +492,7 @@ void CStatusBar::OnHandleLeftClick(wxWindow* pWnd)
 			dlg.ShowDialog(pSftpEncryptionNotification);
 		}
 		else
-			wxMessageBox(_("Certificate and session data are not available yet."), _("Security information"));
+			wxMessageBoxEx(_("Certificate and session data are not available yet."), _("Security information"));
 	}
 	else if (pWnd == m_pSpeedLimitsIndicator)
 	{
@@ -601,12 +565,12 @@ void CStatusBar::UpdateSpeedLimitsIcon()
 		tooltip = _("Speed limits are enabled, click to change.");
 		tooltip += _T("\n");
 		if (downloadLimit)
-			tooltip += wxString::Format(_("Download limit: %s/s"), CSizeFormat::FormatUnit(downloadLimit, CSizeFormat::kilo).c_str());
+			tooltip += wxString::Format(_("Download limit: %s/s"), CSizeFormat::FormatUnit(downloadLimit, CSizeFormat::kilo));
 		else
 			tooltip += _("Download limit: none");
 		tooltip += _T("\n");
 		if (uploadLimit)
-			tooltip += wxString::Format(_("Upload limit: %s/s"), CSizeFormat::FormatUnit(uploadLimit, CSizeFormat::kilo).c_str());
+			tooltip += wxString::Format(_("Upload limit: %s/s"), CSizeFormat::FormatUnit(uploadLimit, CSizeFormat::kilo));
 		else
 			tooltip += _("Upload limit: none");
 	}
@@ -614,7 +578,7 @@ void CStatusBar::UpdateSpeedLimitsIcon()
 	if (!m_pSpeedLimitsIndicator)
 	{
 		m_pSpeedLimitsIndicator = new CIndicator(this, bmp);
-		AddChild(0, widget_speedlimit, m_pSpeedLimitsIndicator);
+		AddField(0, widget_speedlimit, m_pSpeedLimitsIndicator);
 	}
 	else
 		m_pSpeedLimitsIndicator->SetBitmap(bmp);
@@ -648,7 +612,7 @@ void CStatusBar::OnOptionChanged(int option)
 	}
 }
 
-void CStatusBar::OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString& data, const void* data2)
+void CStatusBar::OnStateChange(CState*, enum t_statechange_notifications notification, const wxString&, const void*)
 {
 	if (notification == STATECHANGE_SERVER || notification == STATECHANGE_CHANGEDCONTEXT)
 	{
@@ -657,7 +621,7 @@ void CStatusBar::OnStateChange(CState* pState, enum t_statechange_notifications
 	}
 }
 
-void CStatusBar::OnSpeedLimitsEnable(wxCommandEvent& event)
+void CStatusBar::OnSpeedLimitsEnable(wxCommandEvent&)
 {
 	int downloadlimit = COptions::Get()->GetOptionVal(OPTION_SPEEDLIMIT_INBOUND);
 	int uploadlimit = COptions::Get()->GetOptionVal(OPTION_SPEEDLIMIT_OUTBOUND);
@@ -676,7 +640,7 @@ void CStatusBar::OnSpeedLimitsEnable(wxCommandEvent& event)
 		COptions::Get()->SetOption(OPTION_SPEEDLIMIT_ENABLE, 0);
 }
 
-void CStatusBar::OnSpeedLimitsConfigure(wxCommandEvent& event)
+void CStatusBar::OnSpeedLimitsConfigure(wxCommandEvent&)
 {
 	CSpeedLimitsDialog dlg;
 	dlg.Run(m_pParent);
