@@ -2,6 +2,7 @@
 #define __THEMEPROVIDER_H__
 
 #include <option_change_event_handler.h>
+#include <memory>
 
 enum iconSize
 {
@@ -14,17 +15,20 @@ class CThemeProvider : public wxArtProvider, protected COptionChangeEventHandler
 {
 public:
 	CThemeProvider();
-	virtual ~CThemeProvider() {}
+	virtual ~CThemeProvider();
 
-	static std::list<wxString> GetThemes();
-	static std::list<wxBitmap*> GetAllImages(const wxString& theme, const wxSize& size);
+	static std::vector<wxString> GetThemes();
+	static std::vector<std::unique_ptr<wxBitmap>> GetAllImages(const wxString& theme, const wxSize& size);
 	static bool GetThemeData(const wxString& themePath, wxString& name, wxString& author, wxString& email);
-	static std::list<wxString> GetThemeSizes(const wxString& themePath);
+	static std::vector<wxString> GetThemeSizes(const wxString& themePath);
 	static wxIconBundle GetIconBundle(const wxArtID& id, const wxArtClient& client = wxART_OTHER);
 	static bool ThemeHasSize(const wxString& themePath, const wxString& size);
 
 	static wxSize GetIconSize(enum iconSize size);
 
+	static CThemeProvider* Get();
+
+	wxAnimation CreateAnimation(const wxArtID& id, const wxSize& size);
 protected:
 	static wxString GetThemePath();
 
