@@ -18,7 +18,7 @@ CToolBar::CToolBar()
 
 CToolBar::~CToolBar()
 {
-	for (std::map<int, wxToolBarToolBase*>::iterator iter = m_hidden_tools.begin(); iter != m_hidden_tools.end(); iter++)
+	for (auto iter = m_hidden_tools.begin(); iter != m_hidden_tools.end(); ++iter)
 		delete iter->second;
 }
 
@@ -87,7 +87,7 @@ CToolBar* CToolBar::Load(CMainFrame* pMainFrame)
 	return toolbar;
 }
 
-void CToolBar::OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString& data, const void* data2)
+void CToolBar::OnStateChange(CState* pState, enum t_statechange_notifications notification, const wxString&, const void*)
 {
 	switch (notification)
 	{
@@ -146,7 +146,7 @@ void CToolBar::UpdateToolbarState()
 	else
 	{
 		CServer tmp;
-		canReconnect = pState->GetLastServer().GetHost() != _T("");
+		canReconnect = !pState->GetLastServer().GetHost().empty();
 	}
 	EnableTool(XRCID("ID_TOOLBAR_RECONNECT"), canReconnect);
 }
@@ -205,8 +205,7 @@ bool CToolBar::ShowTool(int id)
 {
 	int offset = 0;
 
-	std::map<int, wxToolBarToolBase*>::iterator iter;
-	for (iter = m_hidden_tools.begin(); iter != m_hidden_tools.end(); iter++)
+	for (auto iter = m_hidden_tools.begin(); iter != m_hidden_tools.end(); ++iter)
 	{
 		if (iter->second->GetId() != id)
 		{
@@ -234,14 +233,14 @@ bool CToolBar::HideTool(int id)
 	if (!tool)
 		return false;
 
-	for (std::map<int, wxToolBarToolBase*>::iterator iter = m_hidden_tools.begin(); iter != m_hidden_tools.end(); iter++)
+	for (auto iter = m_hidden_tools.begin(); iter != m_hidden_tools.end(); ++iter)
 	{
 		if (iter->first > pos)
 			break;
-		
+
 		pos++;
 	}
-	
+
 	m_hidden_tools[pos] = tool;
 
 	return true;
