@@ -1,14 +1,20 @@
 #include <filezilla.h>
 #include "treectrlex.h"
 
-IMPLEMENT_CLASS(wxTreeCtrlEx, wxTreeCtrl)
+IMPLEMENT_CLASS(wxTreeCtrlEx, wxNavigationEnabled<wxTreeCtrl>)
+
+#ifdef __WXMAC__
+BEGIN_EVENT_TABLE(wxTreeCtrlEx, wxNavigationEnabled<wxTreeCtrl>)
+EVT_CHAR(wxTreeCtrlEx::OnChar)
+END_EVENT_TABLE()
+#endif
 
 wxTreeCtrlEx::wxTreeCtrlEx(wxWindow *parent, wxWindowID id /*=wxID_ANY*/,
 			   const wxPoint& pos /*=wxDefaultPosition*/,
 			   const wxSize& size /*=wxDefaultSize*/,
 			   long style /*=wxTR_HAS_BUTTONS|wxTR_LINES_AT_ROOT*/)
-	: wxTreeCtrl(parent, id, pos, size, style), m_setSelection(false)
 {
+	Create(parent, id, pos, size, style);
 }
 
 void wxTreeCtrlEx::SafeSelectItem(const wxTreeItemId& item)
@@ -28,3 +34,16 @@ void wxTreeCtrlEx::SafeSelectItem(const wxTreeItemId& item)
 			EnsureVisible(item);
 	}
 }
+
+#ifdef __WXMAC__
+void wxTreeCtrlEx::OnChar(wxKeyEvent& event)
+{
+	if (event.GetKeyCode() != WXK_TAB) {
+		event.Skip();
+		return;
+	}
+
+	HandleAsNavigationKey(event);
+}
+#endif
+
