@@ -2,17 +2,13 @@
 #include "view.h"
 #include "viewheader.h"
 
-BEGIN_EVENT_TABLE(CView, wxWindow)
+BEGIN_EVENT_TABLE(CView, wxNavigationEnabled<wxWindow>)
 EVT_SIZE(CView::OnSize)
 END_EVENT_TABLE()
 
 CView::CView(wxWindow* pParent)
-	: wxWindow(pParent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER)
 {
-	m_pWnd = 0;
-	m_pHeader = 0;
-
-	m_pStatusBar = 0;
+	Create(pParent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER);
 }
 
 void CView::SetStatusBar(wxStatusBar* pStatusBar)
@@ -24,16 +20,14 @@ void CView::OnSize(wxSizeEvent&)
 {
 	wxSize size = GetClientSize();
 	wxRect rect(size);
-	if (m_pHeader)
-	{
+	if (m_pHeader) {
 		wxRect headerRect = rect;
 		headerRect.SetHeight(m_pHeader->GetSize().GetHeight());
 		m_pHeader->SetSize(headerRect);
 		rect.SetHeight(rect.GetHeight() - headerRect.GetHeight());
 		rect.SetY(headerRect.GetHeight());
 	}
-	if (m_pStatusBar && m_pStatusBar->IsShown())
-	{
+	if (m_pStatusBar && m_pStatusBar->IsShown()) {
 		const int status_height = m_pStatusBar->GetSize().GetHeight();
 		rect.height -= status_height;
 
@@ -56,6 +50,20 @@ void CView::SetHeader(CViewHeader* pWnd)
 	m_pHeader = pWnd;
 	if (m_pHeader && m_pHeader->GetParent() != this)
 		CViewHeader::Reparent(&m_pHeader, this);
+	FixTabOrder();
+}
+
+void CView::SetWindow(wxWindow* pWnd)
+{
+	m_pWnd = pWnd;
+	FixTabOrder();
+}
+
+void CView::FixTabOrder()
+{
+	if (m_pHeader && m_pWnd && m_pWnd->GetParent() == this) {
+		m_pWnd->MoveAfterInTabOrder(m_pHeader);
+	}
 }
 
 CViewHeader* CView::DetachHeader()
