@@ -33,20 +33,57 @@ TiXmlElement* CXmlFile::Load()
 
 	wxCHECK(!m_fileName.empty(), 0);
 
-	GetXmlFile();
+	wxString redirectedName = GetRedirectedName();
+
+	GetXmlFile(redirectedName);
 	if (!m_pElement) {
 		wxString err = wxString::Format(_("The file '%s' could not be loaded."), m_fileName);
 		if (m_error.empty()) {
-			m_error = err + wxString(_T("\n")) + _("Make sure the file can be accessed and is a well-formed XML document.");
+			err += wxString(_T("\n")) + _("Make sure the file can be accessed and is a well-formed XML document.");
 		}
 		else {
-			m_error = err + _T("\n") + m_error;
+			err += _T("\n") + m_error;
 		}
-		m_modificationTime.clear();
-		return 0;
+
+		// Try the backup file
+		GetXmlFile(redirectedName + _T("~"));
+		if (!m_pElement) {
+			// Loading backup failed. If both original and backup file are empty, create new file.
+			if (CLocalFileSystem::GetSize(redirectedName) <= 0 && CLocalFileSystem::GetSize(redirectedName + _T("~")) <= 0) {
+				m_error.clear();
+				CreateEmpty();
+				m_modificationTime = CLocalFileSystem::GetModificationTime(redirectedName);
+				return m_pElement;
+			}
+
+			// File corrupt and no functional backup, give up.
+			m_error = err;
+			m_modificationTime.clear();
+			return 0;
+		}
+
+
+		// Loading the backup file succeeded, restore file
+		bool res;
+		{
+			wxLogNull null;
+			res = wxCopyFile(redirectedName + _T("~"), redirectedName);
+		}
+		if (!res) {
+			// Could not restore backup, give up.
+			Close();
+			m_error = err;
+			m_error += _T("\n") + wxString::Format(_("The valid backup file %s could not be restored"), redirectedName + _T("~"));
+			m_modificationTime.clear();
+			return 0;
+		}
+
+		// We no longer need the backup
+		wxRemoveFile(redirectedName + _T("~"));
+		m_error.clear();
 	}
 
-	m_modificationTime = CLocalFileSystem::GetModificationTime(m_fileName);
+	m_modificationTime = CLocalFileSystem::GetModificationTime(redirectedName);
 	return m_pElement;
 }
 
@@ -104,22 +141,6 @@ TiXmlElement* CXmlFile::CreateEmpty()
 	return m_pElement;
 }
 
-char* ConvUTF8(const wxString& value)
-{
-	// First convert the string into unicode if neccessary.
-	const wxWCharBuffer buffer = wxConvCurrent->cWX2WC(value);
-
-	// Calculate utf-8 string length
-	wxMBConvUTF8 conv;
-	int len = conv.WC2MB(0, buffer, 0);
-
-	// Not convert the string
-	char *utf8 = new char[len + 1];
-	conv.WC2MB(utf8, buffer, len + 1);
-
-	return utf8;
-}
-
 wxString ConvLocal(const char *value)
 {
 	return wxString(wxConvUTF8.cMB2WC(value), *wxConvCurrent);
@@ -139,12 +160,11 @@ void AddTextElement(TiXmlElement* node, const char* name, const wxString& value,
 {
 	wxASSERT(node);
 
-	char* utf8 = ConvUTF8(value);
+	wxScopedCharBuffer  utf8 = value.utf8_str();
 	if (!utf8)
 		return;
 
 	AddTextElementRaw(node, name, utf8, overwrite);
-	delete [] utf8;
 }
 
 void AddTextElement(TiXmlElement* node, const char* name, int value, bool overwrite)
@@ -180,12 +200,11 @@ void AddTextElement(TiXmlElement* node, const wxString& value)
 	wxASSERT(node);
 	wxASSERT(value);
 
-	char* utf8 = ConvUTF8(value);
+	wxScopedCharBuffer utf8 = value.utf8_str();
 	if (!utf8)
 		return;
 
 	AddTextElementRaw(node, utf8);
-	delete [] utf8;
 }
 
 void AddTextElement(TiXmlElement* node, int value)
@@ -347,9 +366,9 @@ bool GetTextElementBool(TiXmlElement* node, const char* name, bool defValue /*=f
 	}
 }
 
-bool CXmlFile::LoadXmlDocument()
+bool CXmlFile::LoadXmlDocument(wxString const& file)
 {
-	wxFFile f(m_fileName, _T("rb"));
+	wxFFile f(file, _T("rb"));
 	if (!f.IsOpened()) {
 		const wxChar* s = wxSysErrorMsg();
 		if (s && *s)
@@ -368,6 +387,8 @@ bool CXmlFile::LoadXmlDocument()
 		}
 		else
 			m_error = _("Unknown error opening the file. Make sure the file can be accessed and is a well-formed XML document.");
+		delete m_pDocument;
+		m_pDocument = 0;
 		return false;
 	}
 	return true;
@@ -375,30 +396,47 @@ bool CXmlFile::LoadXmlDocument()
 
 // Opens the specified XML file if it exists or creates a new one otherwise.
 // Returns 0 on error.
-void CXmlFile::GetXmlFile()
+bool CXmlFile::GetXmlFile(wxString const& file)
 {
-	if (CLocalFileSystem::GetSize(m_fileName) > 0) {
-		// File does exist, open it
-		if (!LoadXmlDocument()) {
-			Close();
-			return;
-		}
+	Close();
 
-		m_pElement = m_pDocument->FirstChildElement(m_rootName);
-		if (!m_pElement) {
-			if (m_pDocument->FirstChildElement()) {
-				// Not created by FileZilla3
-				Close();
-				m_error = _("Unknown root element, the file does not appear to be generated by FileZilla.");
-			}
-			else {
-				m_pElement = m_pDocument->LinkEndChild(new TiXmlElement(m_rootName))->ToElement();
+	if (CLocalFileSystem::GetSize(file) <= 0) {
+		return false;
+	}
+	
+	// File exists, open it
+	if (!LoadXmlDocument(file)) {
+		return false;
+	}
+
+	m_pElement = m_pDocument->FirstChildElement(m_rootName);
+	if (!m_pElement) {
+		if (m_pDocument->FirstChildElement()) {
+			// Not created by FileZilla3
+			Close();
+			m_error = _("Unknown root element, the file does not appear to be generated by FileZilla.");
+			return false;
+		}
+		m_pElement = m_pDocument->LinkEndChild(new TiXmlElement(m_rootName))->ToElement();
+	}
+
+	return true;
+}
+
+wxString CXmlFile::GetRedirectedName() const
+{
+	wxString redirectedName = m_fileName;
+	bool isLink = false;
+	if (CLocalFileSystem::GetFileInfo(m_fileName, isLink, 0, 0, 0) == CLocalFileSystem::file) {
+		if (isLink) {
+			CLocalPath target(CLocalFileSystem::GetSymbolicLinkTarget(m_fileName));
+			if (!target.empty()) {
+				redirectedName = target.GetPath();
+				redirectedName.RemoveLast();
 			}
 		}
 	}
-	else {
-		CreateEmpty();
-	}
+	return redirectedName;
 }
 
 bool CXmlFile::SaveXmlFile()
@@ -407,17 +445,19 @@ bool CXmlFile::SaveXmlFile()
 
 	bool isLink = false;
 	int flags = 0;
-	if (CLocalFileSystem::GetFileInfo( m_fileName, isLink, 0, 0, &flags ) == CLocalFileSystem::file) {
+
+	wxString redirectedName = GetRedirectedName();
+	if (CLocalFileSystem::GetFileInfo(redirectedName, isLink, 0, 0, &flags) == CLocalFileSystem::file) {
 #ifdef __WXMSW__
 		if (flags & FILE_ATTRIBUTE_HIDDEN)
-			SetFileAttributes(m_fileName, flags & ~FILE_ATTRIBUTE_HIDDEN);
+			SetFileAttributes(redirectedName, flags & ~FILE_ATTRIBUTE_HIDDEN);
 #endif
 
 		exists = true;
 		bool res;
 		{
 			wxLogNull null;
-			res = wxCopyFile(m_fileName, m_fileName + _T("~"));
+			res = wxCopyFile(redirectedName, redirectedName + _T("~"));
 		}
 		if (!res) {
 			m_error = _("Failed to create backup copy of xml file");
@@ -425,19 +465,20 @@ bool CXmlFile::SaveXmlFile()
 		}
 	}
 
-	wxFFile f(m_fileName, _T("w"));
+	wxFFile f(redirectedName, _T("w"));
 	if (!f.IsOpened() || !m_pDocument->SaveFile(f.fp())) {
-		wxRemoveFile(m_fileName);
+		f.Close();
+		wxRemoveFile(redirectedName);
 		if (exists) {
 			wxLogNull null;
-			wxRenameFile(m_fileName + _T("~"), m_fileName);
+			wxRenameFile(redirectedName + _T("~"), redirectedName);
 		}
 		m_error = _("Failed to write xml file");
 		return false;
 	}
 
 	if (exists)
-		wxRemoveFile(m_fileName + _T("~"));
+		wxRemoveFile(redirectedName + _T("~"));
 
 	return true;
 }
@@ -640,12 +681,11 @@ void SetTextAttribute(TiXmlElement* node, const char* name, const wxString& valu
 {
 	wxASSERT(node);
 
-	char* utf8 = ConvUTF8(value);
+	wxScopedCharBuffer utf8 = value.utf8_str();
 	if (!utf8)
 		return;
 
 	node->SetAttribute(name, utf8);
-	delete [] utf8;
 }
 
 wxString GetTextAttribute(TiXmlElement* node, const char* name)
